@@ -20,28 +20,29 @@
 #include "base/functional/callback.h"
 #include "base/functional/callback_helpers.h"
 #include "base/i18n/time_formatting.h"
-#include "base/lazy_instance.h"
 #include "base/logging.h"
 #include "base/memory/ptr_util.h"
 #include "base/memory/weak_ptr.h"
 #include "base/metrics/histogram_macros.h"
+#include "base/no_destructor.h"
+#include "base/notimplemented.h"
 #include "base/strings/string_split.h"
 #include "base/strings/string_util.h"
 #include "base/strings/utf_string_conversions.h"
 #include "base/task/cancelable_task_tracker.h"
 #include "base/task/current_thread.h"
 #include "base/task/single_thread_task_runner.h"
+#include "base/time/time.h"
 #include "base/values.h"
 #include "build/build_config.h"
 #include "chrome/browser/browser_process.h"
 #include "chrome/browser/download/download_core_service.h"
 #include "chrome/browser/download/download_core_service_factory.h"
-#include "chrome/browser/download/download_danger_prompt.h"
 #include "chrome/browser/download/download_file_icon_extractor.h"
-#include "chrome/browser/download/download_open_prompt.h"
 #include "chrome/browser/download/download_prefs.h"
 #include "chrome/browser/download/download_query.h"
 #include "chrome/browser/download/download_stats.h"
+#include "chrome/browser/extensions/api/downloads/download_extension_errors.h"
 #include "chrome/browser/extensions/chrome_extension_function_details.h"
 #include "chrome/browser/extensions/extension_util.h"
 #include "chrome/browser/extensions/window_controller.h"
@@ -50,8 +51,6 @@
 #include "chrome/browser/icon_manager.h"
 #include "chrome/browser/platform_util.h"
 #include "chrome/browser/profiles/profile.h"
-#include "chrome/browser/ui/browser.h"
-#include "chrome/browser/ui/browser_window.h"
 #include "chrome/common/extensions/api/downloads.h"
 #include "components/download/public/common/download_danger_type.h"
 #include "components/download/public/common/download_interrupt_reasons.h"
@@ -68,6 +67,7 @@
 #include "extensions/browser/extension_prefs.h"
 #include "extensions/browser/install_prefs_helper.h"
 #include "extensions/browser/warning_service.h"
+#include "extensions/buildflags/buildflags.h"
 #include "extensions/common/extension_id.h"
 #include "extensions/common/mojom/context_type.mojom.h"
 #include "extensions/common/mojom/event_dispatcher.mojom-forward.h"
@@ -81,10 +81,19 @@
 #include "ui/gfx/image/image_skia.h"
 #include "ui/gfx/image/image_skia_rep.h"
 
-#if !BUILDFLAG(IS_CHROMEOS)
+#if !BUILDFLAG(IS_CHROMEOS) && BUILDFLAG(ENABLE_EXTENSIONS)
 #include "chrome/browser/download/bubble/download_bubble_ui_controller.h"
 #endif
 
+#if BUILDFLAG(ENABLE_EXTENSIONS)
+#include "chrome/browser/download/download_danger_prompt.h"
+#include "chrome/browser/download/download_open_prompt.h"
+#include "chrome/browser/ui/browser.h"
+#include "chrome/browser/ui/browser_window.h"
+#endif
+
+static_assert(BUILDFLAG(ENABLE_EXTENSIONS_CORE));
+
 using content::BrowserContext;
 using content::BrowserThread;
 using content::DownloadManager;
@@ -92,48 +101,6 @@ using download::DownloadItem;
 using download::DownloadPathReservationTracker;
 using extensions::mojom::APIPermissionID;
 
-namespace download_extension_errors {
-
-const char kEmptyFile[] = "Filename not yet determined";
-const char kFileAlreadyDeleted[] = "Download file already deleted";
-const char kFileNotRemoved[] = "Unable to remove file";
-const char kIconNotFound[] = "Icon not found";
-const char kInvalidDangerType[] = "Invalid danger type";
-const char kInvalidFilename[] = "Invalid filename";
-const char kInvalidFilter[] = "Invalid query filter";
-const char kInvalidHeaderName[] = "Invalid request header name";
-const char kInvalidHeaderUnsafe[] = "Unsafe request header name";
-const char kInvalidHeaderValue[] = "Invalid request header value";
-const char kInvalidId[] = "Invalid downloadId";
-const char kInvalidOrderBy[] = "Invalid orderBy field";
-const char kInvalidQueryLimit[] = "Invalid query limit";
-const char kInvalidState[] = "Invalid state";
-const char kInvalidURL[] = "Invalid URL";
-const char kInvisibleContext[] =
-    "Javascript execution context is not visible "
-    "(tab, window, popup bubble)";
-const char kNotComplete[] = "Download must be complete";
-const char kNotDangerous[] = "Download must be dangerous";
-const char kNotInProgress[] = "Download must be in progress";
-const char kNotResumable[] = "DownloadItem.canResume must be true";
-const char kOpenPermission[] = "The \"downloads.open\" permission is required";
-const char kShelfDisabled[] = "Another extension has disabled the shelf";
-const char kShelfPermission[] =
-    "downloads.setShelfEnabled requires the "
-    "\"downloads.shelf\" permission";
-const char kTooManyListeners[] =
-    "Each extension may have at most one "
-    "onDeterminingFilename listener between all of its renderer execution "
-    "contexts.";
-const char kUiDisabled[] = "Another extension has disabled the download UI";
-const char kUiPermission[] =
-    "downloads.setUiOptions requires the "
-    "\"downloads.ui\" permission";
-const char kUnexpectedDeterminer[] = "Unexpected determineFilename call";
-const char kUserGesture[] = "User gesture required";
-
-}  // namespace download_extension_errors
-
 namespace extensions {
 
 namespace {
@@ -622,17 +589,22 @@ void RecordApiFunctions(DownloadsFunctionName function) {
                             DownloadsFunctionName::kDownloadsFunctionLast);
 }
 
+SortTypeMap& GetSortTypeMap() {
+  static base::NoDestructor<SortTypeMap> map;
+  return *map;
+}
+
 void CompileDownloadQueryOrderBy(const std::vector<std::string>& order_by_strs,
                                  std::string* error,
                                  DownloadQuery* query) {
-  // TODO(benjhayden): Consider switching from LazyInstance to explicit string
+  // TODO(benjhayden): Consider switching from NoDestructor to explicit string
   // comparisons.
-  static base::LazyInstance<SortTypeMap>::DestructorAtExit sorter_types =
-      LAZY_INSTANCE_INITIALIZER;
-  if (sorter_types.Get().empty())
-    InitSortTypeMap(sorter_types.Pointer());
+  SortTypeMap& sort_type_map = GetSortTypeMap();
+  if (sort_type_map.empty()) {
+    InitSortTypeMap(&sort_type_map);
+  }
 
-  for (auto term_str : order_by_strs) {
+  for (std::string_view term_str : order_by_strs) {
     if (term_str.empty())
       continue;
     DownloadQuery::SortDirection direction = DownloadQuery::ASCENDING;
@@ -640,8 +612,8 @@ void CompileDownloadQueryOrderBy(const std::vector<std::string>& order_by_strs,
       direction = DownloadQuery::DESCENDING;
       term_str = term_str.substr(1);
     }
-    SortTypeMap::const_iterator sorter_type = sorter_types.Get().find(term_str);
-    if (sorter_type == sorter_types.Get().end()) {
+    SortTypeMap::const_iterator sorter_type = sort_type_map.find(term_str);
+    if (sorter_type == sort_type_map.end()) {
       *error = download_extension_errors::kInvalidOrderBy;
       return;
     }
@@ -649,17 +621,22 @@ void CompileDownloadQueryOrderBy(const std::vector<std::string>& order_by_strs,
   }
 }
 
+FilterTypeMap& GetFilterTypeMap() {
+  static base::NoDestructor<FilterTypeMap> map;
+  return *map;
+}
+
 void RunDownloadQuery(const downloads::DownloadQuery& query_in,
                       DownloadManager* manager,
                       DownloadManager* incognito_manager,
                       std::string* error,
                       DownloadQuery::DownloadVector* results) {
-  // TODO(benjhayden): Consider switching from LazyInstance to explicit string
+  // TODO(benjhayden): Consider switching from NoDestructor to explicit string
   // comparisons.
-  static base::LazyInstance<FilterTypeMap>::DestructorAtExit filter_types =
-      LAZY_INSTANCE_INITIALIZER;
-  if (filter_types.Get().empty())
-    InitFilterTypeMap(filter_types.Pointer());
+  FilterTypeMap& filter_type_map = GetFilterTypeMap();
+  if (filter_type_map.empty()) {
+    InitFilterTypeMap(&filter_type_map);
+  }
 
   DownloadQuery query_out;
 
@@ -702,8 +679,8 @@ void RunDownloadQuery(const downloads::DownloadQuery& query_in,
 
   for (const auto query_json_field : query_in.ToValue()) {
     FilterTypeMap::const_iterator filter_type =
-        filter_types.Get().find(query_json_field.first);
-    if (filter_type != filter_types.Get().end()) {
+        filter_type_map.find(query_json_field.first);
+    if (filter_type != filter_type_map.end()) {
       if (!query_out.AddFilter(filter_type->second, query_json_field.second)) {
         *error = download_extension_errors::kInvalidFilter;
         return;
@@ -756,12 +733,7 @@ class ExtensionDownloadsEventRouterData : public base::SupportsUserData::Data {
 
   explicit ExtensionDownloadsEventRouterData(DownloadItem* download_item,
                                              base::Value::Dict json_item)
-      : updated_(0),
-        changed_fired_(0),
-        json_(std::move(json_item)),
-        creator_conflict_action_(downloads::FilenameConflictAction::kUniquify),
-        determined_conflict_action_(
-            downloads::FilenameConflictAction::kUniquify),
+      : json_(std::move(json_item)),
         is_download_completed_(download_item->GetState() ==
                                DownloadItem::COMPLETE),
         is_completed_download_deleted_(
@@ -793,8 +765,8 @@ class ExtensionDownloadsEventRouterData : public base::SupportsUserData::Data {
   void OnItemUpdated() { ++updated_; }
   void OnChangedFired() { ++changed_fired_; }
 
-  static void SetDetermineFilenameTimeoutSecondsForTesting(int s) {
-    determine_filename_timeout_s_ = s;
+  static void SetDetermineFilenameTimeoutForTesting(base::TimeDelta timeout) {
+    determine_filename_timeout_ = timeout;
   }
 
   void BeginFilenameDetermination(
@@ -815,7 +787,7 @@ class ExtensionDownloadsEventRouterData : public base::SupportsUserData::Data {
         base::BindOnce(
             &ExtensionDownloadsEventRouterData::DetermineFilenameTimeout,
             weak_ptr_factory_->GetWeakPtr()),
-        base::Seconds(determine_filename_timeout_s_));
+        determine_filename_timeout_);
   }
 
   void DetermineFilenameTimeout() { CallFilenameCallback(); }
@@ -939,7 +911,7 @@ class ExtensionDownloadsEventRouterData : public base::SupportsUserData::Data {
   }
 
  private:
-  static int determine_filename_timeout_s_;
+  static base::TimeDelta determine_filename_timeout_;
 
   struct DeterminerInfo {
     DeterminerInfo();
@@ -978,8 +950,8 @@ class ExtensionDownloadsEventRouterData : public base::SupportsUserData::Data {
         base::Seconds(15));
   }
 
-  int updated_;
-  int changed_fired_;
+  int updated_ = 0;
+  int changed_fired_ = 0;
   // Dictionary representing the current state of the download. It is cleared
   // when download completes.
   base::Value::Dict json_;
@@ -989,9 +961,11 @@ class ExtensionDownloadsEventRouterData : public base::SupportsUserData::Data {
   DeterminerInfoVector determiners_;
 
   base::FilePath creator_suggested_filename_;
-  downloads::FilenameConflictAction creator_conflict_action_;
+  downloads::FilenameConflictAction creator_conflict_action_ =
+      downloads::FilenameConflictAction::kUniquify;
   base::FilePath determined_filename_;
-  downloads::FilenameConflictAction determined_conflict_action_;
+  downloads::FilenameConflictAction determined_conflict_action_ =
+      downloads::FilenameConflictAction::kUniquify;
   DeterminerInfo determiner_;
 
   // Whether a download is complete and whether the completed download is
@@ -1003,7 +977,8 @@ class ExtensionDownloadsEventRouterData : public base::SupportsUserData::Data {
       weak_ptr_factory_;
 };
 
-int ExtensionDownloadsEventRouterData::determine_filename_timeout_s_ = 15;
+base::TimeDelta ExtensionDownloadsEventRouterData::determine_filename_timeout_ =
+    base::Seconds(15);
 
 ExtensionDownloadsEventRouterData::DeterminerInfo::DeterminerInfo(
     const ExtensionId& e_id,
@@ -1217,10 +1192,12 @@ ExtensionFunction::ResponseAction DownloadsSearchFunction::Run() {
   DownloadManager* incognito_manager = nullptr;
   GetManagers(browser_context(), include_incognito_information(), &manager,
               &incognito_manager);
+  CHECK(manager);
   ExtensionDownloadsEventRouter* router =
       DownloadCoreServiceFactory::GetForBrowserContext(
           manager->GetBrowserContext())
           ->GetExtensionEventRouter();
+  CHECK(router);
   router->CheckForHistoryFilesRemoval();
   if (incognito_manager) {
     ExtensionDownloadsEventRouter* incognito_router =
@@ -1434,6 +1411,7 @@ void DownloadsAcceptDangerFunction::PromptOrWait(int download_id, int retries) {
     return;
   }
   RecordApiFunctions(DownloadsFunctionName::kDownloadsFunctionAcceptDanger);
+#if BUILDFLAG(ENABLE_EXTENSIONS)
   // DownloadDangerPrompt displays a modal dialog using native widgets that the
   // user must either accept or cancel. It cannot be scripted.
   DownloadDangerPrompt* prompt = DownloadDangerPrompt::Create(
@@ -1446,6 +1424,10 @@ void DownloadsAcceptDangerFunction::PromptOrWait(int download_id, int retries) {
     on_prompt_created_ = nullptr;
   }
   // Function finishes in DangerPromptCallback().
+#else
+  NOTIMPLEMENTED();
+  Respond(Error("DownloadDangerPrompt not implemented"));
+#endif  // BUILDFLAG(ENABLE_EXTENSIONS)
 }
 
 void DownloadsAcceptDangerFunction::DangerPromptCallback(
@@ -1561,6 +1543,7 @@ ExtensionFunction::ResponseAction DownloadsOpenFunction::Run() {
   // TODO(qinmin): check if user prefers to open all download using the same
   // extension, or check the recent user gesture on the originating webcontents
   // to avoid showing the prompt.
+#if BUILDFLAG(ENABLE_EXTENSIONS)
   DownloadOpenPrompt* download_open_prompt =
       DownloadOpenPrompt::CreateDownloadOpenConfirmationDialog(
           active_contents,
@@ -1572,6 +1555,10 @@ ExtensionFunction::ResponseAction DownloadsOpenFunction::Run() {
     std::move(*on_prompt_created_cb_).Run(download_open_prompt);
   RecordApiFunctions(DownloadsFunctionName::kDownloadsFunctionOpen);
   return RespondLater();
+#else
+  NOTIMPLEMENTED();
+  return RespondNow(Error("DownloadOpenPrompt not implemented"));
+#endif
 }
 
 void DownloadsOpenFunction::OpenPromptDone(int download_id, bool accept) {
@@ -1624,7 +1611,7 @@ ExtensionFunction::ResponseAction DownloadsSetShelfEnabledFunction::Run() {
     if (!match_current_service || current_service->IsDownloadUiEnabled()) {
       continue;
     }
-#if !BUILDFLAG(IS_CHROMEOS)
+#if !BUILDFLAG(IS_CHROMEOS) && BUILDFLAG(ENABLE_EXTENSIONS)
     // Calling this API affects the download bubble as well, so extensions
     // using this API is still compatible with the new download bubble. This
     // API will eventually be deprecated (replaced by the SetUiOptions API
@@ -1678,7 +1665,7 @@ ExtensionFunction::ResponseAction DownloadsSetUiOptionsFunction::Run() {
       continue;
     }
 
-#if !BUILDFLAG(IS_CHROMEOS)
+#if !BUILDFLAG(IS_CHROMEOS) && BUILDFLAG(ENABLE_EXTENSIONS)
     Browser* browser = window->GetBrowser();
     if (browser->window()->GetDownloadBubbleUIController()) {
       browser->window()->GetDownloadBubbleUIController()->HideDownloadUi();
@@ -1779,10 +1766,10 @@ ExtensionDownloadsEventRouter::~ExtensionDownloadsEventRouter() {
     router->UnregisterObserver(this);
 }
 
-void ExtensionDownloadsEventRouter::
-    SetDetermineFilenameTimeoutSecondsForTesting(int s) {
-  ExtensionDownloadsEventRouterData::
-      SetDetermineFilenameTimeoutSecondsForTesting(s);
+void ExtensionDownloadsEventRouter::SetDetermineFilenameTimeoutForTesting(
+    base::TimeDelta timeout) {
+  ExtensionDownloadsEventRouterData::SetDetermineFilenameTimeoutForTesting(
+      timeout);
 }
 
 void ExtensionDownloadsEventRouter::SetUiEnabled(const Extension* extension,
