@@ -15,6 +15,7 @@
 #include "chrome/common/buildflags.h"
 #include "chrome/common/extensions/extension_constants.h"
 #include "chrome/grit/browser_resources.h"
+#include "extensions/buildflags/buildflags.h"
 #include "extensions/common/constants.h"
 #include "printing/buildflags/buildflags.h"
 
@@ -25,6 +26,8 @@
 #include "ui/file_manager/grit/file_manager_resources.h"
 #endif
 
+static_assert(BUILDFLAG(ENABLE_EXTENSIONS_CORE));
+
 namespace extensions {
 
 bool IsComponentExtensionAllowlisted(const std::string& extension_id) {
