@@ -312,7 +312,7 @@ void ComponentLoader::Reload(const ExtensionId& extension_id) {
 }
 
 void ComponentLoader::Load(const ComponentExtensionInfo& info) {
-  std::string error;
+  std::u16string error;
   scoped_refptr<const Extension> extension(CreateExtension(info, &error));
   if (!extension.get()) {
     LOG(ERROR) << error;
@@ -459,7 +459,7 @@ void ComponentLoader::AddKeyboardApp() {
 
 scoped_refptr<const Extension> ComponentLoader::CreateExtension(
     const ComponentExtensionInfo& info,
-    std::string* utf8_error) {
+    std::u16string* error) {
   // TODO(abarth): We should REQUIRE_MODERN_MANIFEST_VERSION once we've updated
   //               our component extensions to the new manifest version.
   int flags = Extension::REQUIRE_KEY;
@@ -472,7 +472,7 @@ scoped_refptr<const Extension> ComponentLoader::CreateExtension(
 
   return Extension::Create(info.root_directory,
                            mojom::ManifestLocation::kComponent, info.manifest,
-                           flags, utf8_error);
+                           flags, error);
 }
 
 // static
