@@ -94,6 +94,10 @@ const char kFCMOAuthScope[] =
 // OAuth2 scope for access to Tachyon api.
 const char kTachyonOAuthScope[] = "https://www.googleapis.com/auth/tachyon";
 
+// OAuth2 scope for School Tools API.
+const char kSchoolToolsAuthScope[] =
+    "https://www.googleapis.com/auth/chromeosschooltools";
+
 // OAuth2 scope for access to the Photos API.
 const char kPhotosOAuth2Scope[] = "https://www.googleapis.com/auth/photos";
 
@@ -129,6 +133,10 @@ const char kCryptAuthOAuth2Scope[] =
 // OAuth2 scope for access to Drive.
 const char kDriveOAuth2Scope[] = "https://www.googleapis.com/auth/drive";
 
+// OAuth2 scope for access to Drive Apps.
+const char kDriveAppsOAuth2Scope[] =
+    "https://www.googleapis.com/auth/drive.apps";
+
 // OAuth2 scope for access for DriveFS to access flags.
 const char kExperimentsAndConfigsOAuth2Scope[] =
     "https://www.googleapis.com/auth/experimentsandconfigs";
@@ -149,6 +157,10 @@ const char kAssistantOAuth2Scope[] =
 const char kNearbyDevicesOAuth2Scope[] =
     "https://www.googleapis.com/auth/nearbydevices-pa";
 
+// OAuth2 scope for access to readonly Drive Apps.
+const char kDriveAppsReadonlyOAuth2Scope[] =
+    "https://www.googleapis.com/auth/drive.apps.readonly";
+
 // OAuth2 scope for access to nearby sharing.
 const char kNearbyShareOAuth2Scope[] =
     "https://www.googleapis.com/auth/nearbysharing-pa";
@@ -272,6 +284,8 @@ const char kPushNotificationOAuth2Scope[] =
 // OAuth2 scope for app license check.
 const char kLicenseCheckOAuth2Scope[] =
     "https://www.googleapis.com/auth/applicense.bytebot";
+// OAuth2 scope for manta.
+const char kMantaOAuth2Scope[] = "https://www.googleapis.com/auth/mdi.aratea";
 
 // Used to build ClientOAuth requests.  These are the names of keys used when
 // building base::DictionaryValue that represent the json data that makes up
