@@ -25,18 +25,31 @@ function $(id) {
   return document.getElementById(id);
 }
 
+/**
+ * A helper function that calls the post-processing functions on a given
+ * element.
+ * @param {HTMLElement} element The container element of the article.
+ */
+function postProcessElement(element) {
+  // Wrap tables to make them scrollable.
+  wrapTables(element);
+
+  // Readability will leave iframes around, but they need the proper structure
+  // and classes to be styled correctly.
+  addClassesToYoutubeIFrames(element);
+  // DomDistiller will leave placeholders, which need to be replaced with
+  // actual iframes.
+  fillYouTubePlaceholders(element);
+  sanitizeLinks(element);
+  identifyEmptySVGs(element);
+  ImageClassifier.processImagesIn(element);
+}
+
 function addToPage(html) {
   const div = document.createElement('div');
   div.innerHTML = html;
   $('content').appendChild(div);
-  // Readability will leave iframes around, but they need the proper structure
-  // and classes to be styled correctly.
-  addClassesToYoutubeIFrames(div);
-  // DomDistiller will leave placeholders, which need to be replaced with
-  // actual iframes.
-  fillYouTubePlaceholders(div);
-  sanitizeLinks(div);
-  ImageClassifier.processImagesIn(div);
+  postProcessElement(div);
 }
 
 /**
@@ -136,8 +149,12 @@ class ImageClassifier {
     if (container) {
       for (const child of container.childNodes) {
         // Skip insignificant nodes.
-        if (child === img) continue;
-        if (child.tagName === 'BR') continue;
+        if (child === img) {
+          continue;
+        }
+        if (child.tagName === 'BR') {
+          continue;
+        }
         if (child.nodeType === Node.TEXT_NODE &&
             child.textContent.trim() === '') {
           continue;
@@ -269,6 +286,30 @@ function sanitizeLinks(element) {
   });
 }
 
+/**
+ * Finds SVGs that use a local resource pointer (e.g. <use xlink:href="#...")
+ * and adds a class to them for styling. This is necessary because CSS
+ * selectors for namespaced attributes like `xlink:href` are not reliably
+ * supported across all renderers.
+ * @param {HTMLElement} element The element to search for SVGs in.
+ */
+function identifyEmptySVGs(element) {
+  const svgs = element.getElementsByTagName('svg');
+  for (const svg of svgs) {
+    const useElement = svg.querySelector('use');
+    if (!useElement) {
+      continue;
+    }
+
+    const href = useElement.getAttribute('href');
+    const xlinkHref = useElement.getAttribute('xlink:href');
+
+    if (href?.startsWith('#') || xlinkHref?.startsWith('#')) {
+      svg.classList.add('distilled-svg-with-local-ref');
+    }
+  }
+}
+
 /**
  * Locates youtube embeds generated by DomDistiller, and creates an iframe for
  * each.
@@ -346,6 +387,28 @@ function embedYoutubeIFrame(element) {
   container.appendChild(element);
 }
 
+/**
+ * Finds all tables within an element and wraps each in a div with the
+ * 'scrollable-container' class to enable horizontal scrolling.
+ * @param {HTMLElement} element The element to search for tables in.
+*/
+function wrapTables(element) {
+  const containerClass = 'distilled-scrollable-container';
+  const tables = element.querySelectorAll('table');
+  tables.forEach(table => {
+    const tableParent = table.parentElement;
+    if (!tableParent || tableParent.classList.contains(containerClass)) {
+      return;
+    }
+
+    const wrapper = document.createElement('div');
+    wrapper.className = containerClass;
+
+    tableParent.insertBefore(wrapper, table);
+    wrapper.appendChild(table);
+  });
+}
+
 function showLoadingIndicator(isLastPage) {
   $('loading-indicator').className = isLastPage ? 'hidden' : 'visible';
 }
@@ -525,7 +588,7 @@ class Pincher {
   refreshTransform_() {
     const slowedScale = Math.exp(Math.log(this.scale) * FONT_SCALE_MULTIPLIER);
     this.clampedScale =
-        Math.max($MIN_SCALE, Math.min(2.0, this.fontSizeAnchor * slowedScale));
+        Math.max($MIN_SCALE, Math.min($MAX_SCALE, this.fontSizeAnchor * slowedScale));
 
     // Use "fake" 3D transform so that the layer is not repainted.
     // With 2D transform, the frame rate would be much lower.
