@@ -541,7 +541,9 @@ void PrefetchContainer::SetPrefetchStatus(PrefetchStatus prefetch_status) {
   switch (GetLoadState()) {
     case LoadState::kStarted:
     case LoadState::kDeterminedHead:
-    case LoadState::kCompletedOrFailed:
+    case LoadState::kFailedDeterminedHead:
+    case LoadState::kCompleted:
+    case LoadState::kFailed:
       SetTriggeringOutcomeAndFailureReasonFromStatus(prefetch_status);
       break;
     case LoadState::kNotStarted:
@@ -615,6 +617,10 @@ void PrefetchContainer::CloseIdleConnections() {
 }
 
 void PrefetchContainer::SetLoadState(LoadState new_load_state) {
+  if (base::FeatureList::IsEnabled(features::kPrefetchGracefulNotification)) {
+    CHECK(!is_in_dtor_);
+  }
+
   switch (new_load_state) {
     case LoadState::kNotStarted:
       NOTREACHED();
@@ -630,12 +636,20 @@ void PrefetchContainer::SetLoadState(LoadState new_load_state) {
       break;
 
     case LoadState::kDeterminedHead:
+    case LoadState::kFailedDeterminedHead:
       CHECK_EQ(load_state_, LoadState::kStarted);
       break;
 
-    case LoadState::kCompletedOrFailed:
+    case LoadState::kCompleted:
+      // `kFailedDeterminedHead` never transitions to successful `kCompleted`.
       CHECK_EQ(load_state_, LoadState::kDeterminedHead);
       break;
+
+    case LoadState::kFailed:
+      // Failures can happen after successful `kDeterminedHead`.
+      CHECK(load_state_ == LoadState::kDeterminedHead ||
+            load_state_ == LoadState::kFailedDeterminedHead);
+      break;
   }
   DVLOG(1) << (*this) << " LoadState " << load_state_ << " -> "
            << new_load_state;
@@ -889,8 +903,18 @@ void PrefetchContainer::CancelStreamingURLLoaderIfNotServing() {
   streaming_loader_.reset();
 }
 
-void PrefetchContainer::OnDeterminedHead() {
-  SetLoadState(LoadState::kDeterminedHead);
+void PrefetchContainer::OnDeterminedHead(bool is_successful_determined_head) {
+  if (base::FeatureList::IsEnabled(features::kPrefetchGracefulNotification) &&
+      is_in_dtor_) {
+    // This can be called due to the loader cancellation during the
+    // `PrefetchContainer` destruction. No state changes should be made and
+    // observers shouldn't be notified during destruction.
+    return;
+  }
+
+  SetLoadState(is_successful_determined_head
+                   ? LoadState::kDeterminedHead
+                   : LoadState::kFailedDeterminedHead);
 
   if (GetNonRedirectHead()) {
     prefetch_container_metrics_.time_header_determined_successfully =
@@ -1024,9 +1048,14 @@ void PrefetchContainer::OnPrefetchCompleteInternal(
   }
 }
 
+// TODO(https://crbug.com/432518638): We should be able to calculate
+// `is_success` and `completion_status` from the last `PrefetchResponseReader`.
+// Before https://crbug.com/432518638 is fixed, we explicitly plumb them here to
+// ensure the correct `PrefetchResponseReader`'s states are used.
 void PrefetchContainer::OnPrefetchComplete(
+    bool is_success,
     const network::URLLoaderCompletionStatus& completion_status) {
-  SetLoadState(LoadState::kCompletedOrFailed);
+  SetLoadState(is_success ? LoadState::kCompleted : LoadState::kFailed);
   OnPrefetchCompleteInternal(completion_status);
 
   std::optional<int> response_code = std::nullopt;
@@ -1058,6 +1087,60 @@ void PrefetchContainer::UpdatePrefetchRequestMetrics(
 
 PrefetchServableState PrefetchContainer::GetServableState(
     base::TimeDelta cacheable_duration) const {
+  // We allow the differences between `GetServableStateInternal()` and
+  // `match_resolver_action.ToServableState()` because we know the latter should
+  // be the correct behavior.
+  auto is_known_allowed_exception =
+      [&](PrefetchServableState servable_state,
+          const PrefetchMatchResolverAction& match_resolver_action) {
+        // `GetCodeOfPrefetchServableStateAndPrefetchMatchResolverActionForDebug()
+        // == 2181`
+        // Failed test: PrefetchServiceTest.IneligibleRedirectCookies/*
+        //
+        // `OnDeterminedHead()` is called when redirect is judged as ineligible,
+        // with `GetNonRedirectResponseReader()` null. Ideally, we should treat
+        // this case as `PrefetchServableState::kNotServable`, but the current
+        // `GetServableStateInternal()` returns
+        // `PrefetchServableState::kShouldBlockUntilHeadReceived`. We will keep
+        // the current behavior and fix it by replacing the implementation with
+        // `GetMatchResolverAction()`.
+        //
+        // TODO(crbug.com/455448933): Do it.
+        if (servable_state ==
+                PrefetchServableState::kShouldBlockUntilHeadReceived &&
+            match_resolver_action.kind() ==
+                PrefetchMatchResolverAction::ActionKind::kDrop &&
+            match_resolver_action.prefetch_container_load_state() ==
+                PrefetchContainer::LoadState::kFailedDeterminedHead) {
+          return true;
+        }
+
+        return false;
+      };
+
+  PrefetchServableState servable_state =
+      GetServableStateInternal(cacheable_duration);
+  PrefetchMatchResolverAction match_resolver_action =
+      GetMatchResolverAction(cacheable_duration);
+
+  if (servable_state != match_resolver_action.ToServableState() &&
+      !is_known_allowed_exception(servable_state, match_resolver_action)) {
+    // We are going to switch from the old implementation
+    // (`GetServableStateInternal()`) to the new one
+    // (`match_resolver_action.ToServableState()`), and check the behavior
+    // difference, if any.
+    SCOPED_CRASH_KEY_NUMBER(
+        "PrefetchContainer", "GSS_ssma",
+        GetCodeOfPrefetchServableStateAndPrefetchMatchResolverActionForDebug(
+            servable_state, match_resolver_action));
+    DUMP_WILL_BE_NOTREACHED();
+  }
+
+  return servable_state;
+}
+
+PrefetchServableState PrefetchContainer::GetServableStateInternal(
+    base::TimeDelta cacheable_duration) const {
   // Servable if the non-redirect response (either fully or partially
   // received body) is servable.
   if (GetNonRedirectResponseReader() &&
@@ -1083,7 +1166,9 @@ PrefetchServableState PrefetchContainer::GetServableState(
       case LoadState::kFailedIneligible:
       case LoadState::kStarted:
       case LoadState::kDeterminedHead:
-      case LoadState::kCompletedOrFailed:
+      case LoadState::kFailedDeterminedHead:
+      case LoadState::kCompleted:
+      case LoadState::kFailed:
       case LoadState::kFailedHeldback:
         // nop
         break;
@@ -1093,6 +1178,65 @@ PrefetchServableState PrefetchContainer::GetServableState(
   return PrefetchServableState::kNotServable;
 }
 
+PrefetchMatchResolverAction PrefetchContainer::GetMatchResolverAction(
+    base::TimeDelta cacheable_duration) const {
+  switch (load_state_) {
+    case LoadState::kNotStarted:
+      if (features::UsePrefetchPrerenderIntegration()) {
+        return PrefetchMatchResolverAction(
+            PrefetchMatchResolverAction::ActionKind::kWait, load_state_,
+            std::nullopt);
+      } else {
+        return PrefetchMatchResolverAction(
+            PrefetchMatchResolverAction::ActionKind::kDrop, load_state_,
+            std::nullopt);
+      }
+    case LoadState::kEligible:
+      if (features::UsePrefetchPrerenderIntegration()) {
+        return PrefetchMatchResolverAction(
+            PrefetchMatchResolverAction::ActionKind::kWait, load_state_,
+            std::nullopt);
+      } else {
+        return PrefetchMatchResolverAction(
+            PrefetchMatchResolverAction::ActionKind::kDrop, load_state_,
+            std::nullopt);
+      }
+    case LoadState::kStarted:
+      return PrefetchMatchResolverAction(
+          PrefetchMatchResolverAction::ActionKind::kWait, load_state_,
+          std::nullopt);
+    case LoadState::kDeterminedHead: {
+      const bool is_expired = false;
+      return PrefetchMatchResolverAction(
+          PrefetchMatchResolverAction::ActionKind::kMaybeServe, load_state_,
+          is_expired);
+    }
+    case LoadState::kFailedDeterminedHead:
+      return PrefetchMatchResolverAction(
+          PrefetchMatchResolverAction::ActionKind::kDrop, load_state_,
+          std::nullopt);
+    case LoadState::kCompleted: {
+      CHECK(!redirect_chain_.empty());
+      CHECK_EQ(redirect_chain_.back()->response_reader_->load_state(),
+               PrefetchResponseReader::LoadState::kCompleted);
+      // This branch corresponds to the first `if` in
+      // `GetServableStateInternal()`.
+      CHECK(GetNonRedirectResponseReader());
+      const bool is_expired =
+          !GetNonRedirectResponseReader()->Servable(cacheable_duration);
+      return PrefetchMatchResolverAction(
+          PrefetchMatchResolverAction::ActionKind::kMaybeServe, load_state_,
+          is_expired);
+    }
+    case LoadState::kFailedHeldback:
+    case LoadState::kFailedIneligible:
+    case LoadState::kFailed:
+      return PrefetchMatchResolverAction(
+          PrefetchMatchResolverAction::ActionKind::kDrop, load_state_,
+          std::nullopt);
+  }
+}
+
 PrefetchSingleRedirectHop&
 PrefetchContainer::GetCurrentSingleRedirectHopToPrefetch() const {
   CHECK(redirect_chain_.size() > 0);
@@ -1190,7 +1334,16 @@ void PrefetchContainer::OnDetectedCookiesChange(
   CHECK_NE(GetPrefetchStatus(), PrefetchStatus::kPrefetchNotUsedCookiesChanged);
   SetPrefetchStatus(PrefetchStatus::kPrefetchNotUsedCookiesChanged);
   UpdateServingPageMetrics();
-  CancelStreamingURLLoaderIfNotServing();
+
+  if (base::FeatureList::IsEnabled(
+          features::kPrefetchAsyncCancelOnCookiesChange)) {
+    base::SequencedTaskRunner::GetCurrentDefault()->PostTask(
+        FROM_HERE,
+        base::BindOnce(&PrefetchContainer::CancelStreamingURLLoaderIfNotServing,
+                       GetWeakPtr()));
+  } else {
+    CancelStreamingURLLoaderIfNotServing();
+  }
 }
 
 void PrefetchContainer::OnPrefetchStarted() {
@@ -1313,6 +1466,11 @@ void PrefetchContainer::MakeResourceRequest() {
   // not be visible outside of the network context.
   resource_request->load_flags = net::LOAD_PREFETCH;
 
+  // TODO(crbug.com/455296998): Remove this code for M145.
+  if (request().should_bypass_http_cache()) {
+    resource_request->load_flags |= net::LOAD_DISABLE_CACHE;
+  }
+
   AddAwAdditionalHeaders(resource_request->headers,
                          request().additional_headers());
 
@@ -1413,7 +1571,7 @@ bool PrefetchContainer::ShouldApplyUserAgentOverride(
   }
   raw_ptr<WebContentsDelegate> delegate = referring_web_contents->GetDelegate();
   NavigationController::UserAgentOverrideOption option =
-      delegate ? delegate->ShouldOverrideUserAgentForPrerender2(request_url)
+      delegate ? delegate->ShouldOverrideUserAgentForPreloading(request_url)
                : NavigationController::UA_OVERRIDE_INHERIT;
   // Use the primary main frame of initiator's WebContents to guess if we should
   // apply UA overrides in this prefetch request. Note that this decision is
@@ -1565,8 +1723,12 @@ std::ostream& operator<<(std::ostream& ostream,
       return ostream << "Started";
     case PrefetchContainer::LoadState::kDeterminedHead:
       return ostream << "DeterminedHead";
-    case PrefetchContainer::LoadState::kCompletedOrFailed:
-      return ostream << "CompletedOrFailed";
+    case PrefetchContainer::LoadState::kFailedDeterminedHead:
+      return ostream << "FailedDeterminedHead";
+    case PrefetchContainer::LoadState::kCompleted:
+      return ostream << "Completed";
+    case PrefetchContainer::LoadState::kFailed:
+      return ostream << "Failed";
     case PrefetchContainer::LoadState::kFailedHeldback:
       return ostream << "FailedHeldback";
   }
