@@ -27,11 +27,14 @@
 #include "extensions/browser/extensions_browser_client.h"
 #include "extensions/browser/pref_names.h"
 #include "extensions/browser/pref_types.h"
+#include "extensions/buildflags/buildflags.h"
 #include "extensions/common/extension.h"
 #include "extensions/common/extension_features.h"
 #include "services/metrics/public/cpp/ukm_builders.h"
 #include "services/metrics/public/cpp/ukm_recorder.h"
 
+static_assert(BUILDFLAG(ENABLE_EXTENSIONS_CORE));
+
 namespace extensions {
 
 namespace {
@@ -156,21 +159,13 @@ MV2ExperimentStage CalculateCurrentExperimentStage() {
     return MV2ExperimentStage::kDisableWithReEnable;
   }
 
-  if (base::FeatureList::IsEnabled(
-          extensions_features::kExtensionManifestV2DeprecationWarning)) {
-    return MV2ExperimentStage::kWarning;
-  }
-
-  return MV2ExperimentStage::kNone;
+  return MV2ExperimentStage::kWarning;
 }
 
 // Returns the pref that stores whether the user has acknowledged the MV2
 // deprecation notice for a given extension in `experiment_stage`.
 PrefMap GetExtensionAcknowledgedPrefFor(MV2ExperimentStage experiment_stage) {
   switch (experiment_stage) {
-    case MV2ExperimentStage::kNone:
-      // There is no notice for this stage, thus it cannot be acknowledged.
-      NOTREACHED();
     case MV2ExperimentStage::kWarning:
       return kMV2DeprecationExtensionWarningAcknowledgedPref;
     case MV2ExperimentStage::kDisableWithReEnable:
@@ -185,9 +180,6 @@ PrefMap GetExtensionAcknowledgedPrefFor(MV2ExperimentStage experiment_stage) {
 PrefMap GetGlobalNoticeAcknowledgedPrefFor(
     MV2ExperimentStage experiment_stage) {
   switch (experiment_stage) {
-    case MV2ExperimentStage::kNone:
-      // There is no notice for this stage, thus it cannot be acknowledged.
-      NOTREACHED();
     case MV2ExperimentStage::kWarning:
       return kMV2DeprecationWarningAcknowledgedGloballyPref;
     case MV2ExperimentStage::kDisableWithReEnable:
@@ -206,7 +198,6 @@ bool ShouldDisableLegacyExtensions(MV2ExperimentStage stage) {
   }
 
   switch (stage) {
-    case MV2ExperimentStage::kNone:
     case MV2ExperimentStage::kWarning:
       return false;
     case MV2ExperimentStage::kDisableWithReEnable:
@@ -227,7 +218,6 @@ bool ShouldBlockLegacyExtensionEnableForStage(MV2ExperimentStage stage) {
   // We only block extension enablement in the `kUnsupported` phase.
   // (We use a switch just to ensure compile errors if we ever add a new phase.)
   switch (stage) {
-    case MV2ExperimentStage::kNone:
     case MV2ExperimentStage::kWarning:
     case MV2ExperimentStage::kDisableWithReEnable:
       return false;
@@ -258,7 +248,6 @@ bool ShouldBlockUnpackedExtensions(MV2ExperimentStage stage) {
 // given experiment `stage`.
 bool UserCanReEnableExtensionsForStage(MV2ExperimentStage stage) {
   switch (stage) {
-    case MV2ExperimentStage::kNone:
     case MV2ExperimentStage::kWarning:
     case MV2ExperimentStage::kDisableWithReEnable:
       return true;
@@ -276,7 +265,6 @@ ManifestV2ExperimentManager::ManifestV2ExperimentManager(
       // the `impact_checker_` because this class is a KeyedService that depends
       // on `ExtensionManagement`.
       impact_checker_(
-          experiment_stage_,
           ExtensionManagementFactory::GetForBrowserContext(browser_context)),
       browser_context_(browser_context) {
   registry_observation_.Observe(ExtensionRegistry::Get(browser_context));
@@ -373,10 +361,8 @@ bool ManifestV2ExperimentManager::ShouldBlockExtensionEnable(
 
 bool ManifestV2ExperimentManager::DidUserAcknowledgeNotice(
     const ExtensionId& extension_id) {
-  // There is no notice for kNone stage, thus it cannot be acknowledged.
   // The notice cannot be acknowledged in kUnsupported stage.
-  if (experiment_stage_ == MV2ExperimentStage::kNone ||
-      experiment_stage_ == MV2ExperimentStage::kUnsupported) {
+  if (experiment_stage_ == MV2ExperimentStage::kUnsupported) {
     return false;
   }
 
@@ -389,10 +375,8 @@ bool ManifestV2ExperimentManager::DidUserAcknowledgeNotice(
 
 void ManifestV2ExperimentManager::MarkNoticeAsAcknowledged(
     const ExtensionId& extension_id) {
-  // There is no notice for kNone stage, thus it cannot be acknowledged. The
-  // notice cannot be acknowledged in kUnsupported stage.
-  if (experiment_stage_ == MV2ExperimentStage::kNone ||
-      experiment_stage_ == MV2ExperimentStage::kUnsupported) {
+  // The notice cannot be acknowledged in kUnsupported stage.
+  if (experiment_stage_ == MV2ExperimentStage::kUnsupported) {
     return;
   }
 
@@ -401,21 +385,11 @@ void ManifestV2ExperimentManager::MarkNoticeAsAcknowledged(
 }
 
 bool ManifestV2ExperimentManager::DidUserAcknowledgeNoticeGlobally() {
-  // There is no notice for kNone stage, thus it cannot be acknowledged.
-  if (experiment_stage_ == MV2ExperimentStage::kNone) {
-    return false;
-  }
-
   PrefMap pref = GetGlobalNoticeAcknowledgedPrefFor(experiment_stage_);
   return extension_prefs()->GetPrefAsBoolean(pref);
 }
 
 void ManifestV2ExperimentManager::MarkNoticeAsAcknowledgedGlobally() {
-  // There is no notice for kNone stage, thus it cannot be acknowledged.
-  if (experiment_stage_ == MV2ExperimentStage::kNone) {
-    return;
-  }
-
   PrefMap pref = GetGlobalNoticeAcknowledgedPrefFor(experiment_stage_);
   extension_prefs()->SetBooleanPref(pref, true);
 }
