@@ -185,6 +185,7 @@ content::WebUIDataSource* CreateAndAddExtensionsSource(Profile* profile,
       {"itemDetailsBackButtonRoleDescription",
        IDS_EXTENSIONS_DETAILS_BACK_BUTTON_ARIA_ROLE_DESCRIPTION},
       {"itemErrors", IDS_EXTENSIONS_ITEM_ERRORS},
+      {"itemWarnings", IDS_EXTENSIONS_ITEM_WARNINGS},
       {"accessibilityErrorLine", IDS_EXTENSIONS_ACCESSIBILITY_ERROR_LINE},
       {"accessibilityErrorMultiLine",
        IDS_EXTENSIONS_ACCESSIBILITY_ERROR_MULTI_LINE},
@@ -392,6 +393,7 @@ content::WebUIDataSource* CreateAndAddExtensionsSource(Profile* profile,
       {"viewActivityLog", IDS_EXTENSIONS_VIEW_ACTIVITY_LOG},
       {"viewBackgroundPage", IDS_EXTENSIONS_BACKGROUND_PAGE},
       {"viewIncognito", IDS_EXTENSIONS_VIEW_INCOGNITO},
+      {"viewInDevTools", IDS_EXTENSIONS_VIEW_IN_DEVTOOLS},
       {"viewInactive", IDS_EXTENSIONS_VIEW_INACTIVE},
       {"viewIframe", IDS_EXTENSIONS_VIEW_IFRAME},
       {"viewServiceWorker", IDS_EXTENSIONS_SERVICE_WORKER_BACKGROUND},
@@ -399,15 +401,7 @@ content::WebUIDataSource* CreateAndAddExtensionsSource(Profile* profile,
       {"safetyCheckExtensionThreeDotDetails",
        IDS_EXTENSIONS_SC_THREEDOT_DETAILS},
       {"safetyCheckRemoveAll", IDS_EXTENSIONS_SC_REMOVE_ALL},
-
-// TODO(crbug.com/391777809): Make the message available on desktop android
-// without adding unused strings.
-#if BUILDFLAG(IS_ANDROID)
-      {"safetyHubHeader", IDS_OK /* placeholder to avoid crash */},
-#else
-      {"safetyHubHeader", IDS_SETTINGS_SAFETY_HUB},
-#endif  // BUILDFLAG(IS_ANDROID)
-
+      {"safetyHubHeader", IDS_EXTENSIONS_SAFETY_HUB_HEADER},
       {"safetyCheckRemoveButtonA11yLabel",
        IDS_EXTENSIONS_SC_REMOVE_BUTTON_A11Y_LABEL},
       {"safetyCheckOptionMenuA11yLabel",
@@ -492,13 +486,6 @@ content::WebUIDataSource* CreateAndAddExtensionsSource(Profile* profile,
       "safetyHubThreeDotDetails",
       base::FeatureList::IsEnabled(features::kSafetyHubThreeDotDetails));
 
-#if BUILDFLAG(IS_ANDROID)
-  source->AddResourcePath("images/product_logo.png",
-                          webui::CurrentChannelLogoResourceId());
-  // TODO(crbug.com/392777363): Clean these up with non-placeholder values.
-  source->AddInteger("MV2ExperimentStage", 0);
-  source->AddBoolean("MV2DeprecationNoticeDismissed", true);
-#else
   // MV2 deprecation.
   auto* mv2_experiment_manager = ManifestV2ExperimentManager::Get(profile);
   MV2ExperimentStage experiment_stage =
@@ -507,6 +494,10 @@ content::WebUIDataSource* CreateAndAddExtensionsSource(Profile* profile,
   source->AddBoolean(
       "MV2DeprecationNoticeDismissed",
       mv2_experiment_manager->DidUserAcknowledgeNoticeGlobally());
+
+#if BUILDFLAG(IS_ANDROID)
+  source->AddResourcePath("images/product_logo.png",
+                          webui::CurrentChannelLogoResourceId());
 #endif  // BUILDFLAG(IS_ANDROID)
 
 #if BUILDFLAG(IS_CHROMEOS)
