@@ -2,9 +2,10 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#include "chrome/browser/chrome_browser_interface_binders_webui_parts.h"
-
 #include "chrome/browser/actor/ui/actor_overlay_ui.h"
+#include "chrome/browser/chrome_browser_interface_binders_webui_parts.h"
+#include "chrome/browser/contextual_tasks/contextual_tasks.mojom.h"
+#include "chrome/browser/contextual_tasks/contextual_tasks_ui.h"
 #include "chrome/browser/history_clusters/history_clusters_service_factory.h"
 #include "chrome/browser/history_embeddings/history_embeddings_utils.h"
 #include "chrome/browser/new_tab_page/modules/file_suggestion/drive_suggestion.mojom.h"
@@ -17,6 +18,7 @@
 #include "chrome/browser/new_tab_page/new_tab_page_util.h"
 #include "chrome/browser/ui/lens/lens_overlay_untrusted_ui.h"
 #include "chrome/browser/ui/lens/lens_side_panel_untrusted_ui.h"
+#include "chrome/browser/ui/omnibox/omnibox_next_features.h"
 #include "chrome/browser/ui/ui_features.h"
 #include "chrome/browser/ui/views/side_panel/history/history_side_panel_coordinator.h"
 #include "chrome/browser/ui/webui/access_code_cast/access_code_cast.mojom.h"
@@ -40,6 +42,7 @@
 #include "chrome/browser/ui/webui/metrics_reporter/metrics_reporter_service.h"
 #include "chrome/browser/ui/webui/new_tab_footer/new_tab_footer.mojom.h"
 #include "chrome/browser/ui/webui/new_tab_footer/new_tab_footer_ui.h"
+#include "chrome/browser/ui/webui/new_tab_page/action_chips/action_chips.mojom.h"
 #include "chrome/browser/ui/webui/new_tab_page/composebox/variations/composebox_fieldtrial.h"
 #include "chrome/browser/ui/webui/new_tab_page/new_tab_page.mojom.h"
 #include "chrome/browser/ui/webui/new_tab_page/new_tab_page_ui.h"
@@ -53,6 +56,8 @@
 #include "chrome/browser/ui/webui/privacy_sandbox/privacy_sandbox_internals_ui.h"
 #include "chrome/browser/ui/webui/privacy_sandbox/private_state_tokens/private_state_tokens.mojom.h"
 #include "chrome/browser/ui/webui/privacy_sandbox/related_website_sets/related_website_sets.mojom.h"
+#include "chrome/browser/ui/webui/reload_button/reload_button.mojom.h"
+#include "chrome/browser/ui/webui/reload_button/reload_button_ui.h"
 #include "chrome/browser/ui/webui/search_engine_choice/search_engine_choice.mojom.h"  // nogncheck crbug.com/1125897
 #include "chrome/browser/ui/webui/search_engine_choice/search_engine_choice_ui.h"
 #include "chrome/browser/ui/webui/settings/settings_ui.h"
@@ -82,11 +87,13 @@
 #include "components/autofill/core/browser/ml_model/logging/autofill_ml_internals.mojom.h"
 #include "components/commerce/core/mojom/product_specifications.mojom.h"
 #include "components/commerce/core/mojom/shopping_service.mojom.h"  // nogncheck crbug.com/1125897
+#include "components/contextual_tasks/public/features.h"
 #include "components/data_sharing/public/features.h"
 #include "components/guest_contents/common/guest_contents.mojom.h"
 #include "components/history_clusters/core/history_clusters_service.h"
 #include "components/lens/lens_features.h"
 #include "components/omnibox/browser/searchbox.mojom.h"
+#include "components/omnibox/common/omnibox_features.h"
 #include "components/optimization_guide/core/optimization_guide_features.h"
 #include "components/page_image_service/mojom/page_image_service.mojom.h"
 #include "components/privacy_sandbox/privacy_sandbox_features.h"
@@ -203,10 +210,6 @@ void PopulateChromeWebUIFrameBindersPartsDesktop(
   RegisterWebUIControllerInterfaceBinder<downloads::mojom::PageHandlerFactory,
                                          DownloadsUI>(map);
 
-  RegisterWebUIControllerInterfaceBinder<
-      new_tab_page_third_party::mojom::PageHandlerFactory,
-      NewTabPageThirdPartyUI>(map);
-
   if (lens::features::IsLensOverlayEnabled()) {
     RegisterWebUIControllerInterfaceBinder<
         lens::mojom::LensSidePanelPageHandlerFactory,
@@ -249,11 +252,11 @@ void PopulateChromeWebUIFrameBindersPartsDesktop(
       ColorPipelineInternalsUI, UserEducationInternalsUI, ReadingListUI,
       TabSearchUI, WebuiGalleryUI, HistoryClustersSidePanelUI,
       ShoppingInsightsSidePanelUI, media_router::AccessCodeCastUI,
-      commerce::ProductSpecificationsUI, NewTabFooterUI>(map);
+      commerce::ProductSpecificationsUI>(map);
 
   RegisterWebUIControllerInterfaceBinder<
-      customize_buttons::mojom::CustomizeButtonsHandlerFactory, NewTabPageUI,
-      NewTabFooterUI>(map);
+      customize_buttons::mojom::CustomizeButtonsHandlerFactory, NewTabPageUI>(
+      map);
 
   RegisterWebUIControllerInterfaceBinder<
       new_tab_page::mojom::PageHandlerFactory, NewTabPageUI>(map);
@@ -264,12 +267,13 @@ void PopulateChromeWebUIFrameBindersPartsDesktop(
         ntp_promo::mojom::NtpPromoHandlerFactory, NewTabPageUI>(map);
   }
 
-  RegisterWebUIControllerInterfaceBinder<
-      new_tab_footer::mojom::NewTabFooterHandlerFactory, NewTabFooterUI>(map);
+  if (base::FeatureList::IsEnabled(ntp_features::kNtpNextFeatures)) {
+    RegisterWebUIControllerInterfaceBinder<
+        action_chips::mojom::ActionChipsHandlerFactory, NewTabPageUI>(map);
+  }
 
   RegisterWebUIControllerInterfaceBinder<
-      most_visited::mojom::MostVisitedPageHandlerFactory, NewTabPageUI,
-      NewTabPageThirdPartyUI>(map);
+      most_visited::mojom::MostVisitedPageHandlerFactory, NewTabPageUI>(map);
 
   if (HistorySidePanelCoordinator::IsSupported()) {
     RegisterWebUIControllerInterfaceBinder<history::mojom::PageHandler,
@@ -355,22 +359,21 @@ void PopulateChromeWebUIFrameBindersPartsDesktop(
   RegisterWebUIControllerInterfaceBinder<
       customize_color_scheme_mode::mojom::
           CustomizeColorSchemeModeHandlerFactory,
-      CustomizeChromeUI, settings::SettingsUI>(map);
+      CustomizeChromeUI>(map);
 
   RegisterWebUIControllerInterfaceBinder<
       theme_color_picker::mojom::ThemeColorPickerHandlerFactory,
       CustomizeChromeUI
 #if !BUILDFLAG(IS_CHROMEOS)
       ,
-      ProfileCustomizationUI, settings::SettingsUI
+      ProfileCustomizationUI
 #endif  // !BUILDFLAG(IS_CHROMEOS)
       >(map);
 
   RegisterWebUIControllerInterfaceBinder<
       help_bubble::mojom::HelpBubbleHandlerFactory, UserEducationInternalsUI,
-      settings::SettingsUI, ReadingListUI, NewTabPageUI, CustomizeChromeUI,
-      PasswordManagerUI, HistoryUI, lens::LensOverlayUntrustedUI,
-      lens::LensSidePanelUntrustedUI
+      ReadingListUI, NewTabPageUI, CustomizeChromeUI, PasswordManagerUI,
+      HistoryUI, lens::LensOverlayUntrustedUI, lens::LensSidePanelUntrustedUI
 #if !BUILDFLAG(IS_CHROMEOS)
       ,
       ProfilePickerUI
@@ -423,12 +426,6 @@ void PopulateChromeWebUIFrameBindersPartsDesktop(
         file_suggestion::mojom::MicrosoftFilesPageHandler, NewTabPageUI>(map);
   }
 
-  if (ntp_composebox::IsNtpComposeboxEnabled(Profile::FromBrowserContext(
-          render_frame_host->GetProcess()->GetBrowserContext()))) {
-    RegisterWebUIControllerInterfaceBinder<
-        composebox::mojom::PageHandlerFactory, NewTabPageUI>(map);
-  }
-
   RegisterWebUIControllerInterfaceBinder<
       reading_list::mojom::PageHandlerFactory, ReadingListUI>(map);
   RegisterWebUIControllerInterfaceBinder<
@@ -525,6 +522,32 @@ void PopulateChromeWebUIFrameBindersPartsDesktop(
   RegisterWebUIControllerInterfaceBinder<
       guest_contents::mojom::GuestContentsHost, WebUIBrowserUI>(map);
 
+  const bool is_ntp_composebox_enabled =
+      ntp_composebox::IsNtpComposeboxEnabled(Profile::FromBrowserContext(
+          render_frame_host->GetProcess()->GetBrowserContext()));
+  const bool is_omnibox_aim_popup_enabled = omnibox::IsAimPopupFeatureEnabled();
+  const bool is_contextual_tasks_enabled =
+      base::FeatureList::IsEnabled(contextual_tasks::kContextualTasks);
+
+  if (is_contextual_tasks_enabled) {
+    RegisterWebUIControllerInterfaceBinder<
+        contextual_tasks::mojom::PageHandlerFactory, ContextualTasksUI>(map);
+  }
+
+  // Registering bindings for all WebUIControllers, even if only one of the
+  // features is enabled, as it is too cumbersome and not scalable to account
+  // for all combinations of feature flags here.
+  // TODO(crbug.com/452983498): This should be fixed by following the
+  // registry.ForWebUI() pattern used in
+  // PopulateChromeWebUIFrameInterfaceBrokersUntrustedPartsDesktop below which
+  // eliminates the need to account for feature flag combinations.
+  if (is_ntp_composebox_enabled || is_omnibox_aim_popup_enabled ||
+      is_contextual_tasks_enabled) {
+    RegisterWebUIControllerInterfaceBinder<
+        composebox::mojom::PageHandlerFactory, NewTabPageUI, ContextualTasksUI,
+        OmniboxPopupUI>(map);
+  }
+
 #if BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX)
   RegisterWebUIControllerInterfaceBinder<
       app_management::mojom::PageHandlerFactory, WebAppSettingsUI>(map);
@@ -543,6 +566,34 @@ void PopulateChromeWebUIFrameBindersPartsDesktop(
 #endif
 }
 
+void PopulateChromeWebUIFrameInterfaceBrokersTrustedPartsDesktop(
+    content::WebUIBrowserInterfaceBrokerRegistry& registry) {
+  if (base::FeatureList::IsEnabled(ntp_features::kNtpFooter)) {
+    registry.ForWebUI<NewTabFooterUI>()
+        .Add<color_change_listener::mojom::PageHandler>()
+        .Add<customize_buttons::mojom::CustomizeButtonsHandlerFactory>()
+        .Add<new_tab_footer::mojom::NewTabFooterHandlerFactory>()
+        .Add<help_bubble::mojom::HelpBubbleHandlerFactory>();
+  }
+
+  registry.ForWebUI<NewTabPageThirdPartyUI>()
+      .Add<most_visited::mojom::MostVisitedPageHandlerFactory>()
+      .Add<new_tab_page_third_party::mojom::PageHandlerFactory>();
+
+  registry
+      .ForWebUI<settings::SettingsUI>()
+#if !BUILDFLAG(IS_CHROMEOS)
+      .Add<theme_color_picker::mojom::ThemeColorPickerHandlerFactory>()
+#endif  // !BUILDFLAG(IS_CHROMEOS)
+      .Add<customize_color_scheme_mode::mojom::
+               CustomizeColorSchemeModeHandlerFactory>()
+      .Add<help_bubble::mojom::HelpBubbleHandlerFactory>();
+
+  // TODO(crbug.com/452983498): Migrate all remaining
+  // RegisterWebUIControllerInterfaceBinder calls to registry.ForWebUI().Add()
+  // calls.
+}
+
 void PopulateChromeWebUIFrameInterfaceBrokersUntrustedPartsDesktop(
     content::WebUIBrowserInterfaceBrokerRegistry& registry) {
   if (lens::features::IsLensOverlayEnabled()) {
@@ -586,6 +637,13 @@ void PopulateChromeWebUIFrameInterfaceBrokersUntrustedPartsDesktop(
         .Add<tabs_api::mojom::TabStripService>()
         .Add<tracked_element::mojom::TrackedElementHandler>();
   }
+
+  if (features::IsWebUIReloadButtonEnabled()) {
+    registry.ForWebUI<ReloadButtonUI>()
+        .Add<color_change_listener::mojom::PageHandler>()
+        .Add<reload_button::mojom::PageHandlerFactory>()
+        .Add<metrics_reporter::mojom::PageMetricsHost>();
+  }
 }
 
 }  // namespace chrome::internal
