@@ -4,9 +4,13 @@
 
 #include "chrome/browser/pdf/pdf_extension_util.h"
 
+#include <array>
 #include <string>
+#include <vector>
 
+#include "base/containers/contains.h"
 #include "base/feature_list.h"
+#include "base/notreached.h"
 #include "base/strings/string_util.h"
 #include "base/values.h"
 #include "build/branding_buildflags.h"
@@ -14,8 +18,10 @@
 #include "chrome/browser/browser_process.h"
 #include "chrome/browser/pdf/pdf_viewer_stream_manager.h"
 #include "chrome/common/extensions/api/pdf_viewer_private.h"
+#include "chrome/common/url_constants.h"
 #include "chrome/grit/browser_resources.h"
 #include "chrome/grit/generated_resources.h"
+#include "chrome/grit/pdf_resources_map.h"
 #include "components/strings/grit/components_strings.h"
 #include "components/zoom/page_zoom_constants.h"
 #include "content/public/browser/browser_context.h"
@@ -36,11 +42,14 @@
 #include "chromeos/ash/components/browser_context_helper/browser_context_types.h"
 #endif  // BUILDFLAG(IS_CHROMEOS)
 
-#if BUILDFLAG(IS_CHROMEOS) || BUILDFLAG(ENABLE_PDF_INK2)
-#include "chrome/browser/profiles/profile.h"
+#if BUILDFLAG(ENABLE_PDF_INK2)
 #include "chrome/common/pref_names.h"
 #include "components/prefs/pref_service.h"
-#endif  // BUILDFLAG(IS_CHROMEOS) || BUILDFLAG(ENABLE_PDF_INK2)
+#endif  // BUILDFLAG(ENABLE_PDF_INK2)
+
+#if BUILDFLAG(ENABLE_PDF_INK2) || BUILDFLAG(ENABLE_PDF_SAVE_TO_DRIVE)
+#include "chrome/browser/profiles/profile.h"
+#endif  // BUILDFLAG(ENABLE_PDF_INK2) || BUILDFLAG(ENABLE_PDF_SAVE_TO_DRIVE)
 
 namespace pdf_extension_util {
 
@@ -49,9 +58,9 @@ namespace {
 // Tags in the manifest to be replaced.
 const char kNameTag[] = "<NAME>";
 
-// Adds strings that are used both by the stand-alone PDF Viewer and the Print
+// Gets strings that are used both by the stand-alone PDF Viewer and the Print
 // Preview PDF Viewer.
-void AddCommonStrings(base::Value::Dict* dict) {
+base::Value::Dict GetCommonStrings() {
   static constexpr webui::LocalizedString kPdfResources[] = {
       {"errorDialogTitle", IDS_PDF_ERROR_DIALOG_TITLE},
       {"pageLoadFailed", IDS_PDF_PAGE_LOAD_FAILED},
@@ -63,16 +72,19 @@ void AddCommonStrings(base::Value::Dict* dict) {
       {"tooltipZoomOut", IDS_PDF_TOOLTIP_ZOOM_OUT},
       {"twoUpViewEnable", IDS_PDF_TWO_UP_VIEW_ENABLE},
   };
-  for (const auto& resource : kPdfResources)
-    dict->Set(resource.name, l10n_util::GetStringUTF16(resource.id));
+  base::Value::Dict dict;
+  for (const auto& resource : kPdfResources) {
+    dict.Set(resource.name, l10n_util::GetStringUTF16(resource.id));
+  }
 
-  dict->Set("presetZoomFactors", zoom::GetPresetZoomFactorsAsJSON());
-  dict->Set("pdfOopifEnabled",
-            chrome_pdf::features::IsOopifPdfEnabled() ? "pdfOopifEnabled" : "");
+  dict.Set("presetZoomFactors", zoom::GetPresetZoomFactorsAsJSON());
+  dict.Set("pdfOopifEnabled",
+           chrome_pdf::features::IsOopifPdfEnabled() ? "pdfOopifEnabled" : "");
+  return dict;
 }
 
-// Adds strings that are used only by the stand-alone PDF Viewer.
-void AddPdfViewerStrings(base::Value::Dict* dict) {
+// Gets strings that are used only by the stand-alone PDF Viewer.
+base::Value::Dict GetPdfViewerStrings() {
   static constexpr webui::LocalizedString kPdfResources[] = {
       {"annotationsShowToggle", IDS_PDF_ANNOTATIONS_SHOW_TOGGLE},
       {"bookmarks", IDS_PDF_BOOKMARKS},
@@ -80,7 +92,6 @@ void AddPdfViewerStrings(base::Value::Dict* dict) {
       {"downloadEdited", IDS_PDF_DOWNLOAD_EDITED},
       {"downloadOriginal", IDS_PDF_DOWNLOAD_ORIGINAL},
       {"labelPageNumber", IDS_PDF_LABEL_PAGE_NUMBER},
-      {"menu", IDS_MENU},
       {"moreActions", IDS_DOWNLOAD_MORE_ACTIONS},
       {"oversizeAttachmentWarning", IDS_PDF_OVERSIZE_ATTACHMENT_WARNING},
       {"passwordDialogTitle", IDS_PDF_PASSWORD_DIALOG_TITLE},
@@ -111,6 +122,7 @@ void AddPdfViewerStrings(base::Value::Dict* dict) {
       {"rotationStateLabel180", IDS_PDF_ROTATION_STATE_LABEL_180},
       {"rotationStateLabel270", IDS_PDF_ROTATION_STATE_LABEL_270},
       {"searchifyInProgress", IDS_PDF_SEARCHIFY_IN_PROGRESS},
+      {"sidebarLabel", IDS_PDF_SIDEBAR_LABEL},
       {"thumbnailPageAriaLabel", IDS_PDF_THUMBNAIL_PAGE_ARIA_LABEL},
       {"tooltipAttachments", IDS_PDF_TOOLTIP_ATTACHMENTS},
       {"tooltipDocumentOutline", IDS_PDF_TOOLTIP_DOCUMENT_OUTLINE},
@@ -121,63 +133,48 @@ void AddPdfViewerStrings(base::Value::Dict* dict) {
       {"tooltipThumbnails", IDS_PDF_TOOLTIP_THUMBNAILS},
       {"zoomTextInputAriaLabel", IDS_PDF_ZOOM_TEXT_INPUT_ARIA_LABEL},
 #if BUILDFLAG(ENABLE_PDF_SAVE_TO_DRIVE)
+      {"saveToDriveDialogCancelUploadButtonLabel",
+       IDS_SAVE_TO_DRIVE_DIALOG_CANCEL_UPLOAD_BUTTON_LABEL},
+      {"saveToDriveDialogConnectionErrorMessage",
+       IDS_SAVE_TO_DRIVE_DIALOG_CONNECTION_ERROR_MESSAGE},
+      {"saveToDriveDialogErrorTitle", IDS_SAVE_TO_DRIVE_DIALOG_ERROR_TITLE},
+      {"saveToDriveDialogManageStorageButtonLabel",
+       IDS_SAVE_TO_DRIVE_DIALOG_MANAGE_STORAGE_BUTTON_LABEL},
+      {"saveToDriveDialogOpenInDriveButtonLabel",
+       IDS_SAVE_TO_DRIVE_DIALOG_OPEN_IN_DRIVE_BUTTON_LABEL},
+      {"saveToDriveDialogRetryButtonLabel",
+       IDS_SAVE_TO_DRIVE_DIALOG_RETRY_BUTTON_LABEL},
+      {"saveToDriveDialogSessionTimeoutErrorMessage",
+       IDS_SAVE_TO_DRIVE_DIALOG_SESSION_TIMEOUT_ERROR_MESSAGE},
+      {"saveToDriveDialogStorageFullErrorMessage",
+       IDS_SAVE_TO_DRIVE_DIALOG_STORAGE_FULL_ERROR_MESSAGE},
+      {"saveToDriveDialogSuccessMessage",
+       IDS_SAVE_TO_DRIVE_DIALOG_SUCCESS_MESSAGE},
+      {"saveToDriveDialogSuccessTitle", IDS_SAVE_TO_DRIVE_DIALOG_SUCCESS_TITLE},
+      {"saveToDriveDialogUnknownErrorMessage",
+       IDS_SAVE_TO_DRIVE_DIALOG_UNKNOWN_ERROR_MESSAGE},
+      {"saveToDriveDialogUploadingTitle",
+       IDS_SAVE_TO_DRIVE_DIALOG_UPLOADING_TITLE},
       {"tooltipSaveToDrive", IDS_PDF_TOOLTIP_SAVE_TO_DRIVE},
 #endif  // BUILDFLAG(ENABLE_PDF_SAVE_TO_DRIVE)
-#if BUILDFLAG(IS_CHROMEOS) || BUILDFLAG(ENABLE_PDF_INK2)
-      {"tooltipAnnotate", IDS_PDF_ANNOTATION_ANNOTATE},
-      {"annotationDocumentTooLarge", IDS_PDF_ANNOTATION_DOCUMENT_TOO_LARGE},
-      {"annotationDocumentProtected", IDS_PDF_ANNOTATION_DOCUMENT_PROTECTED},
-      {"annotationDocumentRotated", IDS_PDF_ANNOTATION_DOCUMENT_ROTATED},
-      {"annotationEditInDefaultView", IDS_PDF_ANNOTATION_EDIT_IN_DEFAULT_VIEW},
-      {"annotationResetRotate", IDS_PDF_ANNOTATION_RESET_ROTATE},
-      {"annotationResetTwoPageView", IDS_PDF_ANNOTATION_RESET_TWO_PAGE_VIEW},
-      {"annotationResetRotateAndTwoPageView",
-       IDS_PDF_ANNOTATION_RESET_ROTATE_AND_TWO_PAGE_VIEW},
+#if BUILDFLAG(ENABLE_PDF_INK2)
       {"cancelButton", IDS_CANCEL},
       {"annotationPen", IDS_PDF_ANNOTATION_PEN},
       {"annotationHighlighter", IDS_PDF_ANNOTATION_HIGHLIGHTER},
       {"annotationEraser", IDS_PDF_ANNOTATION_ERASER},
       {"annotationUndo", IDS_PDF_ANNOTATION_UNDO},
       {"annotationRedo", IDS_PDF_ANNOTATION_REDO},
-      {"annotationExpand", IDS_PDF_ANNOTATION_EXPAND},
       {"annotationColorBlack", IDS_PDF_ANNOTATION_COLOR_BLACK},
       {"annotationColorRed", IDS_PDF_ANNOTATION_COLOR_RED},
       {"annotationColorYellow", IDS_PDF_ANNOTATION_COLOR_YELLOW},
       {"annotationColorGreen", IDS_PDF_ANNOTATION_COLOR_GREEN},
-      {"annotationColorCyan", IDS_PDF_ANNOTATION_COLOR_CYAN},
-      {"annotationColorPurple", IDS_PDF_ANNOTATION_COLOR_PURPLE},
-      {"annotationColorBrown", IDS_PDF_ANNOTATION_COLOR_BROWN},
       {"annotationColorWhite", IDS_PDF_ANNOTATION_COLOR_WHITE},
-      {"annotationColorCrimson", IDS_PDF_ANNOTATION_COLOR_CRIMSON},
-      {"annotationColorAmber", IDS_PDF_ANNOTATION_COLOR_AMBER},
-      {"annotationColorAvocadoGreen", IDS_PDF_ANNOTATION_COLOR_AVOCADO_GREEN},
-      {"annotationColorCobaltBlue", IDS_PDF_ANNOTATION_COLOR_COBALT_BLUE},
-      {"annotationColorDeepPurple", IDS_PDF_ANNOTATION_COLOR_DEEP_PURPLE},
-      {"annotationColorDarkBrown", IDS_PDF_ANNOTATION_COLOR_DARK_BROWN},
-      {"annotationColorDarkGrey", IDS_PDF_ANNOTATION_COLOR_DARK_GREY},
-      {"annotationColorHotPink", IDS_PDF_ANNOTATION_COLOR_HOT_PINK},
       {"annotationColorOrange", IDS_PDF_ANNOTATION_COLOR_ORANGE},
-      {"annotationColorLime", IDS_PDF_ANNOTATION_COLOR_LIME},
       {"annotationColorBlue", IDS_PDF_ANNOTATION_COLOR_BLUE},
-      {"annotationColorViolet", IDS_PDF_ANNOTATION_COLOR_VIOLET},
-      {"annotationColorTeal", IDS_PDF_ANNOTATION_COLOR_TEAL},
       {"annotationColorLightGrey", IDS_PDF_ANNOTATION_COLOR_LIGHT_GREY},
-      {"annotationColorLightPink", IDS_PDF_ANNOTATION_COLOR_LIGHT_PINK},
       {"annotationColorLightOrange", IDS_PDF_ANNOTATION_COLOR_LIGHT_ORANGE},
       {"annotationColorLightGreen", IDS_PDF_ANNOTATION_COLOR_LIGHT_GREEN},
       {"annotationColorLightBlue", IDS_PDF_ANNOTATION_COLOR_LIGHT_BLUE},
-      {"annotationColorLavender", IDS_PDF_ANNOTATION_COLOR_LAVENDER},
-      {"annotationColorLightTeal", IDS_PDF_ANNOTATION_COLOR_LIGHT_TEAL},
-      {"annotationSize1", IDS_PDF_ANNOTATION_SIZE1},
-      {"annotationSize2", IDS_PDF_ANNOTATION_SIZE2},
-      {"annotationSize3", IDS_PDF_ANNOTATION_SIZE3},
-      {"annotationSize4", IDS_PDF_ANNOTATION_SIZE4},
-      {"annotationSize8", IDS_PDF_ANNOTATION_SIZE8},
-      {"annotationSize12", IDS_PDF_ANNOTATION_SIZE12},
-      {"annotationSize16", IDS_PDF_ANNOTATION_SIZE16},
-      {"annotationSize20", IDS_PDF_ANNOTATION_SIZE20},
-#endif  // BUILDFLAG(IS_CHROMEOS) || BUILDFLAG(ENABLE_PDF_INK2)
-#if BUILDFLAG(ENABLE_PDF_INK2)
       {"ink2Draw", IDS_PDF_INK2_DRAW},
       {"ink2Tool", IDS_PDF_INK2_ANNOTATION_TOOL},
       {"ink2Size", IDS_PDF_INK2_ANNOTATION_SIZE},
@@ -225,17 +222,20 @@ void AddPdfViewerStrings(base::Value::Dict* dict) {
       {"ink2TextColorCyan3", IDS_PDF_INK2_ANNOTATION_COLOR_CYAN_3},
 #endif  // BUILDFLAG(ENABLE_PDF_INK2)
   };
-  for (const auto& resource : kPdfResources)
-    dict->Set(resource.name, l10n_util::GetStringUTF16(resource.id));
+  base::Value::Dict dict;
+  for (const auto& resource : kPdfResources) {
+    dict.Set(resource.name, l10n_util::GetStringUTF16(resource.id));
+  }
 
-#if BUILDFLAG(IS_CHROMEOS) || BUILDFLAG(ENABLE_PDF_INK2)
+#if BUILDFLAG(ENABLE_PDF_INK2)
   std::u16string edit_string = l10n_util::GetStringUTF16(IDS_EDIT);
   std::erase(edit_string, '&');
-  dict->Set("editButton", edit_string);
-#endif  // BUILDFLAG(IS_CHROMEOS) || BUILDFLAG(ENABLE_PDF_INK2)
+  dict.Set("editButton", edit_string);
+#endif  // BUILDFLAG(ENABLE_PDF_INK2)
 
   webui::SetLoadTimeDataDefaults(g_browser_process->GetApplicationLocale(),
-                                 dict);
+                                 &dict);
+  return dict;
 }
 
 bool IsPrintingEnabled(content::BrowserContext* context) {
@@ -246,20 +246,14 @@ bool IsPrintingEnabled(content::BrowserContext* context) {
 #endif  // BUILDFLAG(IS_CHROMEOS)
 }
 
-#if BUILDFLAG(IS_CHROMEOS) || BUILDFLAG(ENABLE_PDF_INK2)
+#if BUILDFLAG(ENABLE_PDF_INK2)
 bool IsPdfAnnotationsEnabledByPolicy(content::BrowserContext* context) {
   PrefService* prefs =
       context ? Profile::FromBrowserContext(context)->GetPrefs() : nullptr;
   return !prefs || !prefs->IsManagedPreference(prefs::kPdfAnnotationsEnabled) ||
          prefs->GetBoolean(prefs::kPdfAnnotationsEnabled);
 }
-#endif  // BUILDFLAG(IS_CHROMEOS) || BUILDFLAG(ENABLE_PDF_INK2)
-
-#if BUILDFLAG(IS_CHROMEOS)
-bool IsPdfInk1AnnotationsEnabled(content::BrowserContext* context) {
-  return IsPdfAnnotationsEnabledByPolicy(context);
-}
-#endif  // BUILDFLAG(IS_CHROMEOS)
+#endif  // BUILDFLAG(ENABLE_PDF_INK2)
 
 #if BUILDFLAG(ENABLE_PDF_INK2)
 bool IsPdfInk2AnnotationsEnabled(content::BrowserContext* context) {
@@ -287,48 +281,88 @@ std::string GetManifest() {
   return manifest_contents;
 }
 
-void AddStrings(PdfViewerContext context, base::Value::Dict* dict) {
-  AddCommonStrings(dict);
+base::Value::Dict GetStrings(PdfViewerContext context) {
+  base::Value::Dict dict = GetCommonStrings();
   if (context == PdfViewerContext::kPdfViewer ||
       context == PdfViewerContext::kAll) {
-    AddPdfViewerStrings(dict);
+    dict.Merge(GetPdfViewerStrings());
   }
   if (context == PdfViewerContext::kPrintPreview ||
       context == PdfViewerContext::kAll) {
     // Nothing to do yet, since there are no PrintPreview-only strings.
   }
+  return dict;
 }
 
-void AddAdditionalData(content::BrowserContext* context,
-                       base::Value::Dict* dict) {
+base::Value::Dict GetAdditionalData(content::BrowserContext* context) {
   // NOTE: This function should not include any data used for $i18n{}
-  // replacements. The i18n string resources should be added using AddStrings()
+  // replacements. The i18n string resources should be added using GetStrings()
   // above instead.
-  dict->Set("printingEnabled", IsPrintingEnabled(context));
-
-#if BUILDFLAG(IS_CHROMEOS)
-  dict->Set("pdfInk1AnnotationsEnabled", IsPdfInk1AnnotationsEnabled(context));
-#endif
+  base::Value::Dict dict;
+  dict.Set("printingEnabled", IsPrintingEnabled(context));
 
 #if BUILDFLAG(ENABLE_PDF_INK2)
   const bool use_ink2 = IsPdfInk2AnnotationsEnabled(context);
-  dict->Set("pdfInk2Enabled", use_ink2);
-  dict->Set("pdfTextAnnotationsEnabled",
-            use_ink2 && chrome_pdf::features::kPdfInk2TextAnnotations.Get());
+  dict.Set("pdfInk2Enabled", use_ink2);
+  dict.Set("pdfTextAnnotationsEnabled",
+           use_ink2 && chrome_pdf::features::kPdfInk2TextAnnotations.Get());
 #endif  // BUILDFLAG(ENABLE_PDF_INK2)
-  dict->Set("pdfGetSaveDataInBlocks",
-            chrome_pdf::features::IsPdfGetSaveDataInBlocksEnabled());
-  dict->Set("pdfUseShowSaveFilePicker",
-            base::FeatureList::IsEnabled(
-                chrome_pdf::features::kPdfUseShowSaveFilePicker));
-  dict->Set(
+  dict.Set("pdfGetSaveDataInBlocks",
+           base::FeatureList::IsEnabled(
+               chrome_pdf::features::kPdfGetSaveDataInBlocks));
+  dict.Set("pdfUseShowSaveFilePicker",
+           base::FeatureList::IsEnabled(
+               chrome_pdf::features::kPdfUseShowSaveFilePicker));
+  dict.Set(
       "pdfSearchifySaveEnabled",
       base::FeatureList::IsEnabled(chrome_pdf::features::kPdfSearchifySave));
 
 #if BUILDFLAG(ENABLE_PDF_SAVE_TO_DRIVE)
-  dict->Set("pdfSaveToDrive", base::FeatureList::IsEnabled(
-                                  chrome_pdf::features::kPdfSaveToDrive));
+  const bool save_to_drive_enabled =
+      base::FeatureList::IsEnabled(chrome_pdf::features::kPdfSaveToDrive) &&
+      !Profile::FromBrowserContext(context)->IsOffTheRecord();
+  dict.Set("pdfSaveToDrive", save_to_drive_enabled);
+  dict.Set("pdfSaveToDriveHelpCenterURL",
+           chrome::kPdfViewerSaveToDriveHelpCenterURL);
 #endif
+  return dict;
+}
+
+std::vector<webui::ResourcePath> GetResources(PdfViewerContext context) {
+  static constexpr auto kExcludeFromPdfViewer =
+      std::to_array<std::string_view>({
+          "pdf/index_print.html",
+          "pdf/main_print.js",
+          "pdf/pdf_print_wrapper.js",
+      });
+  static constexpr auto kExcludeFromPrintPreview =
+      std::to_array<std::string_view>({
+          "pdf/index.html",
+          "pdf/main.js",
+          "pdf/pdf_viewer_wrapper.js",
+      });
+  base::span<const std::string_view> exclusions;
+
+  switch (context) {
+    case PdfViewerContext::kPdfViewer:
+      exclusions = kExcludeFromPdfViewer;
+      break;
+    case PdfViewerContext::kPrintPreview:
+      exclusions = kExcludeFromPrintPreview;
+      break;
+    default:
+      NOTREACHED();
+  }
+
+  std::vector<webui::ResourcePath> resources;
+  resources.reserve(std::size(kPdfResources));
+  for (const webui::ResourcePath& resource : kPdfResources) {
+    if (base::Contains(exclusions, resource.path)) {
+      continue;
+    }
+    resources.push_back(resource);
+  }
+  return resources;
 }
 
 bool MaybeDispatchSaveEvent(content::RenderFrameHost* embedder_host) {
