@@ -25,7 +25,6 @@
 #include "base/trace_event/trace_event.h"
 #include "build/build_config.h"
 #include "chrome/common/chrome_constants.h"
-#include "chrome/common/chrome_features.h"
 #include "chrome/common/chrome_isolated_world_ids.h"
 #include "chrome/common/chrome_switches.h"
 #include "chrome/common/open_search_description_document_handler.mojom.h"
@@ -61,6 +60,7 @@
 #include "third_party/blink/public/web/web_element.h"
 #include "third_party/blink/public/web/web_frame_content_dumper.h"
 #include "third_party/blink/public/web/web_local_frame.h"
+#include "third_party/blink/public/web/web_local_frame_client.h"
 #include "third_party/blink/public/web/web_node.h"
 #include "third_party/blink/public/web/web_security_policy.h"
 #include "third_party/blink/public/web/web_view.h"
@@ -249,10 +249,23 @@ void ChromeRenderFrameObserver::ReadyToCommitNavigation(
 }
 
 void ChromeRenderFrameObserver::DidSetPageLifecycleState(
-    bool restoring_from_bfcache) {
-  if (restoring_from_bfcache && translate_agent_) {
+    blink::BFCacheStateChange bfcache_change) {
+  if (bfcache_change == blink::BFCacheStateChange::kRestoredFromBFCache &&
+      translate_agent_) {
     translate_agent_->RenewPageRegistration();
   }
+#if !BUILDFLAG(IS_ANDROID)
+  if (bfcache_change == blink::BFCacheStateChange::kStoredToBFCache) {
+    // Reset actor state if entering the BFCache
+    page_stability_monitor_.reset();
+    tool_executor_.reset();
+
+    // Flush any remaining log entries which may have been added in the
+    // destructors above. Don't reset the actor journal since it is only created
+    // from the constructor.
+    actor_journal_->SendLogBuffer();
+  }
+#endif
 }
 
 void ChromeRenderFrameObserver::DidFinishLoad() {
@@ -609,12 +622,6 @@ void ChromeRenderFrameObserver::LoadBlockedPlugins(
 #endif  // BUILDFLAG(ENABLE_PLUGINS)
 }
 
-void ChromeRenderFrameObserver::SetSupportsDraggableRegions(
-    bool supports_draggable_regions) {
-  render_frame()->GetWebView()->SetSupportsDraggableRegions(
-      supports_draggable_regions);
-}
-
 void ChromeRenderFrameObserver::SetShouldDeferMediaLoad(bool should_defer) {
   prerender::SetShouldDeferMediaLoad(render_frame(), should_defer);
 }
@@ -640,11 +647,6 @@ void ChromeRenderFrameObserver::CreatePageStabilityMonitor(
     mojo::PendingReceiver<actor::mojom::PageStabilityMonitor> monitor,
     const actor::TaskId& task_id,
     bool supports_paint_stability) {
-  if (features::kActorGeneralPageStabilityMode.Get() ==
-      features::ActorGeneralPageStabilityMode::kDisabled) {
-    return;
-  }
-
   page_stability_monitor_ = std::make_unique<actor::PageStabilityMonitor>(
       *render_frame(), supports_paint_stability, task_id, *actor_journal_);
   page_stability_monitor_->Bind(std::move(monitor));
