@@ -187,7 +187,8 @@ void AutofillManager::OnLanguageDetermined(
 
   // Wait for ongoing parsing operations to finish, so `form_structures_` is
   // up to date.
-  AfterParsingFinishes(base::BindOnce([](base::WeakPtr<AutofillManager> self) {
+  AfterParsingFinishesDeprecated(base::BindOnce([](base::WeakPtr<
+                                                    AutofillManager> self) {
     if (!self) {
       return;
     }
@@ -313,7 +314,7 @@ void AutofillManager::OnFormsParsed(const std::vector<FormData>& forms) {
     // server response is processed, to ensure server predictions are not lost.
     client().GetCrowdsourcingManager().StartQueryRequest(
         queryable_forms, driver().GetIsolationInfo(),
-        AfterParsingFinishes(base::BindOnce(
+        AfterParsingFinishesDeprecated(base::BindOnce(
             &AutofillManager::OnLoadedServerPredictions, GetWeakPtr())));
   }
 }
@@ -416,7 +417,9 @@ void AutofillManager::OnFocusOnFormField(const FormData& form,
 }
 
 void AutofillManager::OnFocusOnNonFormField() {
+  NotifyObservers(&Observer::OnBeforeFocusOnNonFormField);
   OnFocusOnNonFormFieldImpl();
+  NotifyObservers(&Observer::OnAfterFocusOnNonFormField);
 }
 
 void AutofillManager::OnDidEndTextFieldEditing() {
@@ -551,11 +554,11 @@ AutofillManager::GetServerPredictionsForForm(
 }
 
 base::flat_map<FieldGlobalId, FieldType>
-AutofillManager::GetHeursticPredictionForForm(
+AutofillManager::GetHeuristicPredictionForForm(
     HeuristicSource source,
     FormGlobalId form_id,
     const std::vector<FieldGlobalId>& field_ids) const {
-  FormStructure* cached_form = FindCachedFormById(form_id);
+  const FormStructure* const cached_form = FindCachedFormById(form_id);
   if (!cached_form) {
     return {};
   }
@@ -871,6 +874,28 @@ void AutofillManager::RunMlModels(
 }
 #endif  // BUILDFLAG(BUILD_WITH_TFLITE_LIB)
 
+// TODO(crbug.com/448144129): Remove once `kAutofillSynchronousAfterParsing`
+// can be cleaned up.
+template <typename... Args>
+base::OnceCallback<void(Args...)>
+AutofillManager::AfterParsingFinishesDeprecated(
+    base::OnceCallback<void(Args...)> callback) {
+  if (base::FeatureList::IsEnabled(
+          features::kAutofillSynchronousAfterParsing)) {
+    return callback;
+  }
+  return base::BindOnce(
+      [](base::WeakPtr<AutofillManager> self,
+         base::OnceCallback<void(Args...)> callback, Args... args) {
+        if (self) {
+          self->parsing_task_runner_->PostTaskAndReply(
+              FROM_HERE, base::DoNothing(),
+              base::BindOnce(std::move(callback), std::forward<Args>(args)...));
+        }
+      },
+      GetWeakPtr(), std::move(callback));
+}
+
 void AutofillManager::OnLoadedServerPredictions(
     std::optional<AutofillCrowdsourcingManager::QueryResponse> response) {
   absl::Cleanup on_after_loaded_server_predictions = [this] {
@@ -917,8 +942,7 @@ void AutofillManager::OnLoadedServerPredictions(
 
   for (const raw_ptr<FormStructure, VectorExperimental> form : queried_forms) {
     form->RationalizeAndAssignSections(client().GetVariationConfigCountryCode(),
-                                       GetCurrentPageLanguage(), log_manager(),
-                                       /*legacy_order=*/true);
+                                       GetCurrentPageLanguage(), log_manager());
 
     autofill_metrics::LogQualityMetricsBasedOnAutocomplete(
         *form, client().GetFormInteractionsUkmLogger(),
