@@ -35,6 +35,7 @@
 #include "components/permissions/permission_uma_util.h"
 #include "components/permissions/permission_util.h"
 #include "components/safe_browsing/content/browser/notification_content_detection/notification_content_detection_constants.h"
+#include "components/safe_browsing/core/browser/safe_browsing_metrics_collector.h"
 #include "components/safe_browsing/core/common/features.h"
 #include "components/site_engagement/content/site_engagement_service.h"
 #include "content/public/browser/browser_thread.h"
@@ -300,7 +301,8 @@ void PersistentNotificationHandler::OnAppTerminating() {
 void PersistentNotificationHandler::DisableNotifications(
     Profile* profile,
     const GURL& origin,
-    const std::optional<std::string>& notification_id) {
+    const std::optional<std::string>& notification_id,
+    const std::optional<bool>& is_suspicious) {
   DCHECK_CURRENTLY_ON(BrowserThread::UI);
   permissions::PermissionUmaUtil::ScopedRevocationReporter
       scoped_revocation_reporter(
@@ -331,6 +333,15 @@ void PersistentNotificationHandler::DisableNotifications(
       safe_browsing::MaybeLogSuspiciousNotificationUnsubscribeUkm(
           hcsm, origin, notification_id.value(), profile);
     }
+    if (is_suspicious.has_value()) {
+      safe_browsing::SafeBrowsingMetricsCollector::
+          LogSafeBrowsingNotificationRevocationSourceHistogram(
+              is_suspicious.value()
+                  ? safe_browsing::NotificationRevocationSource::
+                        kSuspiciousWarningOneTapUnsubscribe
+                  : safe_browsing::NotificationRevocationSource::
+                        kStandardOneTapUnsubscribe);
+    }
 #endif
   }
 }
