@@ -215,19 +215,27 @@ struct OsSignalsResponse : BaseSignalResponse {
 
   ~OsSignalsResponse() override;
 
-  // Common to all platforms
-  std::optional<std::string> display_name = std::nullopt;
+  // Common to all platforms, not necessarily all being collected.
+
   std::string browser_version{};
   std::optional<std::string> device_enrollment_domain = std::nullopt;
   std::string device_manufacturer{};
   std::string device_model{};
   device_signals::SettingValue disk_encryption =
       device_signals::SettingValue::UNKNOWN;
+  // Display name of the device, e.g "John Doe's Devoce"
+  std::optional<std::string> display_name = std::nullopt;
   std::optional<std::string> hostname = std::nullopt;
   std::optional<std::vector<std::string>> mac_addresses = std::nullopt;
   std::string operating_system{};
   device_signals::SettingValue os_firewall =
       device_signals::SettingValue::UNKNOWN;
+
+  // Version of the OS
+  // - Win: <major>.<minor>.<build>.<patch>, e.g 10.0.22631.5909
+  // - Linux: utsname.release, e.g 6.12.35-1rodete1-amd64
+  // - Mac: <major>.<minor>.<bugfix>, e.g 15.7.0
+  // - Android: The major version number, e.g 13
   std::string os_version{};
   device_signals::SettingValue screen_lock_secured =
       device_signals::SettingValue::UNKNOWN;
@@ -246,7 +254,9 @@ struct OsSignalsResponse : BaseSignalResponse {
   // Android specific
   bool has_potentially_harmful_apps;
   bool verified_apps_enabled;
-  std::string security_patch;
+  // The date when the device most recently applied a security patch, in ms
+  // since epoch.
+  std::optional<int64_t> security_patch_ms;
 };
 
 struct ProfileSignalsResponse : BaseSignalResponse {
