@@ -8,8 +8,12 @@
 #include <variant>
 
 #include "base/barrier_callback.h"
+#include "base/base64.h"
 #include "base/check.h"
 #include "base/functional/callback.h"
+#include "base/rand_util.h"
+#include "base/strings/string_number_conversions.h"
+#include "base/time/time.h"
 #include "build/build_config.h"
 #include "components/device_signals/core/browser/signals_aggregator.h"
 #include "components/device_signals/core/common/signals_features.h"
@@ -17,6 +21,7 @@
 #include "components/enterprise/browser/reporting/report_type.h"
 #include "components/enterprise/browser/reporting/report_util.h"
 #include "components/enterprise/browser/reporting/reporting_delegate_factory.h"
+#include "components/enterprise/device_attestation/device_attestation_service_factory.h"
 #include "components/policy/core/common/policy_logger.h"
 
 namespace enterprise_reporting {
@@ -25,6 +30,16 @@ namespace em = enterprise_management;
 
 namespace {
 
+// The size of the nonce challenge in bytes.
+const int kNonceSizeInBytes = 16;
+
+std::string CreateNonce() {
+  std::vector<uint8_t> nonce_buffer(kNonceSizeInBytes);
+  base::RandBytes(nonce_buffer);
+
+  return base::Base64Encode(nonce_buffer);
+}
+
 em::ChromeProfileReportRequest::ReportType GetReportTypeFromSignalsMode(
     SecuritySignalsMode signals_mode) {
   switch (signals_mode) {
@@ -69,7 +84,10 @@ ChromeProfileRequestGenerator::ChromeProfileRequestGenerator(
     : profile_path_(profile_path),
       browser_report_generator_(delegate_factory),
       profile_report_generator_(delegate_factory),
-      signals_aggregator_(signals_aggregator) {
+      signals_aggregator_(signals_aggregator),
+      device_attestation_service_(
+          enterprise::DeviceAttestationServiceFactory::GetInstance()
+              ->CreateDeviceAttestationService()) {
   profile_report_generator_.set_is_machine_scope(false);
 }
 
@@ -176,6 +194,8 @@ void ChromeProfileRequestGenerator::OnBaseReportsReady(
           std::move(profile_report)));
 }
 
+// TODO(crbug.com/448356931): Separate the following logics into a specialized
+// module.
 void ChromeProfileRequestGenerator::OnAggregatedSignalsReceived(
     std::unique_ptr<ReportRequest> request,
     ReportCallback callback,
@@ -253,7 +273,10 @@ void ChromeProfileRequestGenerator::OnAggregatedSignalsReceived(
     os_report->set_has_potentially_harmful_apps(
         os_signals.has_potentially_harmful_apps);
     os_report->set_verified_apps_enabled(os_signals.verified_apps_enabled);
-    os_report->set_security_patch(os_signals.security_patch);
+
+    if (os_signals.security_patch_ms) {
+      os_report->set_security_patch_ms(os_signals.security_patch_ms.value());
+    }
 #endif  // BUILDFLAG(IS_ANDROID)
 
     browser_report->set_browser_version(os_signals.browser_version);
@@ -343,8 +366,37 @@ void ChromeProfileRequestGenerator::OnAggregatedSignalsReceived(
   request->GetChromeProfileReportRequest().set_allocated_browser_report(
       browser_report.release());
 
-  VLOG_POLICY(1, REPORTING)
-      << "Signals report request generated: "
+  VLOG_POLICY(1, REPORTING) << "Signals report request is mostly ready, "
+                               "generating attestation payload";
+  std::string report_timestamp =
+      base::NumberToString(base::Time::Now().InMillisecondsFSinceUnixEpoch());
+  std::string report_nonce = CreateNonce();
+  auto signals_string =
+      GetSecuritySignalsInReport(request->GetChromeProfileReportRequest());
+  device_attestation_service_->GetAttestationResponse(
+      signals_string, report_timestamp, report_nonce,
+      base::BindOnce(&ChromeProfileRequestGenerator::OnAttestationResultReady,
+                     weak_ptr_factory_.GetWeakPtr(), report_timestamp,
+                     report_nonce, std::move(callback), std::move(request)));
+}
+
+void ChromeProfileRequestGenerator::OnAttestationResultReady(
+    std::string_view timestamp,
+    std::string_view nonce,
+    ReportCallback callback,
+    std::unique_ptr<ReportRequest> request,
+    const enterprise::BlobGenerationResult& attestation_result) {
+  auto attestation_payload = std::make_unique<em::AttestationPayload>();
+  attestation_payload->set_timestamp(timestamp);
+  attestation_payload->set_nonce(nonce);
+
+  attestation_payload->set_attestation_blob(
+      attestation_result.attestation_blob);
+  attestation_payload->set_attestation_error(attestation_result.error_message);
+  request->GetChromeProfileReportRequest().set_allocated_attestation_payload(
+      attestation_payload.release());
+  VLOG_POLICY(2, REPORTING)
+      << "Signals report request generated with attestation: "
       << GetSecuritySignalsInReport(request->GetChromeProfileReportRequest());
   OnRequestReady(std::move(request), std::move(callback));
 }
