@@ -12,6 +12,7 @@
 #include "base/containers/contains.h"
 #include "base/metrics/histogram_functions.h"
 #include "base/metrics/histogram_macros.h"
+#include "base/notreached.h"
 #include "base/rand_util.h"
 #include "base/strings/string_number_conversions.h"
 #include "base/strings/string_split.h"
@@ -36,6 +37,7 @@ const char kCacheCreationTime[] = "cache_creation_time";
 const char kVerdictProto[] = "verdict_proto";
 const char kRealTimeThreatInfoProto[] = "rt_threat_info_proto";
 const char kPasswordOnFocusCacheKey[] = "password_on_focus_cache_key";
+const char kOneTimePasswordCacheKey[] = "one_time_password_cache_key";
 const char kRealTimeUrlCacheKey[] = "real_time_url_cache_key";
 const char kCsdTypeCacheKey[] = "client_side_detection_type_cache_key";
 const char kLlamaForcedTriggerInfoKey[] = "llama_forced_trigger_info_key";
@@ -82,7 +84,7 @@ struct MatchParams {
 GURL GetHostNameWithHTTPScheme(const GURL& url) {
   DCHECK(url.SchemeIsHTTPOrHTTPS());
   std::string result(url::kHttpScheme);
-  result.append(url::kStandardSchemeSeparator).append(url.host());
+  result.append(url::kStandardSchemeSeparator).append(url.GetHost());
   return GURL(result);
 }
 // e.g, ("www.foo.com", "/bar/test.cgi") -> "http://www.foo.com/bar/test/cgi"
@@ -259,12 +261,19 @@ VerdictCacheManager::DictionaryCounts ComputeCountsAndMaybeRemoveExpiredEntries(
 std::string GetKeyOfTypeFromTriggerType(
     LoginReputationClientRequest::TriggerType trigger_type,
     ReusedPasswordAccountType password_type) {
-  return trigger_type == LoginReputationClientRequest::UNFAMILIAR_LOGIN_PAGE
-             ? kPasswordOnFocusCacheKey
-             : base::NumberToString(
-                   static_cast<std::underlying_type_t<
-                       ReusedPasswordAccountType::AccountType>>(
-                       password_type.account_type()));
+  switch (trigger_type) {
+    case LoginReputationClientRequest::UNFAMILIAR_LOGIN_PAGE:
+      return kPasswordOnFocusCacheKey;
+    case LoginReputationClientRequest::PASSWORD_REUSE_EVENT:
+      return base::NumberToString(
+          static_cast<
+              std::underlying_type_t<ReusedPasswordAccountType::AccountType>>(
+              password_type.account_type()));
+    case LoginReputationClientRequest::ONE_TIME_PASSWORD_FIELD_DETECTED:
+      return kOneTimePasswordCacheKey;
+    default:
+      NOTREACHED();
+  }
 }
 
 // If the verdict doesn't have |cache_expression_match_type| field, always
@@ -508,7 +517,9 @@ void VerdictCacheManager::CachePhishGuardVerdict(
   }
   DCHECK(content_settings_);
   DCHECK(trigger_type == LoginReputationClientRequest::UNFAMILIAR_LOGIN_PAGE ||
-         trigger_type == LoginReputationClientRequest::PASSWORD_REUSE_EVENT);
+         trigger_type == LoginReputationClientRequest::PASSWORD_REUSE_EVENT ||
+         trigger_type ==
+             LoginReputationClientRequest::ONE_TIME_PASSWORD_FIELD_DETECTED);
 
   GURL hostname = GetHostNameFromCacheExpression(GetCacheExpression(verdict));
 
@@ -536,9 +547,7 @@ void VerdictCacheManager::CachePhishGuardVerdict(
   // before.
   if (!verdict_dictionary->contains(GetCacheExpression(verdict))) {
     std::optional<size_t>* stored_verdict_count =
-        trigger_type == LoginReputationClientRequest::UNFAMILIAR_LOGIN_PAGE
-            ? &stored_verdict_count_password_on_focus_
-            : &stored_verdict_count_password_entry_;
+        GetStoredVerdictCountForTrigger(trigger_type);
     *stored_verdict_count = GetStoredPhishGuardVerdictCount(trigger_type) + 1;
   }
 
@@ -558,7 +567,9 @@ VerdictCacheManager::GetCachedPhishGuardVerdict(
     ReusedPasswordAccountType password_type,
     LoginReputationClientResponse* out_response) {
   DCHECK(trigger_type == LoginReputationClientRequest::UNFAMILIAR_LOGIN_PAGE ||
-         trigger_type == LoginReputationClientRequest::PASSWORD_REUSE_EVENT);
+         trigger_type == LoginReputationClientRequest::PASSWORD_REUSE_EVENT ||
+         trigger_type ==
+             LoginReputationClientRequest::ONE_TIME_PASSWORD_FIELD_DETECTED);
   if (is_shut_down_) {
     return LoginReputationClientResponse::VERDICT_TYPE_UNSPECIFIED;
   }
@@ -583,11 +594,11 @@ size_t VerdictCacheManager::GetStoredPhishGuardVerdictCount(
   }
   DCHECK(content_settings_);
   DCHECK(trigger_type == LoginReputationClientRequest::UNFAMILIAR_LOGIN_PAGE ||
-         trigger_type == LoginReputationClientRequest::PASSWORD_REUSE_EVENT);
+         trigger_type == LoginReputationClientRequest::PASSWORD_REUSE_EVENT ||
+         trigger_type ==
+             LoginReputationClientRequest::ONE_TIME_PASSWORD_FIELD_DETECTED);
   std::optional<size_t>* stored_verdict_count =
-      trigger_type == LoginReputationClientRequest::UNFAMILIAR_LOGIN_PAGE
-          ? &stored_verdict_count_password_on_focus_
-          : &stored_verdict_count_password_entry_;
+      GetStoredVerdictCountForTrigger(trigger_type);
   // If we have already computed this, return its value.
   if (stored_verdict_count->has_value()) {
     return stored_verdict_count->value();
@@ -595,6 +606,7 @@ size_t VerdictCacheManager::GetStoredPhishGuardVerdictCount(
 
   stored_verdict_count_password_on_focus_ = 0;
   stored_verdict_count_password_entry_ = 0;
+  stored_verdict_count_one_time_password_ = 0;
   for (const ContentSettingPatternSource& source :
        content_settings_->GetSettingsForOneType(
            ContentSettingsType::PASSWORD_PROTECTION)) {
@@ -602,6 +614,9 @@ size_t VerdictCacheManager::GetStoredPhishGuardVerdictCount(
       if (item.first == std::string_view(kPasswordOnFocusCacheKey)) {
         stored_verdict_count_password_on_focus_.value() +=
             item.second.GetDict().size();
+      } else if (item.first == std::string_view(kOneTimePasswordCacheKey)) {
+        stored_verdict_count_one_time_password_.value() +=
+            item.second.GetDict().size();
       } else {
         stored_verdict_count_password_entry_.value() +=
             item.second.GetDict().size();
@@ -758,7 +773,7 @@ bool VerdictCacheManager::GetCachedRealTimeLlamaForcedTriggerInfo(
 
 ChromeUserPopulation::PageLoadToken VerdictCacheManager::CreatePageLoadToken(
     const GURL& url) {
-  std::string hostname = url.host();
+  std::string hostname = url.GetHost();
   ChromeUserPopulation::PageLoadToken token;
   token.set_token_source(
       ChromeUserPopulation::PageLoadToken::CLIENT_GENERATION);
@@ -772,7 +787,7 @@ ChromeUserPopulation::PageLoadToken VerdictCacheManager::CreatePageLoadToken(
 
 ChromeUserPopulation::PageLoadToken VerdictCacheManager::GetPageLoadToken(
     const GURL& url) {
-  std::string hostname = url.host();
+  std::string hostname = url.GetHost();
   if (!base::Contains(page_load_token_map_, hostname)) {
     return ChromeUserPopulation::PageLoadToken();
   }
@@ -826,7 +841,10 @@ void VerdictCacheManager::CleanUpExpiredPhishGuardVerdicts() {
   if (GetStoredPhishGuardVerdictCount(
           LoginReputationClientRequest::UNFAMILIAR_LOGIN_PAGE) <= 0 &&
       GetStoredPhishGuardVerdictCount(
-          LoginReputationClientRequest::PASSWORD_REUSE_EVENT) <= 0) {
+          LoginReputationClientRequest::PASSWORD_REUSE_EVENT) <= 0 &&
+      GetStoredPhishGuardVerdictCount(
+          LoginReputationClientRequest::ONE_TIME_PASSWORD_FIELD_DETECTED) <=
+          0) {
     return;
   }
 
@@ -842,9 +860,13 @@ void VerdictCacheManager::CleanUpExpiredPhishGuardVerdicts() {
         LoginReputationClientRequest::UNFAMILIAR_LOGIN_PAGE, cache_dictionary);
     bool has_expired_password_reuse_entry = RemoveExpiredPhishGuardVerdicts(
         LoginReputationClientRequest::PASSWORD_REUSE_EVENT, cache_dictionary);
+    bool has_expired_one_time_password_entry = RemoveExpiredPhishGuardVerdicts(
+        LoginReputationClientRequest::ONE_TIME_PASSWORD_FIELD_DETECTED,
+        cache_dictionary);
 
     if (!cache_dictionary.empty() && !has_expired_password_on_focus_entry &&
-        !has_expired_password_reuse_entry) {
+        !has_expired_password_reuse_entry &&
+        !has_expired_one_time_password_entry) {
       continue;
     }
 
@@ -964,44 +986,84 @@ void VerdictCacheManager::OnCookiesDeleted() {
   CleanUpAllPageLoadTokens(ClearReason::kCookiesDeleted);
 }
 
+void VerdictCacheManager::RemoveExpiredVerdictsFromSubDict(
+    base::Value::Dict& cache_dictionary,
+    const char* sub_dict_key,
+    std::optional<size_t>& stored_verdict_count,
+    size_t& verdicts_removed,
+    std::vector<std::string>& keys_to_remove) {
+  base::Value::Dict* sub_dict = cache_dictionary.FindDict(sub_dict_key);
+  if (sub_dict) {
+    VerdictCacheManager::DictionaryCounts counts =
+        ComputeCountsAndMaybeRemoveExpiredEntries<
+            LoginReputationClientResponse>(*sub_dict, kVerdictProto,
+                                           /*remove_entries=*/true);
+    verdicts_removed = counts.num_removed_expired_entries;
+    if (stored_verdict_count.has_value()) {
+      stored_verdict_count.value() -= verdicts_removed;
+    }
+    if (sub_dict->empty()) {
+      keys_to_remove.push_back(sub_dict_key);
+    }
+  }
+}
+
 bool VerdictCacheManager::RemoveExpiredPhishGuardVerdicts(
     LoginReputationClientRequest::TriggerType trigger_type,
     base::Value::Dict& cache_dictionary) {
   DCHECK(trigger_type == LoginReputationClientRequest::UNFAMILIAR_LOGIN_PAGE ||
-         trigger_type == LoginReputationClientRequest::PASSWORD_REUSE_EVENT);
+         trigger_type == LoginReputationClientRequest::PASSWORD_REUSE_EVENT ||
+         trigger_type ==
+             LoginReputationClientRequest::ONE_TIME_PASSWORD_FIELD_DETECTED);
   if (cache_dictionary.empty()) {
     return false;
   }
 
   size_t verdicts_removed = 0;
-  std::vector<std::string> empty_keys;
-  for (auto [key, value] : cache_dictionary) {
-    if (trigger_type == LoginReputationClientRequest::UNFAMILIAR_LOGIN_PAGE &&
-        key == std::string(kPasswordOnFocusCacheKey)) {
-      DictionaryCounts counts = ComputeCountsAndMaybeRemoveExpiredEntries<
-          LoginReputationClientResponse>(value.GetDict(), kVerdictProto,
-                                         /*remove_entries=*/true);
-      verdicts_removed += counts.num_removed_expired_entries;
-      if (stored_verdict_count_password_on_focus_.has_value()) {
-        stored_verdict_count_password_on_focus_.value() -=
-            counts.num_removed_expired_entries;
-      }
-    } else {
-      DictionaryCounts counts = ComputeCountsAndMaybeRemoveExpiredEntries<
-          LoginReputationClientResponse>(value.GetDict(), kVerdictProto,
-                                         /*remove_entries=*/true);
-      verdicts_removed += counts.num_removed_expired_entries;
-      if (stored_verdict_count_password_entry_.has_value()) {
-        stored_verdict_count_password_entry_.value() -=
-            counts.num_removed_expired_entries;
-      }
-    }
+  std::vector<std::string> keys_to_remove;
 
-    if (value.GetDict().size() == 0U) {
-      empty_keys.push_back(key);
-    }
+  switch (trigger_type) {
+    case LoginReputationClientRequest::UNFAMILIAR_LOGIN_PAGE:
+      RemoveExpiredVerdictsFromSubDict(cache_dictionary,
+                                       kPasswordOnFocusCacheKey,
+                                       stored_verdict_count_password_on_focus_,
+                                       verdicts_removed, keys_to_remove);
+      break;
+    case LoginReputationClientRequest::ONE_TIME_PASSWORD_FIELD_DETECTED:
+      RemoveExpiredVerdictsFromSubDict(cache_dictionary,
+                                       kOneTimePasswordCacheKey,
+                                       stored_verdict_count_one_time_password_,
+                                       verdicts_removed, keys_to_remove);
+      break;
+    case LoginReputationClientRequest::PASSWORD_REUSE_EVENT:
+      for (auto it = cache_dictionary.begin(); it != cache_dictionary.end();
+           ++it) {
+        const std::string& key = it->first;
+        base::Value& value = it->second;
+
+        if (key != std::string(kPasswordOnFocusCacheKey) &&
+            key != std::string(kOneTimePasswordCacheKey)) {
+          if (value.is_dict()) {
+            DictionaryCounts counts = ComputeCountsAndMaybeRemoveExpiredEntries<
+                LoginReputationClientResponse>(value.GetDict(), kVerdictProto,
+                                               /*remove_entries=*/true);
+            verdicts_removed += counts.num_removed_expired_entries;
+            if (stored_verdict_count_password_entry_.has_value()) {
+              stored_verdict_count_password_entry_.value() -=
+                  counts.num_removed_expired_entries;
+            }
+            if (value.GetDict().empty()) {
+              keys_to_remove.push_back(key);
+            }
+          }
+        }
+      }
+      break;
+    default:
+      NOTREACHED();
   }
-  for (const auto& key : empty_keys) {
+
+  for (const auto& key : keys_to_remove) {
     cache_dictionary.Remove(key);
   }
 
@@ -1050,6 +1112,7 @@ void VerdictCacheManager::RemoveContentSettingsOnURLsDeleted(
         ContentSettingsType::PASSWORD_PROTECTION);
     stored_verdict_count_password_on_focus_ = 0;
     stored_verdict_count_password_entry_ = 0;
+    stored_verdict_count_one_time_password_ = 0;
     has_stored_verdicts_real_time_url_check_ = false;
     content_settings_->ClearSettingsForOneType(
         ContentSettingsType::SAFE_BROWSING_URL_CHECK_DATA);
@@ -1076,6 +1139,12 @@ void VerdictCacheManager::RemoveContentSettingsOnURLsDeleted(
             LoginReputationClientRequest::PASSWORD_REUSE_EVENT) -
         GetPhishGuardVerdictCountForURL(
             url_key, LoginReputationClientRequest::PASSWORD_REUSE_EVENT);
+    stored_verdict_count_one_time_password_ =
+        GetStoredPhishGuardVerdictCount(
+            LoginReputationClientRequest::ONE_TIME_PASSWORD_FIELD_DETECTED) -
+        GetPhishGuardVerdictCountForURL(
+            url_key,
+            LoginReputationClientRequest::ONE_TIME_PASSWORD_FIELD_DETECTED);
     content_settings_->SetWebsiteSettingDefaultScope(
         url_key, GURL(), ContentSettingsType::PASSWORD_PROTECTION,
         base::Value());
@@ -1089,7 +1158,9 @@ size_t VerdictCacheManager::GetPhishGuardVerdictCountForURL(
     const GURL& url,
     LoginReputationClientRequest::TriggerType trigger_type) {
   DCHECK(trigger_type == LoginReputationClientRequest::UNFAMILIAR_LOGIN_PAGE ||
-         trigger_type == LoginReputationClientRequest::PASSWORD_REUSE_EVENT);
+         trigger_type == LoginReputationClientRequest::PASSWORD_REUSE_EVENT ||
+         trigger_type ==
+             LoginReputationClientRequest::ONE_TIME_PASSWORD_FIELD_DETECTED);
   base::Value cache_dictionary_value = content_settings_->GetWebsiteSetting(
       url, GURL(), ContentSettingsType::PASSWORD_PROTECTION, nullptr);
 
@@ -1102,9 +1173,14 @@ size_t VerdictCacheManager::GetPhishGuardVerdictCountForURL(
     base::Value::Dict* password_on_focus_dict =
         cache_dictionary_value.GetDict().FindDict(kPasswordOnFocusCacheKey);
     verdict_cnt += password_on_focus_dict ? password_on_focus_dict->size() : 0;
+  } else if (trigger_type ==
+             LoginReputationClientRequest::ONE_TIME_PASSWORD_FIELD_DETECTED) {
+    base::Value::Dict* one_time_password_dict =
+        cache_dictionary_value.GetDict().FindDict(kOneTimePasswordCacheKey);
+    verdict_cnt += one_time_password_dict ? one_time_password_dict->size() : 0;
   } else {
     for (auto [key, value] : cache_dictionary_value.GetDict()) {
-      if (key == kPasswordOnFocusCacheKey) {
+      if (key == kPasswordOnFocusCacheKey || key == kOneTimePasswordCacheKey) {
         continue;
       }
       verdict_cnt += value.GetDict().size();
@@ -1113,6 +1189,20 @@ size_t VerdictCacheManager::GetPhishGuardVerdictCountForURL(
   return verdict_cnt;
 }
 
+std::optional<size_t>* VerdictCacheManager::GetStoredVerdictCountForTrigger(
+    LoginReputationClientRequest::TriggerType trigger_type) {
+  switch (trigger_type) {
+    case LoginReputationClientRequest::UNFAMILIAR_LOGIN_PAGE:
+      return &stored_verdict_count_password_on_focus_;
+    case LoginReputationClientRequest::PASSWORD_REUSE_EVENT:
+      return &stored_verdict_count_password_entry_;
+    case LoginReputationClientRequest::ONE_TIME_PASSWORD_FIELD_DETECTED:
+      return &stored_verdict_count_one_time_password_;
+    default:
+      NOTREACHED();
+  }
+}
+
 void VerdictCacheManager::CacheArtificialUnsafeRealTimeUrlVerdictFromSwitch() {
   std::string phishing_url_string =
       base::CommandLine::ForCurrentProcess()->GetSwitchValueASCII(
@@ -1251,7 +1341,7 @@ void VerdictCacheManager::StopCleanUpTimerForTesting() {
 void VerdictCacheManager::SetPageLoadTokenForTesting(
     const GURL& url,
     ChromeUserPopulation::PageLoadToken token) {
-  std::string hostname = url.host();
+  std::string hostname = url.GetHost();
   page_load_token_map_[hostname] = token;
 }
 
