@@ -23,9 +23,9 @@
 #include "net/tools/transport_security_state_generator/preloaded_state_generator.h"
 #include "net/tools/transport_security_state_generator/transport_security_state_entry.h"
 
-using net::transport_security_state::TransportSecurityStateEntries;
 using net::transport_security_state::Pinsets;
 using net::transport_security_state::PreloadedStateGenerator;
+using net::transport_security_state::TransportSecurityStateEntries;
 
 namespace {
 
@@ -38,25 +38,24 @@ void PrintHelp() {
 
 // Checks if there are pins with the same name or the same hash.
 bool CheckForDuplicatePins(const Pinsets& pinsets) {
-  std::set<std::string> seen_names;
-  std::map<std::string, std::string> seen_hashes;
+  std::set<std::string_view> seen_names;
+  std::map<std::string_view, std::string> seen_hashes;
 
   for (const auto& pin : pinsets.spki_hashes()) {
     if (seen_names.find(pin.first) != seen_names.cend()) {
       LOG(ERROR) << "Duplicate pin name " << pin.first << " in pins file";
       return false;
     }
-    seen_names.insert(pin.first);
+    seen_names.emplace(pin.first);
 
-    const std::string hash =
-        std::string(base::as_string_view(pin.second.span()));
+    const std::string_view hash = base::as_string_view(pin.second.span());
     auto it = seen_hashes.find(hash);
     if (it != seen_hashes.cend()) {
       LOG(ERROR) << "Duplicate pin hash for " << pin.first
                  << ", already seen as " << it->second;
       return false;
     }
-    seen_hashes.insert(std::pair<std::string, std::string>(hash, pin.first));
+    seen_hashes.emplace(hash, pin.first);
   }
 
   return true;
@@ -65,43 +64,44 @@ bool CheckForDuplicatePins(const Pinsets& pinsets) {
 // Checks if there are pinsets that reference non-existing pins, if two
 // pinsets share the same name, or if there are unused pins.
 bool CheckCertificatesInPinsets(const Pinsets& pinsets) {
-  std::set<std::string> pin_names;
+  std::set<std::string_view> pin_names;
   for (const auto& pin : pinsets.spki_hashes()) {
-    pin_names.insert(pin.first);
+    pin_names.emplace(pin.first);
   }
 
-  std::set<std::string> used_pin_names;
-  std::set<std::string> pinset_names;
+  std::set<std::string_view> used_pin_names;
+  std::set<std::string_view> pinset_names;
   for (const auto& pinset : pinsets.pinsets()) {
     if (pinset_names.find(pinset.second->name()) != pinset_names.cend()) {
       LOG(ERROR) << "Duplicate pinset name " << pinset.second->name();
       return false;
     }
-    pinset_names.insert(pinset.second->name());
+    pinset_names.emplace(pinset.second->name());
 
     const std::vector<std::string>& good_hashes =
         pinset.second->static_spki_hashes();
     const std::vector<std::string>& bad_hashes =
         pinset.second->bad_static_spki_hashes();
 
-    std::vector<std::string> all_pin_names;
-    all_pin_names.reserve(good_hashes.size() + bad_hashes.size());
-    all_pin_names.insert(all_pin_names.end(), good_hashes.begin(),
-                         good_hashes.end());
-    all_pin_names.insert(all_pin_names.end(), bad_hashes.begin(),
-                         bad_hashes.end());
-
-    for (const auto& pin_name : all_pin_names) {
+    for (const auto& pin_name : good_hashes) {
       if (pin_names.find(pin_name) == pin_names.cend()) {
         LOG(ERROR) << "Pinset " << pinset.second->name()
                    << " references pin " + pin_name << " which doesn't exist";
         return false;
       }
-      used_pin_names.insert(pin_name);
+      used_pin_names.emplace(pin_name);
+    }
+    for (const auto& pin_name : bad_hashes) {
+      if (pin_names.find(pin_name) == pin_names.cend()) {
+        LOG(ERROR) << "Pinset " << pinset.second->name()
+                   << " references pin " + pin_name << " which doesn't exist";
+        return false;
+      }
+      used_pin_names.emplace(pin_name);
     }
   }
 
-  for (const auto& pin_name : pin_names) {
+  for (const std::string_view pin_name : pin_names) {
     if (used_pin_names.find(pin_name) == used_pin_names.cend()) {
       LOG(ERROR) << "Pin " << pin_name << " is unused.";
       return false;
@@ -113,14 +113,14 @@ bool CheckCertificatesInPinsets(const Pinsets& pinsets) {
 
 // Checks if there are two or more entries for the same hostname.
 bool CheckDuplicateEntries(const TransportSecurityStateEntries& entries) {
-  std::set<std::string> seen_entries;
+  std::set<std::string_view> seen_entries;
   bool has_duplicates = false;
   for (const auto& entry : entries) {
     if (seen_entries.find(entry->hostname) != seen_entries.cend()) {
       LOG(ERROR) << "Duplicate entry for " << entry->hostname;
       has_duplicates = true;
     }
-    seen_entries.insert(entry->hostname);
+    seen_entries.emplace(entry->hostname);
   }
   return !has_duplicates;
 }
