@@ -26,7 +26,6 @@
 #include "components/content_settings/core/browser/content_settings_utils.h"
 #include "components/content_settings/core/browser/website_settings_registry.h"
 #include "components/content_settings/core/common/content_settings_metadata.h"
-#include "components/content_settings/core/common/content_settings_partition_key.h"
 #include "components/content_settings/core/common/content_settings_pattern.h"
 #include "components/content_settings/core/common/content_settings_types.h"
 #include "components/content_settings/core/common/content_settings_utils.h"
@@ -65,6 +64,8 @@ constexpr char kGeolocationMigrateExceptionsPref[] =
     "profile.content_settings.exceptions.migrate_geolocation";
 
 #if !BUILDFLAG(IS_IOS)
+constexpr char kObsoleteTopLevelTpcdTrialExceptionsPref[] =
+    "profile.content_settings.exceptions.top_level_3pcd_support";
 // This setting was accidentally bound to a UI surface intended for a different
 // setting (https://crbug.com/364820109). It should not have been settable
 // except via enterprise policy, so it is temporarily cleaned up here to revert
@@ -113,6 +114,7 @@ void PrefProvider::RegisterProfilePrefs(
       kObsoleteFederatedIdentityActiveSesssionExceptionsPref);
   registry->RegisterDictionaryPref(kObsoletePrivateNetworkChooserDataPref);
 #if !BUILDFLAG(IS_IOS)
+  registry->RegisterDictionaryPref(kObsoleteTopLevelTpcdTrialExceptionsPref);
   // TODO(https://crbug.com/367181093): clean this up.
   registry->RegisterBooleanPref(kBug364820109AlreadyWorkedAroundPref, false);
 #endif  // !BUILDFLAG(IS_IOS)
@@ -147,12 +149,11 @@ PrefProvider::PrefProvider(PrefService* prefs,
       WebsiteSettingsRegistry::GetInstance();
   for (const WebsiteSettingsInfo* info : *website_settings) {
     content_settings_prefs_.insert(std::make_pair(
-        info->type(),
-        std::make_unique<ContentSettingsPref>(
-            info->type(), prefs_, &pref_change_registrar_, info->pref_name(),
-            info->partitioned_pref_name(), off_the_record_, restore_session,
-            base::BindRepeating(&PrefProvider::Notify,
-                                base::Unretained(this)))));
+        info->type(), std::make_unique<ContentSettingsPref>(
+                          info->type(), prefs_, &pref_change_registrar_,
+                          info->pref_name(), off_the_record_, restore_session,
+                          base::BindRepeating(&PrefProvider::Notify,
+                                              base::Unretained(this)))));
   }
 
   MigrateGeolocationExceptions();
@@ -181,37 +182,32 @@ PrefProvider::~PrefProvider() {
 
 std::unique_ptr<RuleIterator> PrefProvider::GetRuleIterator(
     ContentSettingsType content_type,
-    bool off_the_record,
-    const PartitionKey& partition_key) const {
+    bool off_the_record) const {
   if (!supports_type(content_type)) {
     return nullptr;
   }
 
-  return GetPref(content_type)->GetRuleIterator(off_the_record, partition_key);
+  return GetPref(content_type)->GetRuleIterator(off_the_record);
 }
 
-std::unique_ptr<Rule> PrefProvider::GetRule(
-    const GURL& primary_url,
-    const GURL& secondary_url,
-    ContentSettingsType content_type,
-    bool off_the_record,
-    const PartitionKey& partition_key) const {
+std::unique_ptr<Rule> PrefProvider::GetRule(const GURL& primary_url,
+                                            const GURL& secondary_url,
+                                            ContentSettingsType content_type,
+                                            bool off_the_record) const {
   if (!supports_type(content_type)) {
     return nullptr;
   }
 
   return GetPref(content_type)
-      ->GetRule(primary_url, secondary_url, off_the_record, partition_key);
+      ->GetRule(primary_url, secondary_url, off_the_record);
 }
 
-// TODO(b/307193732): handle the PartitionKey in all relevant methods.
 bool PrefProvider::SetWebsiteSetting(
     const ContentSettingsPattern& primary_pattern,
     const ContentSettingsPattern& secondary_pattern,
     ContentSettingsType content_type,
     base::Value&& in_value,
-    const ContentSettingConstraints& constraints,
-    const PartitionKey& partition_key) {
+    const ContentSettingConstraints& constraints) {
   DCHECK(CalledOnValidThread());
   DCHECK(prefs_);
 
@@ -257,8 +253,7 @@ bool PrefProvider::SetWebsiteSetting(
   metadata.SetFromConstraints(constraints);
   GetPref(content_type)
       ->SetWebsiteSetting(primary_pattern, secondary_pattern,
-                          std::move(in_value), std::move(metadata),
-                          partition_key);
+                          std::move(in_value), std::move(metadata));
   return true;
 }
 
@@ -266,8 +261,7 @@ bool PrefProvider::SetLastVisitTime(
     const ContentSettingsPattern& primary_pattern,
     const ContentSettingsPattern& secondary_pattern,
     ContentSettingsType content_type,
-    const base::Time time,
-    const PartitionKey& partition_key) {
+    const base::Time time) {
   return UpdateSetting(
       content_type,
       [&](const Rule& rule) -> bool {
@@ -282,20 +276,18 @@ bool PrefProvider::SetLastVisitTime(
         rule.metadata.set_last_visited(time);
 
         return true;
-      },
-      partition_key);
+      });
 }
 
-bool PrefProvider::UpdateSetting(ContentSettingsType content_type,
-                                 base::FunctionRef<bool(const Rule&)> is_match,
-                                 base::FunctionRef<bool(Rule&)> perform_update,
-                                 const PartitionKey& partition_key) {
+bool PrefProvider::UpdateSetting(
+    ContentSettingsType content_type,
+    base::FunctionRef<bool(const Rule&)> is_match,
+    base::FunctionRef<bool(Rule&)> perform_update) {
   if (!supports_type(content_type)) {
     return false;
   }
 
-  auto it = GetRuleIterator(content_type, off_the_record_,
-                            PartitionKey::WipGetDefault());
+  auto it = GetRuleIterator(content_type, off_the_record_);
   if (!it) {
     return false;
   }
@@ -323,7 +315,7 @@ bool PrefProvider::UpdateSetting(ContentSettingsType content_type,
     GetPref(content_type)
         ->SetWebsiteSetting(std::move(primary_pattern),
                             std::move(secondary_pattern), std::move(value),
-                            std::move(metadata), partition_key);
+                            std::move(metadata));
     return true;
   }
   return false;
@@ -332,8 +324,7 @@ bool PrefProvider::UpdateSetting(ContentSettingsType content_type,
 bool PrefProvider::UpdateLastUsedTime(const GURL& primary_url,
                                       const GURL& secondary_url,
                                       ContentSettingsType content_type,
-                                      const base::Time time,
-                                      const PartitionKey& partition_key) {
+                                      const base::Time time) {
   return UpdateSetting(
       content_type,
       [&](const Rule& rule) -> bool {
@@ -343,34 +334,30 @@ bool PrefProvider::UpdateLastUsedTime(const GURL& primary_url,
       [&](Rule& rule) -> bool {
         rule.metadata.set_last_used(time);
         return true;
-      },
-      partition_key);
+      });
 }
 
 bool PrefProvider::ResetLastVisitTime(
     const ContentSettingsPattern& primary_pattern,
     const ContentSettingsPattern& secondary_pattern,
-    ContentSettingsType content_type,
-    const PartitionKey& partition_key) {
+    ContentSettingsType content_type) {
   return SetLastVisitTime(primary_pattern, secondary_pattern, content_type,
-                          base::Time(), partition_key);
+                          base::Time());
 }
 
 bool PrefProvider::UpdateLastVisitTime(
     const ContentSettingsPattern& primary_pattern,
     const ContentSettingsPattern& secondary_pattern,
-    ContentSettingsType content_type,
-    const PartitionKey& partition_key) {
+    ContentSettingsType content_type) {
   return SetLastVisitTime(primary_pattern, secondary_pattern, content_type,
-                          GetCoarseVisitedTime(clock_->Now()), partition_key);
+                          GetCoarseVisitedTime(clock_->Now()));
 }
 
 std::optional<base::TimeDelta> PrefProvider::RenewContentSetting(
     const GURL& primary_url,
     const GURL& secondary_url,
     ContentSettingsType content_type,
-    std::optional<ContentSetting> setting_to_match,
-    const PartitionKey& partition_key) {
+    std::optional<ContentSetting> setting_to_match) {
   std::optional<base::TimeDelta> delta_to_expiration;
   UpdateSetting(
       content_type,
@@ -398,19 +385,17 @@ std::optional<base::TimeDelta> PrefProvider::RenewContentSetting(
                                                lifetime);
 
         return true;
-      },
-      partition_key);
+      });
   return delta_to_expiration;
 }
 
 void PrefProvider::ClearAllContentSettingsRules(
-    ContentSettingsType content_type,
-    const PartitionKey& partition_key) {
+    ContentSettingsType content_type) {
   DCHECK(CalledOnValidThread());
   DCHECK(prefs_);
 
   if (supports_type(content_type)) {
-    GetPref(content_type)->ClearAllContentSettingsRules(partition_key);
+    GetPref(content_type)->ClearAllContentSettingsRules();
   }
 }
 
@@ -433,10 +418,8 @@ ContentSettingsPref* PrefProvider::GetPref(ContentSettingsType type) const {
 
 void PrefProvider::Notify(const ContentSettingsPattern& primary_pattern,
                           const ContentSettingsPattern& secondary_pattern,
-                          ContentSettingsType content_type,
-                          const PartitionKey* partition_key) {
-  NotifyObservers(primary_pattern, secondary_pattern, content_type,
-                  partition_key);
+                          ContentSettingsType content_type) {
+  NotifyObservers(primary_pattern, secondary_pattern, content_type);
 }
 
 void PrefProvider::DiscardOrMigrateObsoletePreferences() {
@@ -456,6 +439,7 @@ void PrefProvider::DiscardOrMigrateObsoletePreferences() {
   prefs_->ClearPref(kObsoletePrivateNetworkChooserDataPref);
 
 #if !BUILDFLAG(IS_IOS)
+  prefs_->ClearPref(kObsoleteTopLevelTpcdTrialExceptionsPref);
   // TODO(https://crbug.com/367181093): clean this up.
   prefs_->ClearPref(kBug364820109AlreadyWorkedAroundPref);
 #endif  // !BUILDFLAG(IS_IOS)
@@ -468,17 +452,13 @@ void PrefProvider::MigrateGeolocationExceptions() {
 
   auto* info = PermissionSettingsRegistry::GetInstance()->Get(
       ContentSettingsType::GEOLOCATION_WITH_OPTIONS);
-  // TODO(b/307193732):  Partition keys were never launched and should be
-  // removed. If this changes, then we should run the migration over
-  // all keys.
-  auto partition_key = PartitionKey::WipGetDefault();
   // Migrate when the feature gets enabled the first time.
   if (base::FeatureList::IsEnabled(
           features::kApproximateGeolocationPermission) &&
       !prefs_->GetBoolean(kGeolocationMigrateExceptionsPref)) {
     auto* old_pref = GetPref(ContentSettingsType::GEOLOCATION);
     auto* options_pref = GetPref(ContentSettingsType::GEOLOCATION_WITH_OPTIONS);
-    auto it = old_pref->GetRuleIterator(false, partition_key);
+    auto it = old_pref->GetRuleIterator(false);
     while (it && it->HasNext()) {
       auto rule = it->Next();
       auto content_setting = ValueToContentSetting(rule->value);
@@ -488,10 +468,10 @@ void PrefProvider::MigrateGeolocationExceptions() {
       options_pref->SetWebsiteSetting(
           rule->primary_pattern, rule->secondary_pattern,
           info->delegate().ToValue(geolocation_setting),
-          std::move(rule->metadata), partition_key);
+          std::move(rule->metadata));
     }
     it.reset();
-    old_pref->ClearAllContentSettingsRules(partition_key);
+    old_pref->ClearAllContentSettingsRules();
     prefs_->SetBoolean(kGeolocationMigrateExceptionsPref, true);
   }
 
@@ -501,7 +481,7 @@ void PrefProvider::MigrateGeolocationExceptions() {
       prefs_->GetBoolean(kGeolocationMigrateExceptionsPref)) {
     auto* old_pref = GetPref(ContentSettingsType::GEOLOCATION);
     auto* options_pref = GetPref(ContentSettingsType::GEOLOCATION_WITH_OPTIONS);
-    auto it = options_pref->GetRuleIterator(false, partition_key);
+    auto it = options_pref->GetRuleIterator(false);
     while (it && it->HasNext()) {
       auto rule = it->Next();
       auto geolocation_setting = std::get<GeolocationSetting>(
@@ -509,10 +489,10 @@ void PrefProvider::MigrateGeolocationExceptions() {
       old_pref->SetWebsiteSetting(
           rule->primary_pattern, rule->secondary_pattern,
           ContentSettingToValue(ToContentSetting(geolocation_setting.precise)),
-          std::move(rule->metadata), partition_key);
+          std::move(rule->metadata));
     }
     it.reset();
-    options_pref->ClearAllContentSettingsRules(partition_key);
+    options_pref->ClearAllContentSettingsRules();
     prefs_->SetBoolean(kGeolocationMigrateExceptionsPref, false);
   }
 }
