@@ -6,6 +6,7 @@
 
 #include <utility>
 
+#include "base/byte_count.h"
 #include "base/feature_list.h"
 #include "base/i18n/number_formatting.h"
 #include "base/i18n/rtl.h"
@@ -19,6 +20,7 @@
 #include "chrome/browser/download/download_ui_enterprise_util.h"
 #include "chrome/browser/download/download_ui_safe_browsing_util.h"
 #include "chrome/browser/download/offline_item_utils.h"
+#include "chrome/browser/download/status_text_builder_utils.h"
 #include "chrome/browser/enterprise/connectors/common.h"
 #include "chrome/browser/safe_browsing/advanced_protection_status_manager.h"
 #include "chrome/browser/safe_browsing/advanced_protection_status_manager_factory.h"
@@ -194,9 +196,9 @@ std::u16string DownloadUIModel::GetProgressSizesString() const {
 std::u16string DownloadUIModel::StatusTextBuilder::GetProgressSizesString()
     const {
   std::u16string size_ratio;
-  int64_t size = model_->GetCompletedBytes();
-  int64_t total = model_->GetTotalBytes();
-  if (total > 0) {
+  base::ByteCount size = base::ByteCount(model_->GetCompletedBytes());
+  base::ByteCount total = base::ByteCount(model_->GetTotalBytes());
+  if (total > base::ByteCount(0)) {
     ui::DataUnits amount_units = ui::GetByteDisplayUnits(total);
     std::u16string simple_size =
         ui::FormatBytesWithUnits(size, amount_units, false);
@@ -219,29 +221,8 @@ std::u16string DownloadUIModel::StatusTextBuilder::GetProgressSizesString()
 
 std::u16string
 DownloadUIModel::BubbleStatusTextBuilder::GetProgressSizesString() const {
-  std::u16string size_ratio;
-  int64_t size = model_->GetCompletedBytes();
-  int64_t total = model_->GetTotalBytes();
-  if (total > 0) {
-    ui::DataUnits amount_units = ui::GetByteDisplayUnits(total);
-    std::u16string simple_size =
-        ui::FormatBytesWithUnits(size, amount_units, false);
-    std::u16string simple_total =
-        ui::FormatBytesWithUnits(total, amount_units, true);
-
-    // Linux prepends an RLM (right-to-left mark) in the FormatBytesWithUnits
-    // call when showing units if the string has strong RTL characters. This is
-    // problematic for this fraction use case because it ends up moving it
-    // around so that the numerator is in the wrong place. Therefore, we remove
-    // that extra marker before proceeding.
-    base::i18n::UnadjustStringForLocaleDirection(&simple_total);
-    size_ratio = l10n_util::GetStringFUTF16(IDS_DOWNLOAD_STATUS_SIZES,
-                                            simple_size, simple_total);
-  } else {
-    size_ratio = ui::FormatBytes(size);
-  }
-
-  return size_ratio;
+  return StatusTextBuilderUtils::GetBubbleProgressSizesString(
+      model_->GetCompletedBytes(), model_->GetTotalBytes());
 }
 
 std::u16string DownloadUIModel::GetStatusText() const {
@@ -867,43 +848,6 @@ std::u16string DownloadUIModel::StatusTextBuilder::GetInProgressStatusText()
   }
 }
 
-// static
-std::u16string
-DownloadUIModel::BubbleStatusTextBuilder::GetBubbleStatusMessageWithBytes(
-    const std::u16string& bytes_substring,
-    const std::u16string& detail_message,
-    bool is_active) {
-  // For some RTL languages (e.g. Hebrew), the translated form of 123/456 MB
-  // still uses the English characters "MB" rather than RTL characters. We
-  // specifically mark this as LTR because it should be displayed as "123/456
-  // MB" (not "MB 123/456"). Conversely, some other RTL languages (e.g. Arabic)
-  // do translate "MB" to RTL characters. For these, we do nothing, that way the
-  // phrase is correctly displayed as RTL, with the translated "MB" to the left
-  // of the fraction.
-  std::u16string final_bytes_substring =
-      base::i18n::GetStringDirection(bytes_substring) ==
-              base::i18n::TextDirection::LEFT_TO_RIGHT
-          ? base::i18n::GetDisplayStringInLTRDirectionality(bytes_substring)
-          : bytes_substring;
-
-  std::u16string download_progress =
-      is_active ? l10n_util::GetStringFUTF16(
-                      IDS_DOWNLOAD_BUBBLE_DOWNLOAD_STATUS_WITH_SYMBOL,
-                      final_bytes_substring)
-                : final_bytes_substring;
-
-  std::u16string text = l10n_util::GetStringFUTF16(
-      IDS_DOWNLOAD_BUBBLE_DOWNLOAD_STATUS_MESSAGE_WITH_SEPARATOR,
-      download_progress, detail_message);
-
-  // Some RTL languages like Hebrew still display "MB" in English
-  // characters, which are the first strongly directional characters in
-  // the full string. We mark the full string as RTL to ensure it doesn't get
-  // displayed as LTR in spite of the first characters ("MB") being LTR.
-  base::i18n::AdjustStringForLocaleDirection(&text);
-  return text;
-}
-
 std::u16string
 DownloadUIModel::BubbleStatusTextBuilder::GetBubbleWarningStatusText() const {
   // If the detail message is "Malware", then this returns "Blocked • Malware"
@@ -1058,15 +1002,16 @@ DownloadUIModel::BubbleStatusTextBuilder::GetInProgressStatusText() const {
   // If the detail message is "Paused" and the size_ratio is "100/120 MB", then
   // this returns "100/120 MB • Paused".
   auto get_size_ratio_string = [size_ratio](std::u16string detail_message) {
-    return GetBubbleStatusMessageWithBytes(size_ratio, detail_message,
-                                           /*is_active=*/false);
+    return StatusTextBuilderUtils::GetBubbleStatusMessageWithBytes(
+        size_ratio, detail_message);
   };
   // If the detail message is "Opening in 10 seconds..." and the size_ratio is
   // "100/120 MB", then this returns "↓ 100/120 MB • Opening in 10 seconds...".
   auto get_active_download_size_ratio_string =
       [size_ratio](std::u16string detail_message) {
-        return GetBubbleStatusMessageWithBytes(size_ratio, detail_message,
-                                               /*is_active=*/true);
+        return StatusTextBuilderUtils::
+            GetActiveDownloadBubbleStatusMessageWithBytes(size_ratio,
+                                                          detail_message);
       };
 
   const auto completed_bytes = model_->GetCompletedBytes();
@@ -1075,8 +1020,8 @@ DownloadUIModel::BubbleStatusTextBuilder::GetInProgressStatusText() const {
   // If the detail message is "Done" and the total_bytes is "120 MB", then
   // this returns "120 MB • Done".
   auto get_total_string = [total_bytes](std::u16string detail_message) {
-    return GetBubbleStatusMessageWithBytes(ui::FormatBytes(total_bytes),
-                                           detail_message, /*is_active=*/false);
+    return StatusTextBuilderUtils::GetBubbleStatusMessageWithBytes(
+        ui::FormatBytes(base::ByteCount(total_bytes)), detail_message);
   };
 
   // The download is a CRX (app, extension, theme, ...) and it is being unpacked
@@ -1126,8 +1071,7 @@ DownloadUIModel::BubbleStatusTextBuilder::GetInProgressStatusText() const {
         l10n_util::GetStringUTF16(IDS_DOWNLOAD_BUBBLE_STATUS_RESUMING));
   } else {
     // "120 MB • Done"
-    return get_total_string(
-        l10n_util::GetStringUTF16(IDS_DOWNLOAD_BUBBLE_STATUS_DONE));
+    return StatusTextBuilderUtils::GetCompletedTotalSizeString(total_bytes);
   }
 }
 
@@ -1177,9 +1121,8 @@ DownloadUIModel::BubbleStatusTextBuilder::GetCompletedStatusText() const {
             : ui::TimeFormat::Simple(ui::TimeFormat::FORMAT_ELAPSED,
                                      ui::TimeFormat::LENGTH_LONG, time_elapsed);
   }
-  return GetBubbleStatusMessageWithBytes(
-      ui::FormatBytes(model_->GetTotalBytes()), delta_str,
-      /*is_active=*/false);
+  return StatusTextBuilderUtils::GetBubbleStatusMessageWithBytes(
+      ui::FormatBytes(base::ByteCount(model_->GetTotalBytes())), delta_str);
 }
 
 // To clarify variable / method names in methods below that help form failure
@@ -1352,7 +1295,7 @@ std::u16string DownloadUIModel::GetInProgressAccessibleAlertText() const {
   // Percent remaining is also unknown, announce bytes to download.
   return l10n_util::GetStringFUTF16(
       IDS_DOWNLOAD_STATUS_IN_PROGRESS_ACCESSIBLE_ALERT,
-      ui::FormatBytes(GetTotalBytes()),
+      ui::FormatBytes(base::ByteCount(GetTotalBytes())),
       GetFileNameToReportUser().LossyDisplayName());
 }
 
