@@ -194,7 +194,7 @@ ProfileManagementNavigationThrottle::~ProfileManagementNavigationThrottle() =
 content::NavigationThrottle::ThrottleCheckResult
 ProfileManagementNavigationThrottle::WillProcessResponse() {
   if (!base::Contains(GetAttributeMap(),
-                      navigation_handle()->GetURL().host())) {
+                      navigation_handle()->GetURL().GetHost())) {
     return PROCEED;
   }
 
@@ -224,7 +224,7 @@ void ProfileManagementNavigationThrottle::OnResponseBodyReady(
   // TODO(crbug.com/40267996): As a fallback, check more attributes that may
   // contain the user's email address.
   const auto profile_attributes =
-      GetAttributeMap().at(navigation_handle()->GetURL().host());
+      GetAttributeMap().at(navigation_handle()->GetURL().GetHost());
   saml_response_parser_ = std::make_unique<SAMLResponseParser>(
       std::vector<std::string>{profile_attributes.name,
                                profile_attributes.domain,
@@ -237,7 +237,7 @@ void ProfileManagementNavigationThrottle::OnResponseBodyReady(
 
 void ProfileManagementNavigationThrottle::OnManagementDataReceived(
     const base::flat_map<std::string, std::string>& attributes) {
-  const std::string navigation_host = navigation_handle()->GetURL().host();
+  const std::string navigation_host = navigation_handle()->GetURL().GetHost();
   DCHECK(base::Contains(GetAttributeMap(), navigation_host));
   const auto profile_attributes = GetAttributeMap().at(navigation_host);
 
