@@ -99,6 +99,8 @@ void RevokePermission(const GURL& origin, Profile* profile) {
     AbusiveNotificationPermissionsManager::
         ExecuteAbusiveNotificationAutoRevocation(
             HostContentSettingsMapFactory::GetForProfile(profile), origin,
+            safe_browsing::NotificationRevocationSource::
+                kSafeBrowsingUnwantedRevocation,
             base::DefaultClock::GetInstance());
   } else {
     permissions::PermissionsClient::Get()
@@ -231,9 +233,10 @@ void PermissionRevocationRequest::OnSafeBrowsingVerdictReceived(
       NotifyCallback(Outcome::PERMISSION_REVOKED_DUE_TO_DISRUPTIVE_BEHAVIOR);
     }
 
-    base::UmaHistogramEnumeration("SafeBrowsing.NotificationRevocationSource",
-                                  safe_browsing::NotificationRevocationSource::
-                                      kManualSafeBrowsingRevocation);
+    safe_browsing::SafeBrowsingMetricsCollector::
+        LogSafeBrowsingNotificationRevocationSourceHistogram(
+            safe_browsing::NotificationRevocationSource::
+                kSafeBrowsingUnwantedRevocation);
   } else {
     NotifyCallback(Outcome::PERMISSION_NOT_REVOKED);
   }
