@@ -467,6 +467,10 @@ class ChromePasswordProtectionService
                            OnEnterpriseTriggerOffGSuite);
   FRIEND_TEST_ALL_PREFIXES(ChromePasswordProtectionServiceBrowserTest,
                            VerifyIsInExcludedCountry);
+  FRIEND_TEST_ALL_PREFIXES(ChromePasswordProtectionServiceTest,
+                           VerifyAlertModeForEnterprisePasswordEntryPing);
+  FRIEND_TEST_ALL_PREFIXES(ChromePasswordProtectionServiceTest,
+                           VerifyUserPopulationForOtpPing);
 
  private:
   friend class MockChromePasswordProtectionService;
