@@ -737,7 +737,12 @@ bool DiceWebSigninInterceptor::ShouldShowEnterpriseDialog(
   }
 
   // If the user has declined profile creation twice, stop asking them.
-  if (HasUserDeclinedProfileCreation(intercepted_account_info.email)) {
+  // When in `ChromeSigninUserChoice::kAlwaysAsk` setting mode, the decline
+  // is not remembered, so the user can still see the dialog.
+  if (SigninPrefs(*profile_->GetPrefs())
+          .GetChromeSigninInterceptionUserChoice(intercepted_account_info.gaia) !=
+      ChromeSigninUserChoice::kAlwaysAsk &&
+      HasUserDeclinedProfileCreation(intercepted_account_info.email)) {
     return false;
   }
 
