@@ -8,6 +8,7 @@
 
 #include "base/command_line.h"
 #include "base/memory/raw_ptr.h"
+#include "base/test/metrics/user_action_tester.h"
 #include "base/test/run_until.h"
 #include "base/test/scoped_feature_list.h"
 #include "build/branding_buildflags.h"
@@ -140,30 +141,31 @@ TEST_F(BrowserCommandControllerTest, IsReservedCommandOrKey) {
 }
 
 TEST_F(BrowserCommandControllerTest, IsReservedCommandOrKeyIsApp) {
+  auto browser_window = std::make_unique<TestBrowserWindow>();
   Browser::CreateParams params = Browser::CreateParams::CreateForApp(
       "app",
-      /*trusted_source=*/true, browser()->window()->GetBounds(), profile(),
+      /*trusted_source=*/true, browser_window->GetBounds(), profile(),
       /*user_gesture=*/true);
-  params.window = browser()->window();
-  set_browser(Browser::DeprecatedCreateOwnedForTesting(params));
+  params.window = browser_window.release();
+  auto browser = Browser::DeprecatedCreateOwnedForTesting(params);
 
-  ASSERT_TRUE(browser()->is_type_app());
+  ASSERT_TRUE(browser->is_type_app());
 
   // When is_type_app(), no keys are reserved.
 #if BUILDFLAG(IS_CHROMEOS)
-  EXPECT_FALSE(browser()->command_controller()->IsReservedCommandOrKey(
+  EXPECT_FALSE(browser->command_controller()->IsReservedCommandOrKey(
       IDC_BACK,
       input::NativeWebKeyboardEvent(ui::KeyEvent(
           ui::EventType::kKeyPressed, ui::VKEY_F1, ui::DomCode::F1, 0))));
-  EXPECT_FALSE(browser()->command_controller()->IsReservedCommandOrKey(
+  EXPECT_FALSE(browser->command_controller()->IsReservedCommandOrKey(
       IDC_FORWARD,
       input::NativeWebKeyboardEvent(ui::KeyEvent(
           ui::EventType::kKeyPressed, ui::VKEY_F2, ui::DomCode::F2, 0))));
-  EXPECT_FALSE(browser()->command_controller()->IsReservedCommandOrKey(
+  EXPECT_FALSE(browser->command_controller()->IsReservedCommandOrKey(
       IDC_RELOAD,
       input::NativeWebKeyboardEvent(ui::KeyEvent(
           ui::EventType::kKeyPressed, ui::VKEY_F3, ui::DomCode::F3, 0))));
-  EXPECT_FALSE(browser()->command_controller()->IsReservedCommandOrKey(
+  EXPECT_FALSE(browser->command_controller()->IsReservedCommandOrKey(
       -1, input::NativeWebKeyboardEvent(ui::KeyEvent(
               ui::EventType::kKeyPressed, ui::VKEY_F4, ui::DomCode::F4, 0))));
 #endif  // BUILDFLAG(IS_CHROMEOS)
@@ -171,15 +173,15 @@ TEST_F(BrowserCommandControllerTest, IsReservedCommandOrKeyIsApp) {
 #if defined(USE_AURA)
   // The input::NativeWebKeyboardEvent constructor is available only when
   // USE_AURA is #defined.
-  EXPECT_FALSE(browser()->command_controller()->IsReservedCommandOrKey(
+  EXPECT_FALSE(browser->command_controller()->IsReservedCommandOrKey(
       IDC_NEW_WINDOW, input::NativeWebKeyboardEvent(ui::KeyEvent(
                           ui::EventType::kKeyPressed, ui::VKEY_N,
                           ui::DomCode::US_N, ui::EF_CONTROL_DOWN))));
-  EXPECT_FALSE(browser()->command_controller()->IsReservedCommandOrKey(
+  EXPECT_FALSE(browser->command_controller()->IsReservedCommandOrKey(
       IDC_CLOSE_TAB, input::NativeWebKeyboardEvent(ui::KeyEvent(
                          ui::EventType::kKeyPressed, ui::VKEY_W,
                          ui::DomCode::US_W, ui::EF_CONTROL_DOWN))));
-  EXPECT_FALSE(browser()->command_controller()->IsReservedCommandOrKey(
+  EXPECT_FALSE(browser->command_controller()->IsReservedCommandOrKey(
       IDC_FIND, input::NativeWebKeyboardEvent(
                     ui::KeyEvent(ui::EventType::kKeyPressed, ui::VKEY_F,
                                  ui::DomCode::US_F, ui::EF_CONTROL_DOWN))));
@@ -218,15 +220,16 @@ TEST_F(BrowserCommandControllerTest, AppFullScreen) {
   EXPECT_TRUE(chrome::IsCommandEnabled(browser(), IDC_FULLSCREEN));
 
   // Enabled for app windows.
+  auto browser_window = std::make_unique<TestBrowserWindow>();
   Browser::CreateParams params = Browser::CreateParams::CreateForApp(
       "app",
-      /*trusted_source=*/true, browser()->window()->GetBounds(), profile(),
+      /*trusted_source=*/true, browser_window->GetBounds(), profile(),
       /*user_gesture=*/true);
-  params.window = browser()->window();
-  set_browser(Browser::DeprecatedCreateOwnedForTesting(params));
-  ASSERT_TRUE(browser()->is_type_app());
-  browser()->command_controller()->FullscreenStateChanged();
-  EXPECT_TRUE(chrome::IsCommandEnabled(browser(), IDC_FULLSCREEN));
+  params.window = browser_window.release();
+  auto browser = Browser::DeprecatedCreateOwnedForTesting(params);
+  ASSERT_TRUE(browser->is_type_app());
+  browser->command_controller()->FullscreenStateChanged();
+  EXPECT_TRUE(chrome::IsCommandEnabled(browser.get(), IDC_FULLSCREEN));
 }
 
 TEST_F(BrowserCommandControllerTest, AvatarAcceleratorEnabledOnDesktop) {
@@ -295,7 +298,7 @@ class FullscreenTestBrowserWindow : public TestBrowserWindow,
   bool IsFullscreen() const override { return fullscreen_; }
   void EnterFullscreen(const url::Origin& origin,
                        ExclusiveAccessBubbleType type,
-                       int64_t display_id) override {
+                       FullscreenTabParams fullscreen_tab_params) override {
     fullscreen_ = true;
   }
   void ExitFullscreen() override { fullscreen_ = false; }
@@ -591,6 +594,23 @@ TEST_F(BrowserCommandControllerWithBookmarksTest,
   EXPECT_FALSE(command_controller.IsCommandEnabled(IDC_BOOKMARK_ALL_TABS));
 }
 
+TEST_F(BrowserCommandControllerTest,
+       GroupAllUngroupedTabsUserMetricActionEmitted) {
+  base::UserActionTester user_action_tester;
+  chrome::BrowserCommandController command_controller(browser());
+  // We need at least one active tab before we can group all ungrouped tabs.
+  AddTab(browser(), GURL("https://google.com"));
+
+  ASSERT_TRUE(command_controller.IsCommandEnabled(IDC_GROUP_UNGROUPED_TABS));
+
+  command_controller.ExecuteCommand(
+      IDC_GROUP_UNGROUPED_TABS,
+      blink::WebInputEvent::GetStaticTimeStampForTests());
+
+  EXPECT_EQ(
+      1, user_action_tester.GetActionCount("TabGroups_GroupAllUngroupedTabs"));
+}
+
 #if BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_WIN)
 class CreateShortcutBrowserCommandControllerTest
     : public BrowserCommandControllerTest {
