@@ -136,6 +136,9 @@ void BrowserCommandHandler::CanExecuteCommand(
     case Command::kStartPasswordManagerTutorial:
       can_execute = TutorialServiceExists();
       break;
+    case Command::kOpenAutofillSettings:
+      can_execute = true;
+      break;
     case Command::kOpenAISettings:
       can_execute = true;
       break;
@@ -229,6 +232,10 @@ void BrowserCommandHandler::ExecuteCommandWithDisposition(
     case Command::kStartPasswordManagerTutorial:
       StartPasswordManagerTutorial();
       break;
+    case Command::kOpenAutofillSettings:
+      NavigateToURL(GURL(chrome::GetSettingsUrl(chrome::kAutofillSubPage)),
+                    disposition);
+      break;
     case Command::kOpenAISettings:
       OpenAISettings();
       break;
@@ -368,7 +375,8 @@ void BrowserCommandHandler::OpenGlic() {
 
   glic_service->window_controller().Toggle(
       browser_window, /*prevent_close=*/false,
-      glic::mojom::InvocationSource::kWhatsNew);
+      glic::mojom::InvocationSource::kWhatsNew,
+      /*prompt_suggestion=*/std::nullopt);
 #endif  // BUILDFLAG(ENABLE_GLIC)
 }
 
@@ -413,7 +421,7 @@ void BrowserCommandHandler::PrewarmGlicFre() {
 void BrowserCommandHandler::OpenSplitView() {
   tabs::TabInterface* tab =
       tabs::TabInterface::MaybeGetFromContents(web_contents_);
-  if (tab) {
+  if (tab && !tab->IsSplit()) {
     chrome::NewSplitTab(tab->GetBrowserWindowInterface(),
                         split_tabs::SplitTabCreatedSource::kWhatsNew);
   }
