@@ -21,6 +21,8 @@
 #include "chrome/browser/extensions/cws_info_service_factory.h"
 #include "chrome/browser/profiles/profile.h"
 #include "chrome/browser/signin/identity_manager_factory.h"
+#include "chrome/browser/ui/promos/ios_promo_trigger_service.h"
+#include "chrome/browser/ui/promos/ios_promo_trigger_service_factory.h"
 #include "chrome/browser/ui/safety_hub/extensions_result.h"
 #include "chrome/browser/ui/safety_hub/menu_notification_service_factory.h"
 #include "chrome/browser/ui/safety_hub/notification_permission_review_service.h"
@@ -51,6 +53,7 @@
 #include "components/permissions/constants.h"
 #include "components/safe_browsing/core/common/features.h"
 #include "components/safe_browsing/core/common/safe_browsing_prefs.h"
+#include "components/sharing_message/features.h"
 #include "components/signin/public/base/consent_level.h"
 #include "components/signin/public/identity_manager/identity_manager.h"
 #include "components/site_engagement/content/site_engagement_service.h"
@@ -172,6 +175,7 @@ SafetyHubHandler::SafetyHubHandler(Profile* profile)
     : profile_(profile), clock_(base::DefaultClock::GetInstance()) {
   prefs_observation_.Observe(ExtensionPrefs::Get(profile_));
   extension_registry_observation_.Observe(ExtensionRegistry::Get(profile_));
+  pref_change_registrar_.Init(profile_->GetPrefs());
 }
 SafetyHubHandler::~SafetyHubHandler() = default;
 
@@ -824,3 +828,6 @@ void SafetyHubHandler::SetTriggeringExtensionForTesting(
 void SafetyHubHandler::OnJavascriptAllowed() {}
 
 void SafetyHubHandler::OnJavascriptDisallowed() {}
+
+void SafetyHubHandler::OnSafeBrowsingEnhancedChanged() {
+}
