@@ -20,11 +20,12 @@
 #include "base/task/sequenced_task_runner.h"
 #include "base/time/time.h"
 #include "base/values.h"
-#include "commerce_types.h"
 #include "components/bookmarks/browser/bookmark_model.h"
+#include "components/commerce/core/account_checker.h"
 #include "components/commerce/core/bookmark_update_manager.h"
 #include "components/commerce/core/commerce_constants.h"
 #include "components/commerce/core/commerce_feature_list.h"
+#include "components/commerce/core/commerce_types.h"
 #include "components/commerce/core/commerce_utils.h"
 #include "components/commerce/core/compare/cluster_manager.h"
 #include "components/commerce/core/compare/cluster_server_proxy.h"
