@@ -10,7 +10,6 @@
 #include <utility>
 
 #include "base/containers/contains.h"
-#include "components/password_manager/core/browser/features/password_features.h"
 #include "components/password_manager/core/browser/hash_password_manager.h"
 #include "components/password_manager/core/browser/password_form.h"
 #include "components/password_manager/core/browser/password_hash_data.h"
@@ -152,12 +151,8 @@ void PasswordReuseDetectorImpl::CheckReuse(
   std::vector<MatchingReusedCredential> matching_reused_credentials;
 
   std::pair<uint64_t, size_t> hash_and_pwd_len =
-      base::FeatureList::IsEnabled(
-          features::kReuseDetectionBasedOnPasswordHashes)
-          ? CheckSavedPasswordReuseBasedOnHash(input, domain,
-                                               &matching_reused_credentials)
-          : CheckSavedPasswordReuse(input, domain,
-                                    &matching_reused_credentials);
+      CheckSavedPasswordReuseBasedOnHash(input, domain,
+                                         &matching_reused_credentials);
 
   size_t max_reused_password_length =
       std::max({hash_and_pwd_len.second, gaia_reused_password_length,
@@ -301,66 +296,6 @@ PasswordReuseDetectorImpl::CheckSavedPasswordReuseBasedOnHash(
   return {reused_saved_password_hash, longest_match_len};
 }
 
-std::pair<uint64_t, size_t> PasswordReuseDetectorImpl::CheckSavedPasswordReuse(
-    const std::u16string& input,
-    const std::string& domain,
-    std::vector<MatchingReusedCredential>* matching_reused_credentials_out) {
-  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
-  const std::string registry_controlled_domain =
-      GetRegistryControlledDomain(GURL(domain));
-
-  // More than one password call match |input| if they share a common suffix
-  // with |input|.  Collect the set of MatchingReusedCredential for all matches.
-  std::set<MatchingReusedCredential> matching_reused_credentials_set;
-
-  // The longest password match is kept for metrics.
-  size_t longest_match_len = 0;
-
-  // The reused saved password.
-  std::u16string reused_saved_password;
-
-  for (auto passwords_iterator = FindFirstSavedPassword(input);
-       passwords_iterator != passwords_with_matching_reused_credentials_.end();
-       passwords_iterator = FindNextSavedPassword(input, passwords_iterator)) {
-    const std::set<MatchingReusedCredential>& credentials =
-        passwords_iterator->second;
-    DCHECK(!credentials.empty());
-
-    std::set<std::string> domains;
-    for (const auto& credential : credentials) {
-      domains.insert(GetRegistryControlledDomain(credential.url));
-    }
-    // If the page's URL matches a saved domain for this password,
-    // this isn't password-reuse.
-    if (base::Contains(domains, registry_controlled_domain)) {
-      continue;
-    }
-
-    matching_reused_credentials_set.insert(credentials.begin(),
-                                           credentials.end());
-    DCHECK(!passwords_iterator->first.empty());
-    if (passwords_iterator->first.size() > longest_match_len) {
-      longest_match_len = passwords_iterator->first.size();
-      reused_saved_password = passwords_iterator->first;
-    }
-  }
-
-  matching_reused_credentials_out->reserve(
-      matching_reused_credentials_set.size());
-  for (auto it = matching_reused_credentials_set.begin();
-       it != matching_reused_credentials_set.end();) {
-    matching_reused_credentials_out->push_back(
-        std::move(matching_reused_credentials_set.extract(it++).value()));
-  }
-
-  if (longest_match_len != 0) {
-    return {CalculatePasswordHash(reused_saved_password, std::string()),
-            longest_match_len};
-  }
-
-  return {0, 0};
-}
-
 void PasswordReuseDetectorImpl::UseGaiaPasswordHash(
     std::optional<std::vector<PasswordHashData>> password_hash_data_list) {
   DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
@@ -433,17 +368,11 @@ void PasswordReuseDetectorImpl::AddPassword(const PasswordForm& form) {
     return;
   }
 
-  if (base::FeatureList::IsEnabled(
-          features::kReuseDetectionBasedOnPasswordHashes)) {
-    uint64_t password_hash = CalculatePasswordHash(form.password_value, salt_);
-    password_hashes_with_matching_reused_credentials_[password_hash]
-        .matching_credentials.insert(MatchingReusedCredential(form));
-    password_hashes_with_matching_reused_credentials_[password_hash]
-        .password_length = form.password_value.size();
-  } else {
-    passwords_with_matching_reused_credentials_[form.password_value].insert(
-        MatchingReusedCredential(form));
-  }
+  uint64_t password_hash = CalculatePasswordHash(form.password_value, salt_);
+  password_hashes_with_matching_reused_credentials_[password_hash]
+      .matching_credentials.insert(MatchingReusedCredential(form));
+  password_hashes_with_matching_reused_credentials_[password_hash]
+      .password_length = form.password_value.size();
 }
 
 void PasswordReuseDetectorImpl::RemovePassword(const PasswordForm& form) {
@@ -479,10 +408,6 @@ void PasswordReuseDetectorImpl::RemovePassword(const PasswordForm& form) {
     }
   }
 
-  if (!base::FeatureList::IsEnabled(
-          features::kReuseDetectionBasedOnPasswordHashes)) {
-    return;
-  }
   uint64_t password_hash = CalculatePasswordHash(form.password_value, salt_);
   auto password_hash_iterator =
       password_hashes_with_matching_reused_credentials_.find(password_hash);
@@ -526,10 +451,6 @@ void PasswordReuseDetectorImpl::RemoveAllLoginsByStoreType(
       ++i;
     }
   }
-  if (!base::FeatureList::IsEnabled(
-          features::kReuseDetectionBasedOnPasswordHashes)) {
-    return;
-  }
   for (auto i = password_hashes_with_matching_reused_credentials_.begin();
        i != password_hashes_with_matching_reused_credentials_.end();) {
     // Remove all the matching credentials from the corresponding store.
@@ -592,15 +513,8 @@ PasswordReuseDetectorImpl::FindNextSavedPassword(
 size_t PasswordReuseDetectorImpl::SavedPasswordsCount() {
   DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   size_t count = 0;
-  if (base::FeatureList::IsEnabled(
-          features::kReuseDetectionBasedOnPasswordHashes)) {
-    for (const auto& pair : password_hashes_with_matching_reused_credentials_) {
-      count += pair.second.matching_credentials.size();
-    }
-  } else {
-    for (const auto& pair : passwords_with_matching_reused_credentials_) {
-      count += pair.second.size();
-    }
+  for (const auto& pair : password_hashes_with_matching_reused_credentials_) {
+    count += pair.second.matching_credentials.size();
   }
 
   return count;
