@@ -11,7 +11,7 @@
 #include "base/feature_list.h"
 #include "base/gtest_prod_util.h"
 #include "base/memory/raw_ptr.h"
-#include "base/memory/ref_counted.h"
+#include "base/memory/scoped_refptr.h"
 #include "base/memory/weak_ptr.h"
 #include "base/scoped_observation.h"
 #include "base/sequence_checker.h"
@@ -60,6 +60,7 @@ using password_manager::metrics_util::PasswordType;
 // HostContentSettingsMap instance.
 class PasswordProtectionServiceBase : public history::HistoryServiceObserver {
  public:
+  using OtpPhishingVerdictCallback = base::OnceCallback<void(bool)>;
   // Creates an instance with various fields set. Needs pref_service to get safe
   // browsing protection level, is_off_the_record to check for incognito,
   // identity_manager to verify that the user is signed in, and token_fetcher to
@@ -111,6 +112,10 @@ class PasswordProtectionServiceBase : public history::HistoryServiceObserver {
       ReusedPasswordAccountType password_type,
       LoginReputationClientResponse::VerdictType verdict_type);
 
+  // If we should run otp phishing verdict callback.
+  bool ShouldRunOtpPhishingVerdictCallback(
+      LoginReputationClientRequest::TriggerType trigger_type) const;
+
   // Shows modal warning dialog on the current |web_contents| and pass the
   // |verdict_token| to callback of this dialog.
   virtual void ShowModalWarning(
@@ -365,6 +370,9 @@ class PasswordProtectionServiceBase : public history::HistoryServiceObserver {
   // Set of PasswordProtectionRequests that are triggering modal warnings.
   std::set<scoped_refptr<PasswordProtectionRequest>> warning_requests_;
 
+  // Callback for otp phishing verdict.
+  std::optional<OtpPhishingVerdictCallback> otp_phishing_verdict_callback_;
+
   // The username of the account which password has been reused on. It is only
   // set once a modal warning or interstitial is verified to be shown.
   std::string username_for_last_shown_warning_ = "";
@@ -393,6 +401,8 @@ class PasswordProtectionServiceBase : public history::HistoryServiceObserver {
                            TestCleanUpExpiredVerdict);
   FRIEND_TEST_ALL_PREFIXES(PasswordProtectionServiceTest,
                            NoSendPingPrivateIpHostname);
+  FRIEND_TEST_ALL_PREFIXES(PasswordProtectionServiceBaseTest,
+                           VerifyShouldRunOtpPhishingVerdictCallback);
 
   // Overridden from history::HistoryServiceObserver.
   void OnHistoryDeletions(history::HistoryService* history_service,
