@@ -159,7 +159,8 @@ void CaptivePortalBlockingPage::PopulateInterstitialStrings(
   } else {
     // Portal redirection was done with HTTP redirects, so show the login URL.
     // If |languages| is empty, punycode in |login_host| will always be decoded.
-    std::u16string login_host = url_formatter::IDNToUnicode(login_url_.host());
+    std::u16string login_host =
+        url_formatter::IDNToUnicode(login_url_.GetHost());
     if (base::i18n::IsRTL())
       base::i18n::WrapStringWithLTRFormatting(&login_host);
 
