@@ -1660,61 +1660,3 @@ TEST_F(AccountTrackerServiceTest,
       testing::ElementsAre(base::Bucket(1, 1)));
 }
 #endif
-
-TEST_F(AccountTrackerServiceTest, CapabilityPrefNameMigration) {
-  base::ScopedTempDir scoped_user_data_dir;
-  ASSERT_TRUE(scoped_user_data_dir.CreateUniqueTempDir());
-
-  // Create a tracker and add an account. This should cause the account to be
-  // saved to persistence.
-  ResetAccountTrackerWithPersistence(scoped_user_data_dir.GetPath());
-  SimulateTokenAvailable(kAccountKeyAlpha);
-  ReturnAccountInfoFetchSuccess(kAccountKeyAlpha);
-
-  // The capability is unknown, and none of the capability-related keys should
-  // be set.
-  EXPECT_EQ(
-      signin::Tribool::kUnknown,
-      account_tracker()
-          ->GetAccountInfo(AccountKeyToAccountId(kAccountKeyAlpha))
-          .capabilities
-          .can_show_history_sync_opt_ins_without_minor_mode_restrictions());
-  ScopedListPrefUpdate update(prefs(), prefs::kAccountInfo);
-  ASSERT_FALSE(update->empty());
-  base::Value::Dict* dict = (*update)[0].GetIfDict();
-  ASSERT_TRUE(dict);
-  const char kDeprecatedCapabilityKey[] =
-      "accountcapabilities.can_offer_extended_chrome_sync_promos";
-  const char kNewCapabilityKey[] =
-      "accountcapabilities.accountcapabilities/gi2tklldmfya";
-  // The deprecated key is not set.
-  EXPECT_FALSE(dict->FindIntByDottedPath(kDeprecatedCapabilityKey));
-  EXPECT_TRUE(dict->FindIntByDottedPath(kNewCapabilityKey));
-
-  // Set the capability using the deprecated key, and reload the account.
-  dict->SetByDottedPath(kDeprecatedCapabilityKey, 1);
-  dict->RemoveByDottedPath(kNewCapabilityKey);
-  ClearAccountTrackerEvents();
-  ResetAccountTrackerWithPersistence(scoped_user_data_dir.GetPath());
-  EXPECT_TRUE(CheckAccountTrackerEvents(
-      {TrackingEvent(UPDATED, AccountKeyToAccountId(kAccountKeyAlpha),
-                     AccountKeyToGaiaId(kAccountKeyAlpha),
-                     AccountKeyToEmail(kAccountKeyAlpha))}));
-
-  // Check that the migration happened.
-  std::vector<AccountInfo> infos = account_tracker()->GetAccounts();
-  ASSERT_EQ(1u, infos.size());
-  CheckAccountDetails(kAccountKeyAlpha, infos[0]);
-  // The deprecated key has been read.
-  EXPECT_EQ(
-      signin::Tribool::kTrue,
-      infos[0]
-          .capabilities
-          .can_show_history_sync_opt_ins_without_minor_mode_restrictions());
-  // The deprecated key has been removed.
-  EXPECT_FALSE(dict->FindIntByDottedPath(kDeprecatedCapabilityKey));
-  // The new key has been written.
-  std::optional<int> new_key = dict->FindIntByDottedPath(kNewCapabilityKey);
-  ASSERT_TRUE(new_key.has_value());
-  EXPECT_EQ(static_cast<int>(signin::Tribool::kTrue), new_key.value());
-}
