@@ -62,6 +62,7 @@
 #include "chrome/browser/sessions/session_service_factory.h"
 #include "chrome/browser/sessions/tab_restore_service_factory.h"
 #include "chrome/browser/shortcuts/chrome_webloc_file.h"
+#include "chrome/browser/tab_group_sync/tab_group_sync_service_factory.h"
 #include "chrome/browser/task_manager/task_manager_metrics_recorder.h"
 #include "chrome/browser/ui/browser.h"
 #include "chrome/browser/ui/browser_command_controller.h"
@@ -73,6 +74,7 @@
 #include "chrome/browser/ui/browser_mac.h"
 #include "chrome/browser/ui/browser_window.h"
 #include "chrome/browser/ui/browser_window/public/browser_window_features.h"
+#include "chrome/browser/ui/browser_window/public/browser_window_interface_iterator.h"
 #include "chrome/browser/ui/chrome_pages.h"
 #include "chrome/browser/ui/cocoa/apps/quit_with_apps_controller_mac.h"
 #import "chrome/browser/ui/cocoa/bookmarks/bookmark_menu_bridge.h"
@@ -82,6 +84,7 @@
 #import "chrome/browser/ui/cocoa/history_menu_bridge.h"
 #import "chrome/browser/ui/cocoa/profiles/profile_menu_controller.h"
 #import "chrome/browser/ui/cocoa/share_menu_controller.h"
+#import "chrome/browser/ui/cocoa/tab_group_menu_bridge.h"
 #import "chrome/browser/ui/cocoa/tab_menu_bridge.h"
 #include "chrome/browser/ui/extensions/application_launch.h"
 #include "chrome/browser/ui/profiles/profile_picker.h"
@@ -92,6 +95,7 @@
 #include "chrome/browser/ui/startup/startup_types.h"
 #include "chrome/browser/ui/tabs/tab_enums.h"
 #include "chrome/browser/ui/tabs/tab_strip_model.h"
+#include "chrome/browser/ui/ui_features.h"
 #include "chrome/browser/web_applications/web_app_helpers.h"
 #include "chrome/common/chrome_paths_internal.h"
 #include "chrome/common/chrome_switches.h"
@@ -299,14 +303,19 @@ void ConfigureNSAppForKioskMode() {
 // Returns the list of windows for all browser windows (excluding apps).
 NSSet<NSWindow*>* GetBrowserWindows() {
   NSMutableSet<NSWindow*>* result = [NSMutableSet set];
-  for (Browser* browser : *BrowserList::GetInstance()) {
-    // When focusing Chrome, don't focus any browser windows associated with
-    // an app (https://crbug.com/40626510).
-    if (browser->is_type_app()) {
-      continue;
-    }
-    [result addObject:browser->window()->GetNativeWindow().GetNativeNSWindow()];
-  }
+  ForEachCurrentBrowserWindowInterfaceOrderedByActivation(
+      [result](BrowserWindowInterface* browser_window_interface) {
+        // When focusing Chrome, don't focus any browser windows associated with
+        // an app (https://crbug.com/40626510).
+        if (browser_window_interface->GetType() ==
+            BrowserWindowInterface::TYPE_APP) {
+          return true;
+        }
+        [result addObject:browser_window_interface->GetWindow()
+                              ->GetNativeWindow()
+                              .GetNativeNSWindow()];
+        return true;
+      });
   return result;
 }
 
@@ -660,6 +669,8 @@ class AppControllerNativeThemeObserver : public ui::NativeThemeObserver {
 
   std::unique_ptr<HistoryMenuBridge> _historyMenuBridge;
 
+  std::unique_ptr<TabGroupMenuBridge> _tabGroupMenuBridge;
+
   // The profile menu, which appears right before the Help menu. It is only
   // available when multiple profiles is enabled.
   ProfileMenuController* __strong _profileMenuController;
@@ -949,7 +960,7 @@ class AppControllerNativeThemeObserver : public ui::NativeThemeObserver {
 
 - (BOOL)runConfirmQuitPanel {
   // If there are no windows, quit immediately.
-  if (BrowserList::GetInstance()->empty() &&
+  if (!GetLastActiveBrowserWindowInterfaceWithAnyProfile() &&
       !AppWindowRegistryUtil::IsAppWindowVisibleInAnyProfile(0)) {
     return YES;
   }
@@ -993,6 +1004,8 @@ class AppControllerNativeThemeObserver : public ui::NativeThemeObserver {
   // deleted first.
   _historyMenuBridge.reset();
 
+  _tabGroupMenuBridge.reset();
+
   // It's safe to delete |_lastProfile| now.
   [self setLastProfile:nullptr];
 
@@ -1055,6 +1068,10 @@ class AppControllerNativeThemeObserver : public ui::NativeThemeObserver {
 
   [self setLastProfile:profile];
   _lastActiveColorProvider = browser->window()->GetColorProvider();
+
+  if (_tabGroupMenuBridge) {
+    _tabGroupMenuBridge->SetActiveBrowser(browser);
+  }
 }
 
 // Called when shutting down or logging out.
@@ -1419,6 +1436,7 @@ class AppControllerNativeThemeObserver : public ui::NativeThemeObserver {
         // Profile-level items that affect how the profile's UI looks should
         // only be available while there is a Profile opened.
         case IDC_SHOW_FULL_URLS:
+        case IDC_SHOW_AI_MODE_OMNIBOX_BUTTON:
         case IDC_SHOW_GOOGLE_LENS_SHORTCUT:
         case IDC_SHOW_SEARCH_TOOLS:
           enable = hasLoadedProfile;
@@ -1982,6 +2000,8 @@ class AppControllerNativeThemeObserver : public ui::NativeThemeObserver {
     _historyMenuBridge->OnProfileWillBeDestroyed();
   }
 
+  _tabGroupMenuBridge.reset();
+
   _profilePrefRegistrar.reset();
 
   NSMenuItem* bookmarkItem = [NSApp.mainMenu itemWithTag:IDC_BOOKMARKS_MENU];
@@ -2036,6 +2056,16 @@ class AppControllerNativeThemeObserver : public ui::NativeThemeObserver {
   _historyMenuBridge = std::make_unique<HistoryMenuBridge>(_lastProfile);
   _historyMenuBridge->BuildMenu();
 
+  if (base::FeatureList::IsEnabled(features::kShowTabGroupsMacSystemMenu)) {
+    auto* tab_group_service =
+        tab_groups::TabGroupSyncServiceFactory::GetForProfile(_lastProfile);
+    if (tab_group_service) {
+      _tabGroupMenuBridge =
+          std::make_unique<TabGroupMenuBridge>(_lastProfile, tab_group_service);
+      _tabGroupMenuBridge->BuildMenu();
+    }
+  }
+
   chrome::BrowserCommandController::
       UpdateSharedCommandsForIncognitoAvailability(
           _menuState.get(), _lastProfile);
