@@ -20,18 +20,13 @@
 #include "build/build_config.h"
 #include "chrome/browser/browser_process.h"
 #include "chrome/browser/browser_process_platform_part.h"
-#include "chrome/browser/policy/profile_policy_connector.h"
-#include "chrome/browser/privacy_sandbox/tracking_protection_settings_factory.h"
 #include "chrome/browser/profiles/profile.h"
 #include "chrome/browser/themes/theme_properties.h"
 #include "chrome/browser/themes/theme_service.h"
 #include "chrome/browser/themes/theme_service_factory.h"
 #include "chrome/browser/ui/browser_window.h"
 #include "chrome/browser/ui/color/chrome_color_id.h"
-#include "chrome/browser/ui/cookie_controls/cookie_controls_service.h"
-#include "chrome/browser/ui/cookie_controls/cookie_controls_service_factory.h"
 #include "chrome/browser/ui/layout_constants.h"
-#include "chrome/browser/ui/webui/ntp/cookie_controls_handler.h"
 #include "chrome/browser/ui/webui/webui_util_desktop.h"
 #include "chrome/common/buildflags.h"
 #include "chrome/common/channel_info.h"
@@ -42,13 +37,8 @@
 #include "chrome/grit/browser_resources.h"
 #include "chrome/grit/generated_resources.h"
 #include "chrome/grit/theme_resources.h"
-#include "components/content_settings/core/common/cookie_controls_enforcement.h"
-#include "components/content_settings/core/common/pref_names.h"
-#include "components/policy/core/common/policy_service.h"
-#include "components/policy/policy_constants.h"
 #include "components/prefs/pref_service.h"
 #include "components/privacy_sandbox/privacy_sandbox_features.h"
-#include "components/privacy_sandbox/tracking_protection_settings.h"
 #include "components/strings/grit/components_strings.h"
 #include "components/strings/grit/privacy_sandbox_strings.h"
 #include "content/public/browser/browser_thread.h"
@@ -104,8 +94,11 @@ SkColor GetThemeColor(const ui::NativeTheme* native_theme,
   SkColor color = cp.GetColor(id);
   // If web contents are being inverted because the system is in high-contrast
   // mode, any system theme colors we use must be inverted too to cancel out.
-  return native_theme->GetPlatformHighContrastColorScheme() ==
-                 ui::NativeTheme::PlatformHighContrastColorScheme::kDark
+  // TODO(pkasting): I'm not sure this conditional is correct anymore.
+  return (native_theme->forced_colors() !=
+              ui::ColorProviderKey::ForcedColors::kNone &&
+          native_theme->preferred_color_scheme() ==
+              ui::NativeTheme::PreferredColorScheme::kDark)
              ? color_utils::InvertColor(color)
              : color;
 }
@@ -134,27 +127,11 @@ std::string GetNewTabBackgroundTilingCSS(
   return ThemeProperties::TilingToString(repeat_mode);
 }
 
-NTPResourceCache::NTPResourceCache(Profile* profile)
-    : profile_(profile), is_swipe_tracking_from_scroll_events_enabled_(false) {
+NTPResourceCache::NTPResourceCache(Profile* profile) : profile_(profile) {
   ThemeServiceFactory::GetForProfile(profile_)->AddObserver(this);
 
-  base::RepeatingClosure callback = base::BindRepeating(
-      &NTPResourceCache::OnPreferenceChanged, base::Unretained(this));
-
-  // Watch for pref changes that cause us to need to invalidate the HTML cache.
-  profile_pref_change_registrar_.Init(profile_->GetPrefs());
-  profile_pref_change_registrar_.Add(prefs::kCookieControlsMode, callback);
-
   // TODO(crbug.com/40677117): Remove the global accessor to NativeTheme.
   theme_observation_.Observe(ui::NativeTheme::GetInstanceForNativeUi());
-
-  policy_change_registrar_ = std::make_unique<policy::PolicyChangeRegistrar>(
-      profile->GetProfilePolicyConnector()->policy_service(),
-      policy::PolicyNamespace(policy::POLICY_DOMAIN_CHROME, std::string()));
-  policy_change_registrar_->Observe(
-      policy::key::kBlockThirdPartyCookies,
-      base::BindRepeating(&NTPResourceCache::OnPolicyChanged,
-                          base::Unretained(this)));
 }
 
 NTPResourceCache::~NTPResourceCache() = default;
@@ -246,14 +223,6 @@ void NTPResourceCache::OnNativeThemeUpdated(ui::NativeTheme* updated_theme) {
   Invalidate();
 }
 
-void NTPResourceCache::OnPreferenceChanged() {
-  // A change occurred to one of the preferences we care about, so flush the
-  // cache.
-  new_tab_incognito_html_ = nullptr;
-  new_tab_css_ = nullptr;
-}
-
-// TODO(dbeam): why must Invalidate() and OnPreferenceChanged() both exist?
 void NTPResourceCache::Invalidate() {
   new_tab_incognito_html_ = nullptr;
   new_tab_incognito_css_ = nullptr;
@@ -270,20 +239,8 @@ void NTPResourceCache::CreateNewTabIncognitoHTML(
   DCHECK(!profile_->IsOffTheRecord());
   DCHECK(profile_->HasAnyOffTheRecordProfile());
 
-  // Cookie controls service returns the same result for all off-the-record
-  // profiles, so it doesn't matter which of them we use.
-  Profile* incognito_profile = profile_->GetAllOffTheRecordProfiles()[0];
-  CookieControlsService* cookie_controls_service =
-      CookieControlsServiceFactory::GetForProfile(incognito_profile);
-
   replacements["incognitoTabDescription"] =
       l10n_util::GetStringUTF8(IDS_NEW_TAB_OTR_SUBTITLE_WITH_READING_LIST);
-
-  privacy_sandbox::TrackingProtectionSettings* tracking_protection_settings =
-      TrackingProtectionSettingsFactory::GetForProfile(incognito_profile);
-  bool is_tracking_protection_3pcd_enabled =
-      tracking_protection_settings->IsTrackingProtection3pcdEnabled();
-
   replacements["incognitoTabHeading"] =
       l10n_util::GetStringUTF8(IDS_NEW_TAB_OTR_TITLE);
   replacements["incognitoTabWarning"] =
@@ -298,14 +255,10 @@ void NTPResourceCache::CreateNewTabIncognitoHTML(
       IDS_INCOGNITO_TAB_LEARN_MORE_ACCESSIBILITY_LABEL);
   replacements["title"] = l10n_util::GetStringUTF8(IDS_NEW_INCOGNITO_TAB_TITLE);
 
-  replacements["cookieControlsHeader"] = "cookie-controls-header";
-  replacements["hideBlockCookiesToggle"] = "hidden";
-  replacements["hideTooltipIcon"] = "hidden";
-  replacements["hideUserBypassIcon"] = "hidden";
-
   if (base::FeatureList::IsEnabled(
           privacy_sandbox::kFingerprintingProtectionUx) ||
       base::FeatureList::IsEnabled(privacy_sandbox::kIpProtectionUx)) {
+    replacements["hideUserBypassIcon"] = "hidden";
     replacements["cookieControlsTitle"] = l10n_util::GetStringUTF8(
         IDS_INCOGNITO_NTP_INCOGNITO_TRACKING_PROTECTIONS_HEADER);
     localized_strings.Set(
@@ -317,8 +270,7 @@ void NTPResourceCache::CreateNewTabIncognitoHTML(
                 IDS_INCOGNITO_NTP_INCOGNITO_TRACKING_PROTECTIONS_LINK_A11Y_LABEL),
             l10n_util::GetStringUTF16(
                 IDS_INCOGNITO_NTP_INCOGNITO_TRACKING_PROTECTIONS_LINK_A11Y_DESCRIPTION)));
-  } else if (base::FeatureList::IsEnabled(
-                 privacy_sandbox::kAlwaysBlock3pcsIncognito)) {
+  } else {
     replacements["hideUserBypassIcon"] = "";
     replacements["cookieControlsTitle"] = l10n_util::GetStringUTF8(
         IDS_INCOGNITO_NTP_BLOCK_THIRD_PARTY_COOKIES_HEADER);
@@ -329,36 +281,9 @@ void NTPResourceCache::CreateNewTabIncognitoHTML(
             chrome::kUserBypassHelpCenterURL,
             l10n_util::GetStringUTF16(
                 IDS_NEW_TAB_OPENS_HC_ARTICLE_IN_NEW_TAB)));
-  } else if (is_tracking_protection_3pcd_enabled) {
-    replacements["cookieControlsHeader"] = "cookie-controls-title";
-    replacements["cookieControlsTitle"] =
-        l10n_util::GetStringUTF8(IDS_NEW_TAB_OTR_THIRD_PARTY_BLOCKED_COOKIE);
-    localized_strings.Set(
-        "cookieControlsDescription",
-        l10n_util::GetStringFUTF16(
-            IDS_NEW_TAB_OTR_THIRD_PARTY_BLOCKED_COOKIE_SUBLABEL,
-            chrome::kUserBypassHelpCenterURL,
-            l10n_util::GetStringUTF16(
-                IDS_NEW_TAB_OPENS_HC_ARTICLE_IN_NEW_TAB)));
-  } else {
-    replacements["cookieControlsTitle"] =
-        l10n_util::GetStringUTF8(IDS_NEW_TAB_OTR_THIRD_PARTY_COOKIE);
-    replacements["cookieControlsHeader"] = "cookie-controls-title";
-    replacements["hideBlockCookiesToggle"] = "";
-    replacements["hideTooltipIcon"] =
-        cookie_controls_service->ShouldEnforceCookieControls() ? "" : "hidden";
-    replacements["cookieControlsDescription"] =
-        l10n_util::GetStringUTF8(IDS_NEW_TAB_OTR_THIRD_PARTY_COOKIE_SUBLABEL);
   }
 
-  replacements["cookieControlsToggleChecked"] =
-      cookie_controls_service->GetToggleCheckedValue() ? "checked" : "";
-  replacements["cookieControlsToolTipIcon"] =
-      CookieControlsHandler::GetEnforcementIcon(
-          cookie_controls_service->GetCookieControlsEnforcement());
-  replacements["cookieControlsTooltipText"] = l10n_util::GetStringUTF8(
-      IDS_NEW_TAB_OTR_COOKIE_CONTROLS_CONTROLLED_TOOLTIP_TEXT);
-
+  Profile* incognito_profile = profile_->GetAllOffTheRecordProfiles()[0];
   const ui::ThemeProvider& tp =
       ThemeService::GetThemeProviderForProfile(incognito_profile);
 
@@ -551,8 +476,3 @@ void NTPResourceCache::CreateNewTabCSS(
   new_tab_css_ = base::MakeRefCounted<base::RefCountedString>(
       ReplaceTemplateExpressions(*new_tab_theme_css, substitutions));
 }
-
-void NTPResourceCache::OnPolicyChanged(const base::Value* previous,
-                                       const base::Value* current) {
-  new_tab_incognito_html_ = nullptr;
-}
