@@ -107,7 +107,7 @@
 #endif
 
 #if BUILDFLAG(ENABLE_GLIC)
-#include "chrome/browser/glic/browser_ui/glic_tab_underline_view.h"
+#include "chrome/browser/glic/browser_ui/tab_underline_view.h"
 #endif
 
 using base::UserMetricsAction;
@@ -160,7 +160,7 @@ class TabStyleHighlightPathGenerator : public views::HighlightPathGenerator {
 
   // views::HighlightPathGenerator:
   SkPath GetHighlightPath(const views::View* view) override {
-    return tab_style_views_->GetPath(TabStyle::PathType::kHighlight, 1.0);
+    return tab_style_views_->GetPath(TabStyle::PathType::kHighlight, 1.0, {});
   }
 
  private:
@@ -262,9 +262,9 @@ Tab::Tab(TabSlotController* controller)
       glic::GlicEnabling::IsProfileEligible(
           controller_->GetBrowser()->GetProfile())) {
     glic_tab_underline_view_ = AddChildView(
-        views::Builder<glic::GlicTabUnderlineView>(
-            glic::GlicTabUnderlineView::Factory::Create(
-                controller->GetBrowser(), this))
+        views::Builder<glic::TabUnderlineView>(
+            glic::TabUnderlineView::Factory::Create(controller->GetBrowser(),
+                                                    this))
             // Needed so that expectations of visibility that
             // inform underline updates are correct on first show.
             .SetVisible(false)
@@ -343,7 +343,7 @@ bool Tab::GetHitTestMask(SkPath* mask) const {
   *mask = tab_style_views()->GetPath(
       TabStyle::PathType::kHitTest,
       GetWidget()->GetCompositor()->device_scale_factor(),
-      /* force_active */ false, TabStyle::RenderUnits::kDips);
+      {.render_units = TabStyle::RenderUnits::kDips});
   return true;
 }
 
@@ -452,6 +452,7 @@ void Tab::Layout(PassKey) {
     }
     alert_indicator_button_->SetBoundsRect(bounds);
   }
+  alert_indicator_button_->UpdateAlertIndicatorAnimation();
   alert_indicator_button_->SetVisible(showing_alert_indicator_);
 
   // Size the title to fill the remaining width and use all available height.
@@ -609,7 +610,7 @@ void Tab::OnMouseReleased(const ui::MouseEvent& event) {
   // In some cases, ending the drag will schedule the tab for destruction; if
   // so, bail immediately, since our members are already dead and we shouldn't
   // do anything else except drop the tab where it is.
-  if (controller_->EndDrag(END_DRAG_COMPLETE)) {
+  if (controller_->EndDrag(EndDragReason::kComplete)) {
     shift_pressed_on_mouse_down_ = false;
     return;
   }
@@ -649,7 +650,7 @@ void Tab::OnMouseReleased(const ui::MouseEvent& event) {
 }
 
 void Tab::OnMouseCaptureLost() {
-  controller_->EndDrag(END_DRAG_CAPTURE_LOST);
+  controller_->EndDrag(EndDragReason::kCaptureLost);
 }
 
 void Tab::OnMouseMoved(const ui::MouseEvent& event) {
@@ -821,7 +822,7 @@ void Tab::PaintChildren(const views::PaintInfo& info) {
   const float paint_recording_scale = info.paint_recording_scale_x();
 
   const SkPath clip_path = tab_style_views()->GetPath(
-      TabStyle::PathType::kInteriorClip, paint_recording_scale);
+      TabStyle::PathType::kInteriorClip, paint_recording_scale, {});
 
   clip_recorder.ClipPathWithAntiAliasing(clip_path);
   View::PaintChildren(info);
