@@ -32,7 +32,6 @@
 #include "components/policy/core/common/policy_pref_names.h"
 #include "components/prefs/pref_service.h"
 #include "components/version_info/version_info.h"
-#include "device/vr/buildflags/buildflags.h"
 #include "net/http/http_util.h"
 #include "third_party/blink/public/common/features.h"
 #include "third_party/blink/public/common/user_agent/user_agent_metadata.h"
@@ -48,7 +47,7 @@
 #include "base/mac/mac_util.h"
 #endif
 
-#if BUILDFLAG(IS_IOS)
+#if BUILDFLAG(IS_IOS) || BUILDFLAG(IS_ANDROID)
 #include "ui/base/device_form_factor.h"
 #endif
 
@@ -56,10 +55,6 @@
 #include <sys/utsname.h>
 #endif
 
-#if BUILDFLAG(IS_ANDROID) && BUILDFLAG(ENABLE_VR)
-#include "device/vr/public/cpp/features.h"
-#endif  // BUILDFLAG(IS_ANDROID) && BUILDFLAG(ENABLE_VR)
-
 namespace embedder_support {
 
 namespace {
@@ -338,7 +333,17 @@ std::string GetUserAgentPlatform() {
 }
 
 std::string GetUnifiedPlatform() {
+#if BUILDFLAG(IS_ANDROID) || BUILDFLAG(IS_LINUX)
+  // This constant is only used on Android (desktop) and Linux.
+  constexpr char kUnifiedPlatformLinuxX64[] = "X11; Linux x86_64";
+#endif
 #if BUILDFLAG(IS_ANDROID)
+  // The Android XR device by default also has the unified platform of desktop
+  // form factor.
+  if (ui::GetDeviceFormFactor() == ui::DEVICE_FORM_FACTOR_DESKTOP ||
+      ui::GetDeviceFormFactor() == ui::DEVICE_FORM_FACTOR_XR) {
+    return kUnifiedPlatformLinuxX64;
+  }
   return "Linux; Android 10; K";
 #elif BUILDFLAG(IS_CHROMEOS)
   return "X11; CrOS x86_64 14541.0.0";
@@ -349,7 +354,7 @@ std::string GetUnifiedPlatform() {
 #elif BUILDFLAG(IS_FUCHSIA)
   return "Fuchsia";
 #elif BUILDFLAG(IS_LINUX)
-  return "X11; Linux x86_64";
+  return kUnifiedPlatformLinuxX64;
 #elif BUILDFLAG(IS_IOS)
   if (ui::GetDeviceFormFactor() == ui::DEVICE_FORM_FACTOR_TABLET) {
     return "iPad; CPU iPad OS 14_0 like Mac OS X";
@@ -591,7 +596,58 @@ blink::UserAgentBrandVersion GetGreasedUserAgentBrandVersion(
                                          output_version_type);
 }
 
+bool GetMobileBitForUAMetadata() {
+  // The mobile bit for UA-CH is true if the platform is iOS, or if it's
+  // Android and not a desktop form factor, AND the kUseMobileUserAgent switch
+  // is present.
+#if BUILDFLAG(IS_ANDROID)
+  if (ui::GetDeviceFormFactor() == ui::DEVICE_FORM_FACTOR_DESKTOP ||
+      ui::GetDeviceFormFactor() == ui::DEVICE_FORM_FACTOR_XR) {
+    return false;
+  }
+#endif
+
+#if BUILDFLAG(IS_ANDROID) || BUILDFLAG(IS_IOS)
+  return base::CommandLine::ForCurrentProcess()->HasSwitch(kUseMobileUserAgent);
+#else
+  return false;
+#endif
+}
+
+std::string GetPlatformVersion() {
+#if BUILDFLAG(IS_LINUX)
+  // TODO(crbug.com/40245146): Remove this Blink feature
+  if (base::FeatureList::IsEnabled(
+          blink::features::kReduceUserAgentDataLinuxPlatformVersion)) {
+    return std::string();
+  }
+#endif
+
+#if BUILDFLAG(IS_ANDROID)
+  if (ui::GetDeviceFormFactor() == ui::DEVICE_FORM_FACTOR_DESKTOP ||
+      ui::GetDeviceFormFactor() == ui::DEVICE_FORM_FACTOR_XR) {
+    return std::string();
+  }
+#endif
+
+#if BUILDFLAG(IS_WIN)
+  return GetWindowsPlatformVersion();
+#else
+
+  int32_t major, minor, bugfix = 0;
+  base::SysInfo::OperatingSystemVersionNumbers(&major, &minor, &bugfix);
+  return base::StringPrintf("%d.%d.%d", major, minor, bugfix);
+#endif
+}
+
 std::string GetPlatformForUAMetadata() {
+#if BUILDFLAG(IS_ANDROID)
+  if (ui::GetDeviceFormFactor() == ui::DEVICE_FORM_FACTOR_DESKTOP ||
+      ui::GetDeviceFormFactor() == ui::DEVICE_FORM_FACTOR_XR) {
+    return "Linux";
+  }
+#endif
+
 #if BUILDFLAG(IS_MAC)
   // TODO(crbug.com/40704421): This can be removed/re-refactored once we use
   // "macOS" by default
@@ -611,21 +667,12 @@ std::string GetPlatformForUAMetadata() {
 }
 
 blink::UserAgentMetadata GetUserAgentMetadata(bool only_low_entropy_ch) {
-  return GetUserAgentMetadata(nullptr, only_low_entropy_ch);
-}
-
-blink::UserAgentMetadata GetUserAgentMetadata(const PrefService* pref_service,
-                                              bool only_low_entropy_ch) {
   blink::UserAgentMetadata metadata;
 
   // Low entropy client hints.
   metadata.brand_version_list =
       GetUserAgentBrandMajorVersionListInternal(std::nullopt);
-  metadata.mobile = false;
-#if BUILDFLAG(IS_ANDROID) || BUILDFLAG(IS_IOS)
-  metadata.mobile =
-      base::CommandLine::ForCurrentProcess()->HasSwitch(kUseMobileUserAgent);
-#endif
+  metadata.mobile = GetMobileBitForUAMetadata();
   metadata.platform = GetPlatformForUAMetadata();
 
   // For users providing a valid user-agent override via the command line:
@@ -654,24 +701,7 @@ blink::UserAgentMetadata GetUserAgentMetadata(const PrefService* pref_service,
   metadata.form_factors = GetFormFactorsClientHint(metadata, metadata.mobile);
   metadata.bitness = GetCpuBitness();
   metadata.wow64 = IsWoW64();
-
-#if BUILDFLAG(IS_WIN)
-  metadata.platform_version = GetWindowsPlatformVersion();
-#else
-  int32_t major, minor, bugfix = 0;
-  base::SysInfo::OperatingSystemVersionNumbers(&major, &minor, &bugfix);
-  metadata.platform_version =
-      base::StringPrintf("%d.%d.%d", major, minor, bugfix);
-#endif
-
-#if BUILDFLAG(IS_LINUX)
-  // TODO(crbug.com/40245146): Remove this Blink feature
-  if (base::FeatureList::IsEnabled(
-          blink::features::kReduceUserAgentDataLinuxPlatformVersion)) {
-    metadata.platform_version = std::string();
-  }
-#endif
-
+  metadata.platform_version = GetPlatformVersion();
   return metadata;
 }
 
@@ -682,11 +712,11 @@ std::vector<std::string> GetFormFactorsClientHint(
   std::vector<std::string> form_factors = {
       is_mobile ? blink::kMobileFormFactor : blink::kDesktopFormFactor};
 
-#if BUILDFLAG(IS_ANDROID) && BUILDFLAG(ENABLE_VR)
-  if (device::features::IsXrDevice()) {
+#if BUILDFLAG(IS_ANDROID)
+  if (ui::GetDeviceFormFactor() == ui::DEVICE_FORM_FACTOR_XR) {
     form_factors.push_back(blink::kXRFormFactor);
   }
-#endif  // BUILDFLAG(IS_ANDROID) && BUILDFLAG(ENABLE_VR)
+#endif  // BUILDFLAG(IS_ANDROID)
   return form_factors;
 }
 
@@ -753,6 +783,13 @@ std::string GetCpuArchitecture() {
 #elif BUILDFLAG(IS_IOS)
   return "arm";
 #elif BUILDFLAG(IS_ANDROID)
+  // TODO(crbug.com/433345971) The user agent string should contain the actual
+  // cpu type information obtained from the Android device. Same for the cpu bit
+  // count in #GetCpuBitness below.
+  if (ui::GetDeviceFormFactor() == ui::DEVICE_FORM_FACTOR_DESKTOP ||
+      ui::GetDeviceFormFactor() == ui::DEVICE_FORM_FACTOR_XR) {
+    return "x86";
+  }
   return std::string();
 #elif BUILDFLAG(IS_POSIX)
   std::string cpu_info = BuildCpuInfo();
@@ -789,6 +826,10 @@ std::string GetCpuBitness() {
 #elif BUILDFLAG(IS_APPLE) || BUILDFLAG(IS_FUCHSIA)
   return "64";
 #elif BUILDFLAG(IS_ANDROID)
+  if (ui::GetDeviceFormFactor() == ui::DEVICE_FORM_FACTOR_DESKTOP ||
+      ui::GetDeviceFormFactor() == ui::DEVICE_FORM_FACTOR_XR) {
+    return "64";
+  }
   return std::string();
 #elif BUILDFLAG(IS_POSIX)
   return base::Contains(BuildCpuInfo(), "64") ? "64" : "32";
@@ -856,15 +897,20 @@ std::string BuildUserAgentFromProduct(const std::string& product) {
 }
 
 std::string BuildModelInfo() {
-  std::string model;
 #if BUILDFLAG(IS_ANDROID)
+  // Model information is not exposed on Android desktop.
+  if (ui::GetDeviceFormFactor() == ui::DEVICE_FORM_FACTOR_DESKTOP) {
+    return std::string();
+  }
+
   // Only send the model information if on the release build of Android,
   // matching user agent behaviour.
   if (base::SysInfo::GetAndroidBuildCodename() == "REL") {
-    model = base::SysInfo::HardwareModelName();
+    return base::SysInfo::HardwareModelName();
   }
 #endif
-  return model;
+
+  return std::string();
 }
 
 #if BUILDFLAG(IS_ANDROID)
