@@ -154,7 +154,7 @@ double GetDeviceScaleFactor() {
 double GetZoomFactor(BrowserContext* context, const GURL& url) {
   double zoom_level = HostZoomMap::GetDefaultForBrowserContext(context)
                           ->GetZoomLevelForHostAndScheme(
-                              url.scheme(), net::GetHostOrSpecFromURL(url));
+                              url.GetScheme(), net::GetHostOrSpecFromURL(url));
 
   if (zoom_level == 0.0) {
     // Get default zoom level.
@@ -402,7 +402,7 @@ void AddRttHeader(net::HttpRequestHeaders* headers,
         net::EFFECTIVE_CONNECTION_TYPE_UNKNOWN);
   }
   SetHeaderToInt(headers, WebClientHintsType::kRtt_DEPRECATED,
-                 RoundRtt(url.host(), http_rtt));
+                 RoundRtt(url.GetHost(), http_rtt));
 }
 
 void AddDownlinkHeader(net::HttpRequestHeaders* headers,
@@ -428,7 +428,7 @@ void AddDownlinkHeader(net::HttpRequestHeaders* headers,
   }
 
   SetHeaderToDouble(headers, WebClientHintsType::kDownlink_DEPRECATED,
-                    RoundKbpsToMbps(url.host(), downlink_throughput_kbps));
+                    RoundKbpsToMbps(url.GetHost(), downlink_throughput_kbps));
 }
 
 void AddEctHeader(net::HttpRequestHeaders* headers,
