@@ -133,13 +133,13 @@ BASE_FEATURE(kPrefixCookieHostHttp, base::FEATURE_ENABLED_BY_DEFAULT);
 BASE_FEATURE(kSearchEnginePreconnectInterval,
              base::FEATURE_DISABLED_BY_DEFAULT);
 
-BASE_FEATURE(kSearchEnginePreconnect2, base::FEATURE_DISABLED_BY_DEFAULT);
+BASE_FEATURE(kSearchEnginePreconnect2, base::FEATURE_ENABLED_BY_DEFAULT);
 
 BASE_FEATURE_PARAM(int,
                    kIdleTimeoutInSeconds,
                    &kSearchEnginePreconnect2,
                    "IdleTimeoutInSeconds",
-                   120);
+                   30);
 
 BASE_FEATURE_PARAM(base::TimeDelta,
                    kShortSessionThreshold,
@@ -156,13 +156,13 @@ BASE_FEATURE_PARAM(int,
                    kPingIntervalInSeconds,
                    &kSearchEnginePreconnect2,
                    "PingIntervalInSeconds",
-                   30);
+                   27);
 
 BASE_FEATURE_PARAM(std::string,
                    kQuicConnectionOptions,
                    &kSearchEnginePreconnect2,
                    "QuicConnectionOptions",
-                   "");
+                   "ECCP");
 
 BASE_FEATURE_PARAM(bool,
                    kFallbackInLowPowerMode,
@@ -170,6 +170,8 @@ BASE_FEATURE_PARAM(bool,
                    "FallbackInLowPowerMode",
                    false);
 
+BASE_FEATURE(kConnectionKeepAliveForHttp2, base::FEATURE_DISABLED_BY_DEFAULT);
+
 BASE_FEATURE(kShortLaxAllowUnsafeThreshold, base::FEATURE_DISABLED_BY_DEFAULT);
 
 BASE_FEATURE(kSameSiteDefaultChecksMethodRigorously,
@@ -222,16 +224,10 @@ BASE_FEATURE(kCookieDomainRejectNonASCII, base::FEATURE_DISABLED_BY_DEFAULT);
 // by the top level site to reduce fingerprinting.
 BASE_FEATURE(kThirdPartyStoragePartitioning, base::FEATURE_ENABLED_BY_DEFAULT);
 
-BASE_FEATURE(kTopLevelTpcdOriginTrial, base::FEATURE_ENABLED_BY_DEFAULT);
-
 BASE_FEATURE(kTpcdTrialSettings,
              "TpcdSupportSettings",
              base::FEATURE_ENABLED_BY_DEFAULT);
 
-BASE_FEATURE(kTopLevelTpcdTrialSettings,
-             "TopLevelTpcdSupportSettings",
-             base::FEATURE_ENABLED_BY_DEFAULT);
-
 BASE_FEATURE(kTpcdMetadataGrants, base::FEATURE_ENABLED_BY_DEFAULT);
 
 BASE_FEATURE(kTpcdMetadataStageControl, base::FEATURE_ENABLED_BY_DEFAULT);
@@ -445,6 +441,12 @@ const base::FeatureParam<bool> kIpPrivacyUseQuicProxiesOnly{
     /*name=*/"IpPrivacyUseQuicProxiesOnly",
     /*default_value=*/false};
 
+const base::FeatureParam<bool>
+    kIpPrivacyUseQuicProxiesWithoutWaitingForConnectResponse{
+        &kEnableIpProtectionProxy,
+        /*name=*/"IpPrivacyUseQuicProxiesWithoutWaitingForConnectResponse",
+        /*default_value=*/false};
+
 const base::FeatureParam<bool> kIpPrivacyFallbackToDirect{
     &kEnableIpProtectionProxy,
     /*name=*/"IpPrivacyFallbackToDirect",
@@ -517,10 +519,6 @@ inline constexpr auto kMigrateSessionsOnNetworkChangeV2Default =
 BASE_FEATURE(kMigrateSessionsOnNetworkChangeV2,
              kMigrateSessionsOnNetworkChangeV2Default);
 
-BASE_FEATURE(kDisableBlackholeOnNoNewNetwork,
-             "DisableBlackHoleOnNoNewNetwork",
-             base::FEATURE_DISABLED_BY_DEFAULT);
-
 #if BUILDFLAG(IS_LINUX)
 BASE_FEATURE(kAddressTrackerLinuxIsProxied, base::FEATURE_ENABLED_BY_DEFAULT);
 #endif  // BUILDFLAG(IS_LINUX)
@@ -568,6 +566,8 @@ BASE_FEATURE(kTruncateBodyToContentLength, base::FEATURE_ENABLED_BY_DEFAULT);
 #if BUILDFLAG(IS_MAC)
 BASE_FEATURE(kReduceIPAddressChangeNotification,
              base::FEATURE_ENABLED_BY_DEFAULT);
+BASE_FEATURE(kUseNetworkPathMonitorForNetworkChangeNotifier,
+             base::FEATURE_DISABLED_BY_DEFAULT);
 #endif  // BUILDFLAG(IS_MAC)
 
 BASE_FEATURE(kDeviceBoundSessions, base::FEATURE_DISABLED_BY_DEFAULT);
@@ -591,12 +591,12 @@ BASE_FEATURE_PARAM(int,
                    kDeviceBoundSessionsSchemaVersion,
                    &kDeviceBoundSessions,
                    "SchemaVersion",
-                   1);
+                   2);
 BASE_FEATURE_PARAM(bool,
                    kDeviceBoundSessionsOriginTrialFeedback,
                    &kDeviceBoundSessions,
                    "OriginTrialFeedback",
-                   false);
+                   true);
 
 BASE_FEATURE(kDeviceBoundSessionsFederatedRegistration,
              base::FEATURE_DISABLED_BY_DEFAULT);
@@ -606,6 +606,17 @@ BASE_FEATURE_PARAM(bool,
                    "CheckWellKnown",
                    true);
 
+BASE_FEATURE(kDeviceBoundSessionProactiveRefresh,
+             base::FEATURE_ENABLED_BY_DEFAULT);
+BASE_FEATURE_PARAM(base::TimeDelta,
+                   kDeviceBoundSessionProactiveRefreshThreshold,
+                   &kDeviceBoundSessionProactiveRefresh,
+                   "Threshold",
+                   base::Seconds(120));
+
+BASE_FEATURE(kDeviceBoundSessionSigningQuotaAndCaching,
+             base::FEATURE_ENABLED_BY_DEFAULT);
+
 BASE_FEATURE(kSpdySessionForProxyAdditionalChecks,
              base::FEATURE_ENABLED_BY_DEFAULT);
 
@@ -641,7 +652,12 @@ constexpr base::FeatureParam<DiskCacheBackend>::Option
 #endif  // ENABLE_DISK_CACHE_SQL_BACKEND
 };
 const base::FeatureParam<DiskCacheBackend> kDiskCacheBackendParam{
-    &kDiskCacheBackendExperiment, "backend", DiskCacheBackend::kDefault,
+    &kDiskCacheBackendExperiment, "backend",
+#if BUILDFLAG(ENABLE_DISK_CACHE_SQL_BACKEND)
+    DiskCacheBackend::kSql,
+#else   // ENABLE_DISK_CACHE_SQL_BACKEND
+    DiskCacheBackend::kDefault,
+#endif  // ENABLE_DISK_CACHE_SQL_BACKEND
     &kDiskCacheBackendOptions};
 
 #if BUILDFLAG(ENABLE_DISK_CACHE_SQL_BACKEND)
@@ -655,6 +671,21 @@ BASE_FEATURE_PARAM(int,
                    &kDiskCacheBackendExperiment,
                    "SqlDiskCacheIdleCheckpointThreshold",
                    1000);
+BASE_FEATURE_PARAM(int,
+                   kSqlDiskCacheOptimisticWriteBufferSize,
+                   &kDiskCacheBackendExperiment,
+                   "SqlDiskCacheOptimisticWriteBufferSize",
+                   32 * 1024 * 1024);
+BASE_FEATURE_PARAM(bool,
+                   kSqlDiskCacheSynchronousOff,
+                   &kDiskCacheBackendExperiment,
+                   "SqlDiskCacheSynchronousOff",
+                   false);
+BASE_FEATURE_PARAM(int,
+                   kSqlDiskCacheShardCount,
+                   &kDiskCacheBackendExperiment,
+                   "SqlDiskCacheShardCount",
+                   3);
 #endif  // ENABLE_DISK_CACHE_SQL_BACKEND
 
 BASE_FEATURE(kIgnoreHSTSForLocalhost, base::FEATURE_ENABLED_BY_DEFAULT);
@@ -680,7 +711,8 @@ BASE_FEATURE(kHttpCacheMappedFileFlushWin, base::FEATURE_DISABLED_BY_DEFAULT);
 #endif
 
 BASE_FEATURE(kHttpCacheNoVarySearch,
-#if BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX)
+#if BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX) || \
+    BUILDFLAG(IS_CHROMEOS)
              base::FEATURE_ENABLED_BY_DEFAULT
 #else
              base::FEATURE_DISABLED_BY_DEFAULT
@@ -703,7 +735,10 @@ BASE_FEATURE_PARAM(bool,
                    kHttpCacheNoVarySearchKeepNotSuitable,
                    &kHttpCacheNoVarySearch,
                    "keep_not_suitable",
-                   false);
+                   true);
+
+BASE_FEATURE(kHttpNoVarySearchDataUseNewAreEquivalent,
+             base::FEATURE_DISABLED_BY_DEFAULT);
 
 BASE_FEATURE(kReportingApiCorsOriginHeader, base::FEATURE_ENABLED_BY_DEFAULT);
 
@@ -725,20 +760,32 @@ BASE_FEATURE(kRestrictAbusePortsOnLocalhost, base::FEATURE_ENABLED_BY_DEFAULT);
 
 BASE_FEATURE(kTLSTrustAnchorIDs, base::FEATURE_DISABLED_BY_DEFAULT);
 
-BASE_FEATURE(kSocketPoolSizePerTopLevelSiteTrial,
+BASE_FEATURE(kTcpSocketPoolLimitRandomization,
              base::FEATURE_DISABLED_BY_DEFAULT);
 
-BASE_FEATURE_PARAM(int,
-                   kSocketPoolSizePerTopLevelSiteTrialNormalProfileLimit,
-                   &kSocketPoolSizePerTopLevelSiteTrial,
-                   "SocketPoolSizePerTopLevelSiteTrialNormalProfileLimit",
-                   256);
+BASE_FEATURE_PARAM(double,
+                   kTcpSocketPoolLimitRandomizationBase,
+                   &kTcpSocketPoolLimitRandomization,
+                   "TcpSocketPoolLimitRandomizationBase",
+                   0.0);
 
 BASE_FEATURE_PARAM(int,
-                   kSocketPoolSizePerTopLevelSiteTrialWebSocketProfileLimit,
-                   &kSocketPoolSizePerTopLevelSiteTrial,
-                   "SocketPoolSizePerTopLevelSiteTrialWebSocketProfileLimit",
-                   256);
+                   kTcpSocketPoolLimitRandomizationCapacity,
+                   &kTcpSocketPoolLimitRandomization,
+                   "TcpSocketPoolLimitRandomizationCapacity",
+                   0);
+
+BASE_FEATURE_PARAM(double,
+                   kTcpSocketPoolLimitRandomizationMinimum,
+                   &kTcpSocketPoolLimitRandomization,
+                   "TcpSocketPoolLimitRandomizationMinimum",
+                   0.0);
+
+BASE_FEATURE_PARAM(double,
+                   kTcpSocketPoolLimitRandomizationNoise,
+                   &kTcpSocketPoolLimitRandomization,
+                   "TcpSocketPoolLimitRandomizationNoise",
+                   0.0);
 
 BASE_FEATURE(kNetTaskScheduler, base::FEATURE_ENABLED_BY_DEFAULT);
 BASE_FEATURE_PARAM(bool,
@@ -746,16 +793,6 @@ BASE_FEATURE_PARAM(bool,
                    &kNetTaskScheduler,
                    "http_proxy_connect_job",
                    true);
-BASE_FEATURE_PARAM(bool,
-                   kNetTaskSchedulerHttpCache,
-                   &kNetTaskScheduler,
-                   "http_cache",
-                   false);
-BASE_FEATURE_PARAM(bool,
-                   kNetTaskSchedulerHttpCacheTransaction,
-                   &kNetTaskScheduler,
-                   "http_cache_transaction",
-                   false);
 BASE_FEATURE_PARAM(bool,
                    kNetTaskSchedulerHttpStreamFactoryJob,
                    &kNetTaskScheduler,
@@ -787,6 +824,18 @@ BASE_FEATURE_PARAM(bool,
                    "url_request_redirect_job",
                    true);
 
+BASE_FEATURE(kNetTaskScheduler2, base::FEATURE_DISABLED_BY_DEFAULT);
+BASE_FEATURE_PARAM(bool,
+                   kNetTaskSchedulerHttpCache,
+                   &kNetTaskScheduler2,
+                   "http_cache",
+                   false);
+BASE_FEATURE_PARAM(bool,
+                   kNetTaskSchedulerHttpCacheTransaction,
+                   &kNetTaskScheduler2,
+                   "http_cache_transaction",
+                   false);
+
 BASE_FEATURE(kAdditionalDelayMainJob, base::FEATURE_DISABLED_BY_DEFAULT);
 BASE_FEATURE_PARAM(base::TimeDelta,
                    kAdditionalDelay,
@@ -852,4 +901,7 @@ BASE_FEATURE_PARAM(std::string,
                    "quic_options",
                    "");
 
+BASE_FEATURE(kDnsResponseDiscardPartialQuestions,
+             base::FEATURE_ENABLED_BY_DEFAULT);
+
 }  // namespace net::features
