@@ -6,7 +6,6 @@
 
 #include "base/feature_list.h"
 #include "build/build_config.h"
-#include "ui/base/ui_base_features.h"
 
 #if BUILDFLAG(IS_ANDROID)
 #include "base/android/feature_map.h"
@@ -171,17 +170,6 @@ BASE_FEATURE(kMostVisitedTilesHorizontalRenderGroup,
 // accommodate the autocompletions.
 BASE_FEATURE(kRichAutocompletion, "OmniboxRichAutocompletion", ENABLED);
 
-// If enabled, removes the cutout for the location bar and fills the entire
-// popup content with the WebUI WebView.
-BASE_FEATURE(kWebUIOmniboxFullPopup, DISABLED);
-// If enabled, shows the omnibox suggestions in the popup in WebUI.
-BASE_FEATURE(kWebUIOmniboxPopup, DISABLED);
-// Enables the WebUI for omnibox suggestions without modifying the popup UI.
-BASE_FEATURE(kWebUIOmniboxPopupDebug, DISABLED);
-// Enables side-by-side comparison omnibox suggestions in WebUI and Views.
-const base::FeatureParam<bool> kWebUIOmniboxPopupDebugSxSParam{
-    &kWebUIOmniboxPopupDebug, "SxS", false};
-
 // When enabled, use Assistant for omnibox voice query recognition instead of
 // Android's built-in voice recognition service. Only works on Android.
 BASE_FEATURE(kOmniboxAssistantVoiceSearch, DISABLED);
@@ -353,10 +341,6 @@ BASE_FEATURE(kEnableSiteSearchAllowUserOverridePolicy, ENABLED);
 // Enables preconnecting to omnibox suggestions that are not only Search types.
 BASE_FEATURE(kPreconnectNonSearchOmniboxSuggestions, DISABLED);
 
-// Enables restricting omnibox focus restoration to only situations that involve
-// "invisible focus".
-BASE_FEATURE(kOmniboxRestoreInvisibleFocusOnly, ENABLED);
-
 // Enabls adding an aim shortcut in the typed state.
 BASE_FEATURE(kOmniboxAimShortcutTypedState, DISABLED);
 
@@ -376,7 +360,7 @@ bool IsGeminiPrototypeProviderEnabled() {
 #endif
 
 // Controls whether the composebox
-BASE_FEATURE(kComposeboxUsesChromeComposeClient, DISABLED);
+BASE_FEATURE(kComposeboxUsesChromeComposeClient, ENABLED);
 
 #if BUILDFLAG(IS_ANDROID)
 // Accelerates time from cold start to focused Omnibox on low-end devices,
