@@ -21,6 +21,7 @@ import '../simple_confirmation_dialog.js';
 import './passwords_shared.css.js';
 import './payments_list.js';
 import './virtual_card_unenroll_dialog.js';
+import './your_saved_info_shared.css.js';
 
 import type {CrActionMenuElement} from 'chrome://resources/cr_elements/cr_action_menu/cr_action_menu.js';
 import {AnchorAlignment} from 'chrome://resources/cr_elements/cr_action_menu/cr_action_menu.js';
@@ -61,6 +62,10 @@ declare global {
   }
 }
 
+// TODO(crbug.com/447113309): This file along with all of its dependencies
+// should be moved to .../settings/your_saved_info_page directory after
+// full release of the `Your Saved Info` page.
+
 export interface SettingsPaymentsSectionElement {
   $: {
     autofillCreditCardToggle: SettingsToggleButtonElement,
@@ -210,6 +215,16 @@ export class SettingsPaymentsSectionElement extends
           return loadTimeData.getString('autofillPayOverTimeSettingsSublabel');
         },
       },
+
+      /**
+       * Indicates if this element is used as a Your saved info subpage. Causes
+       * slight adjustments like different title, no page shadow, cards being
+       * visible.
+       */
+      isYourSavedInfoSubpage_: {
+        type: Boolean,
+        value: () => loadTimeData.getBoolean('enableYourSavedInfoSettingsPage'),
+      },
     };
   }
 
@@ -238,6 +253,7 @@ export class SettingsPaymentsSectionElement extends
   declare private cardBenefitsSublabel_: string;
   declare private shouldShowPayOverTimeSettings_: boolean;
   declare private payOverTimeSublabel_: string;
+  declare private isYourSavedInfoSubpage_: boolean;
 
   override connectedCallback() {
     super.connectedCallback();
@@ -305,6 +321,15 @@ export class SettingsPaymentsSectionElement extends
     this.setPersonalDataListener_ = null;
   }
 
+  private getMultiCardClass_(): string {
+    return this.isYourSavedInfoSubpage_ ? 'multi-card' : '';
+  }
+
+  private getPageTitleLabel_(): string {
+    return this.i18n(
+      this.isYourSavedInfoSubpage_ ? 'paymentsTitle' : 'creditCards');
+  }
+
   private setCreditCards_(cardList: chrome.autofillPrivate.CreditCardEntry[]) {
     this.creditCards = cardList;
 
